@@ -1,17 +1,20 @@
 # ja/add_bookmark.rb $Revision 1.3 $
 #
 # Japanese resource of add_bookmark.rb
+# You can redistribute it and/or modify it under GPL2.
 #
 
 @add_bookmark_label = '֥åޡɲ'
 @add_bookmark_desc = 'ڡߤ󥯤åƤ'
 
+@caption_delicious = 'del.icio.usɲ'
 @caption_hatena = 'ϤƤʥ֥åޡɲ'
-@caption_del = 'del.icio.usɲ'
-@caption_mm = 'MM/Memoɲ'
+@caption_livedoor = 'livedoor åפɲ'
+@caption_buzzurl = 'Buzzurl ɲ'
 
 @bookmark_label = [
-   'ϤƤʥ֥åޡ',
    'del.icio.us',
-   'MM/Memo',
+   'ϤƤʥ֥åޡ',
+   'livedoor å',
+   'Buzzurl'
 ]
