@@ -1,17 +1,20 @@
 # zh/add_bookmark.rb $Revision 1.3 $
 #
 # Chinaese resource of add_bookmark.rb
+# You can redistribute it and/or modify it under GPL2.
 #
 
 @add_bookmark_label = 'add to bookmark'
 @add_bookmark_desc = 'Please check the link that wants to be displayed.'
 
+@caption_delicious = 'add to del.icio.us'
 @caption_hatena = 'add to Hatena bookmark'
-@caption_del = 'add to del.icio.us'
-@caption_mm = 'add to MM/Memo'
+@caption_livedoor = 'add to livedoor clip'
+@caption_buzzurl = 'add to Buzzurl'
 
 @bookmark_label = [
-   'Hatena bookmark',
    'del.icio.us',
-   'MM/Memo',
+   'Hatena bookmark',
+   'livedoor Clip',
+   'Buzzurl'
 ]
