@@ -20,7 +20,7 @@
 @antispamref_html_myurl = <<-TEXT
 	<h3>Ƥλ</h3>
 	<p>
-	ȥåץڡURL(#{CGI.escapeHTML(if @conf.index_page.empty? then "̤" else @conf.index_page end)})URL(#{CGI.escapeHTML(if @conf.base_url.empty? then "" else @conf.base_url end)})ʳ˥ȤƵƤURLꤷޤ
+	ȥåץڡURL(#{h(if @conf.index_page.empty? then "̤" else @conf.index_page end)})URL(#{h(if @conf.base_url.empty? then "" else @conf.base_url end)})ʳ˥ȤƵƤURLꤷޤ
 	ɽѲǽǤ
 	</p>
 	TEXT
