@@ -1,12 +1,12 @@
 #!/usr/bin/env ruby
 $KCODE= 'e'
 #
-# posttdiary-ex: update tDiary via e-mail. $Revision: 1.6 $
+# posttdiary-ex: update tDiary via e-mail. $Revision: 1.9 $
 #
 # Copyright (C) 2002, All right reserved by TADA Tadashi <sho@spc.gr.jp>
 # You can redistribute it and/or modify it under GPL2.
 #
-# 2006.8.14: v.1.63: Modified by K.Sakurai (http://ks.nwr.jp)
+# 2007.11.22: v.1.66: Modified by K.Sakurai (http://ks.nwr.jp)
 #  Acknowledgements:
 #   * Based on posttdiary.rb v1.2 by TADA.
 #   * Some codes partially imported from Enikki Plugin Ex. : 
@@ -21,7 +21,7 @@ $KCODE= 'e'
 def usage( detailed_help )
 	# (if "!" is at the head of the line, it is to be shown only when detailed_help == true (-h option) )
 	text = <<-TEXT
-		#{File::basename __FILE__}: update tDiary via e-mail (v1.63).
+		#{File::basename __FILE__}: update tDiary via e-mail (v1.64).
 		usage: ruby posttdiary-ex.rb [options (without -d)] <url> <user> <passwd>
 		       ruby posttdiary-ex.rb [options (with -d)]
 		arguments:
@@ -65,6 +65,8 @@ def usage( detailed_help )
 !		          Adds "!" to subject when -s option is given
 !		          Recognize Wiki style tags and rewrite
 !		          Must be used with image.rb or image_ex.rb plugin.
+		  --blog-style,      -B: do not specify date to append unless specified
+!			  Suitable for use with blogkit
 		  --read-exif,       -c: read "User Comment" tag from EXIF and use as ALT text
 !		          If not specified, filename would be used as ALT text.
 !		          Requires libexif and "exif" command.
@@ -133,7 +135,7 @@ def usage( detailed_help )
 !		  --filter-mode,    -d: print to stdout (does not call update.rb)
 !		  --write-to-file,  -b filename: writeout to file (does not call update.rb)
 !		  --date-margin,    -j date_margin: avoid writing diaries for future dates
-!		          ex. -j 30 (default margin: 7)
+!		          ex. -j 30 (default=7, 0=disabled)
 !		  --rotate, -T LEFT or RIGHT: rotate images
 !			  ex. -T RIGHT (rotate 90degrees clockwise)
 !		          Also possible by adding "_ROT_LEFT#" or "_ROT_RIGHT#"to mail body.
@@ -537,6 +539,39 @@ def post_image( http, cgi, user, pass, image_dir , imgname, remote_image_dir, no
 	(image_body ? true : false)
 end
 
+def get_date_to_append( http, cgi, user, pass, now )
+	# call update.rb via HTTP and get the date to append
+	str = cgi
+	req = Net::HTTP::Get.new( str )
+	req.basic_auth user, pass
+	response, = http.request(req)
+	body = response.body
+
+	year = now.strftime( "%Y" )
+	month = now.strftime( "%m" )
+	day = now.strftime( "%d" )
+	bodytmp = body.split(/$/);
+	bodytmp.each do |oneline|
+		if oneline =~ /\<input\s.*\sname=\"year\"([^\>]*)\>/ then
+			if $1 =~ /value=\"(\d\d\d\d)"/ then
+				year = $1
+			end
+		end
+		if oneline =~ /\<input\s.*\sname=\"month\"([^\>]*)\>/ then
+			if $1 =~ /value=\"(\d+)\"/ then
+				month = $1
+			end
+		end
+		if oneline =~ /\<input\s.*\sname=\"day\"([^\>]*)\>/ then
+			if $1 =~ /value=\"(\d+)\"/ then
+				day = $1
+			end
+		end
+	end
+
+	Time::local( year, month, day )
+end
+
 def parse_mail( head, body , image_dir )
 	imglist = []
 	orglist = []
@@ -544,7 +579,7 @@ def parse_mail( head, body , image_dir )
 	imgnum = -1
 	imgdir = add_delimiter( image_dir )
 
-	if head =~ /Content-Type:\s*Multipart\/Mixed.*boundary=\"*([^\"\r\n]*)\"*/im then
+	if   head =~ /Content-Type:\s*Multipart\/Mixed.*boundary=\"*([^\"\r\n]*)\"*/im or head =~ /Content-Type:\s*Multipart\/Related.*boundary=\"*([^\"\r\n]*)\"*/im then
 		bound = "--" + $1
 		body_sub = body.split( Regexp.compile( Regexp.escape( bound ) ) )
 		body_sub.each do |b|
@@ -656,6 +691,7 @@ begin
 	image_format_with_thumbnail = ' <A HREF="$1"><img class="$3" src="$2" alt="$4" title="$4"></a>'
 	image_format_specified = nil
 	wiki_style = false
+	blog_style = false
 	use_original_name = false
 	date_margin = 7
 	convertpath_specified = nil
@@ -690,6 +726,7 @@ begin
 		['--image-format', '-f', GetoptLong::REQUIRED_ARGUMENT],
 		['--use-original-name', '-r', GetoptLong::NO_ARGUMENT],
 		['--wiki-style', '-w', GetoptLong::NO_ARGUMENT],
+		['--blog-style', '-B', GetoptLong::NO_ARGUMENT],
 		['--read-exif', '-c', GetoptLong::NO_ARGUMENT],
 		['--margin-time', '-m', GetoptLong::REQUIRED_ARGUMENT],
 		['--pass-filename', '-p', GetoptLong::NO_ARGUMENT],
@@ -758,6 +795,8 @@ begin
 			when '--wiki-style'
 				wiki_style = true
 				use_image_ex = true
+			when '--blog-style'
+				blog_style = true
 			when '--read-exif'
 				read_exif = true
 			when '--pass-filename'
@@ -888,6 +927,12 @@ begin
 		if /(\d\d\d\d)[^\d]+(\d+)[^\d]+(\d+)/ =~ t then
 			tmp = Time::local( $1.to_i, $2.to_i, $3.to_i );
 		end
+	else
+		if blog_style and !filter_mode then
+			Net::HTTP.start( host, port ) do |http|
+				tmp = get_date_to_append( http, cgi, user, pass, now )
+			end
+		end
 	end
 	if @body.gsub!( /^\_up[ld]+only\#[ \t]*[\r\n]+/i , '' ) then
 		upload_only = true
@@ -902,8 +947,8 @@ begin
 		rotation_degree_specified = 0
 	end
 
-	if tmp >= now + date_margin * 24 * 3600 then
-#		raise "posttdiary-ex: invalid future date"
+	if date_margin != 0 and (tmp - now).abs >= date_margin * 24 * 3600 then
+#		raise "posttdiary-ex: specified date is too far from today"
 #		# use current date (now) instead of specified date(tmp)..
 	else
 		now = tmp
@@ -979,7 +1024,7 @@ begin
 			serial = i.sub( /^\d+_(\d+)\.[^\.]*?$/, '\1' )
 			serial = i if use_image_ex and pass_filename
 			cm = ""
-			cm = exif_comment[i] if read_exif and exif_comment[i].size > 0
+			cm = exif_comment[i] if read_exif and exif_comment[i] and exif_comment[i].size > 0
 			cm = image_orgname[i] if use_original_name and (!cm or cm.size == 0)
 			cm = i.gsub(/\.[^\.]*?$/, '') if !cm or cm.size == 0
 			if use_image_ex then
