@@ -4,7 +4,7 @@
 
 ;; Author: Junichiro Kita <kita@kitaj.no-ip.com>
 
-;; $Id: tdiary-mode.el,v 1.2 2005/07/20 08:39:56 tadatadashi Exp $
+;; $Id: tdiary-mode.el,v 1.4 2005/08/19 08:36:43 tadatadashi Exp $
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
@@ -69,7 +69,6 @@
 
 (require 'http)
 (require 'poe)
-(require 'derived)
 (require 'tempo)
 
 (defvar tdiary-diary-list nil
@@ -96,6 +95,9 @@ Each element looks like (NAME URL) or (NAME URL INDEX-RB UPDATE-RB).")
 (defvar tdiary-title nil
   "Title of diary")
 
+(defvar tdiary-style-mode 'html-mode
+  "Major mode to be used for tDiary editing.")
+
 (defvar tdiary-date nil
   "Date to be updated.")
 
@@ -504,12 +506,16 @@ Otherwise replace all entity references within current buffer."
   (interactive "P")
   (tdiary-new-or-replace t select-url))
 
-(defun tdiary-setup-keys ()
+(defvar tdiary-mode-map (make-sparse-keymap)
   "Set up keymap for tdiary-mode.
-If you want to set up your own key bindings, use `tdiary-mode-hook'."
-  (define-key tdiary-mode-map [(control return)] 'tdiary-complete-plugin)
-  (define-key tdiary-mode-map "\C-c\C-c" 'tdiary-update)
-  )
+If you want to set up your own key bindings, use `tdiary-mode-hook'.")
+
+(define-key tdiary-mode-map [(control return)] 'tdiary-complete-plugin)
+(define-key tdiary-mode-map "\C-c\C-c" 'tdiary-update)
+
+(push (cons 'tdiary-date tdiary-mode-map) minor-mode-map-alist)
+(if (boundp 'minor-mode-list) (push 'tdiary-mode minor-mode-list))
+(push '(tdiary-date " tDiary") minor-mode-alist)
 
 (defun tdiary-load-init-file ()
   "Load init file."
@@ -526,10 +532,30 @@ If you want to set up your own key bindings, use `tdiary-mode-hook'."
       (set-file-modes tmpdir tdiary-text-directory-mode))
     (expand-file-name tdiary-date tmpdir)))
 
-(define-derived-mode tdiary-mode html-mode "tDiary"
-  "Major mode for tDiary editing.
+(defun tdiary-html-mode-init ()
+  "Initialize tDiary for default style"
+  (tdiary-tempo-define (append tdiary-plugin-initial-definition
+			       tdiary-plugin-definition))
+  (tempo-use-tag-list 'tdiary-tempo-tags tdiary-completion-finder))
+
+(defun tdiary-rd-mode-init ()
+  "Initialize tDiary for RD style"
+  )
+
+(defun tdiary-mode ()
+  "tDiary editing mode.
+The value of `tdiary-style-mode' will be used as actual major mode.
 
 \\{tdiary-mode-map}"
+  (interactive)
+  (funcall tdiary-style-mode)
+  (and (featurep 'font-lock)
+       (font-lock-set-defaults))
+  (tdiary-mode-setup))
+
+(defun tdiary-mode-setup ()
+  "Set tDiary mode up."
+  (interactive)
   (make-local-variable 'require-final-newline)	
   (make-local-variable 'tdiary-date)
   (make-local-variable 'tdiary-title)
@@ -543,8 +569,6 @@ If you want to set up your own key bindings, use `tdiary-mode-hook'."
 	tdiary-edit-mode "replace"
 	tdiary-date (format-time-string "%Y%m%d" (tdiary-today)))
 
-  (tdiary-setup-keys)
-
   (tdiary-load-init-file)
 
   (tdiary-setup-diary-url (if (boundp 'select-url)
@@ -552,29 +576,38 @@ If you want to set up your own key bindings, use `tdiary-mode-hook'."
 			    t))
 
   (set-buffer-file-coding-system tdiary-coding-system)
-  (tdiary-tempo-define (append tdiary-plugin-initial-definition
-			       tdiary-plugin-definition))
-  (tempo-use-tag-list 'tdiary-tempo-tags tdiary-completion-finder)
 
   (or tdiary-passwd-cache
       (tdiary-passwd-file-load))
 
-  (and (featurep 'font-lock)
-       (font-lock-set-defaults))
-
   (if buffer-file-name
-      (when (string-match
-	     "\\([0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9]\\)"
-	     buffer-file-name)
-	(setq tdiary-date (match-string 1 buffer-file-name)))
+      (let ((buf-name (file-name-nondirectory buffer-file-name)))
+	(when (string-match
+	       "\\([0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9]\\)"
+	       buf-name)
+	  (setq tdiary-date (match-string 1 buf-name))))
     (setq tdiary-date (tdiary-read-date nil))
     (if tdiary-text-save-p
 	(set-visited-file-name (tdiary-make-temp-file-name))
-      (rename-buffer tdiary-date t)))
+      (unless (string= (buffer-name) tdiary-date)
+	(rename-buffer tdiary-date t))))
+
+  (let ((init (intern (concat "tdiary-" (symbol-name tdiary-style-mode) "-init"))))
+    (if (fboundp init) (funcall init)))
 
   (run-hooks 'tdiary-mode-hook))
 
-(put 'tdiary-mode 'font-lock-defaults '(html-font-lock-keywords nil t))
+(defun tdiary-mode-toggle (&optional arg)
+  (interactive "P")
+  (let ((in-tdiary (and (boundp 'tdiary-date) tdiary-date)))
+    (cond ((not arg)
+	   (setq arg (not in-tdiary)))
+	  ((or (eq arg '-) (and (numberp arg) (< arg 0)))
+	   (setq arg nil)))
+    (cond (arg
+	   (tdiary-mode-setup))
+	  (in-tdiary
+	   (setq tdiary-date nil)))))
 
 (provide 'tdiary-mode)
 ;;; tdiary-mode.el ends here
