@@ -1,8 +1,8 @@
 #!/usr/bin/env ruby
 #
-# index.rb $Revision: 1.26 $
+# index.rb $Revision: 1.35 $
 #
-# Copyright (C) 2001-2003, TADA Tadashi <sho@spc.gr.jp>
+# Copyright (C) 2001-2006, TADA Tadashi <sho@spc.gr.jp>
 # You can redistribute it and/or modify it under GPL2.
 #
 BEGIN { $defout.binmode }
@@ -18,12 +18,12 @@ begin
 	require 'tdiary'
 
 	@cgi = CGI::new
-	conf = TDiary::Config::new
+	conf = TDiary::Config::new(@cgi)
 	tdiary = nil
 	status = nil
-	if %r[/\d{4,8}\.html?$] =~ ENV['REDIRECT_URL'] and not @cgi.valid?( 'date' ) then
-		@cgi.params['date'] = [ENV['REDIRECT_URL'].sub( /.*\/(\d+)\.html$/, '\1' )]
-		status = '200 OK'
+	if %r[/\d{4,8}(-\d+)?\.html?$] =~ @cgi.redirect_url and not @cgi.valid?( 'date' ) then
+		@cgi.params['date'] = [@cgi.redirect_url.sub( /.*\/(\d+)(-\d+)?\.html$/, '\1\2' )]
+		status = CGI::HTTP_STATUS['OK']
 	end
 
 	begin
@@ -31,7 +31,9 @@ begin
 			tdiary = TDiary::TDiaryComment::new( @cgi, "day.rhtml", conf )
 		elsif @cgi.valid?( 'date' )
 			date = @cgi.params['date'][0]
-			if /^\d{8}$/ =~ date then
+			if /^\d{8}-\d+$/ =~ date then
+				tdiary = TDiary::TDiaryLatest::new( @cgi, "latest.rhtml", conf )
+			elsif /^\d{8}$/ =~ date
 				tdiary = TDiary::TDiaryDay::new( @cgi, "day.rhtml", conf )
 			elsif /^\d{6}$/ =~ date then
 				tdiary = TDiary::TDiaryMonth::new( @cgi, "month.rhtml", conf )
@@ -58,29 +60,32 @@ begin
 		body = ''
 		head['Last-Modified'] = CGI::rfc1123_date( tdiary.last_modified )
 
-		# ETag testing code
-		#require 'md5'
-		#head['ETag'] = MD5::md5( body )
-
-		if /HEAD/i !~ @cgi.request_method then
+		if /HEAD/i =~ @cgi.request_method then
+			head['Pragma'] = 'no-cache'
+			head['Cache-Control'] = 'no-cache'
+			print @cgi.header( head )
+		else
 			if @cgi.mobile_agent? then
 				body = conf.to_mobile( tdiary.eval_rhtml( 'i.' ) )
 				head['charset'] = conf.mobile_encoding
 				head['Content-Length'] = body.size.to_s
 			else
+				require 'digest/md5'
 				body = tdiary.eval_rhtml
-				head['charset'] = conf.encoding
-				head['Content-Length'] = body.size.to_s
+				head['ETag'] = %Q["#{Digest::MD5.hexdigest( body )}"]
+				if ENV['HTTP_IF_NONE_MATCH'] == head['ETag'] and /^GET$/i =~ @cgi.request_method then
+				   head['status'] = CGI::HTTP_STATUS['NOT_MODIFIED']
+					body = ''
+				else
+					head['charset'] = conf.encoding
+					head['Content-Length'] = body.size.to_s
+				end
 				head['Pragma'] = 'no-cache'
 				head['Cache-Control'] = 'no-cache'
 			end
 			head['cookie'] = tdiary.cookies if tdiary.cookies.size > 0
 			print @cgi.header( head )
 			print body
-		else
-			head['Pragma'] = 'no-cache'
-			head['Cache-Control'] = 'no-cache'
-			print @cgi.header( head )
 		end
 	rescue TDiary::ForceRedirect
 		head = {
@@ -100,12 +105,17 @@ begin
 	end
 rescue Exception
 	if @cgi then
-		print @cgi.header( 'type' => 'text/plain' )
+		print @cgi.header( 'status' => CGI::HTTP_STATUS['SERVER_ERROR'], 'type' => 'text/html' )
 	else
-		print "Content-Type: text/plain\n\n"
+		print "Status: 500 Internal Server Error\n"
+		print "Content-Type: text/html\n\n"
 	end
-	puts "#$! (#{$!.class})"
+	puts "<h1>500 Internal Server Error</h1>"
+	puts "<pre>"
+	puts CGI::escapeHTML( "#{$!} (#{$!.class})" )
 	puts ""
-	puts $@.join( "\n" )
+	puts CGI::escapeHTML( $@.join( "\n" ) )
+	puts "</pre>"
+	puts "<div>#{' ' * 500}</div>"
 end
 
