@@ -1,4 +1,4 @@
-# append-css.rb: $Revision: 1.5 $
+# append-css.rb: $Revision: 1.10 $
 #
 # Append CSS fragment via Preferences Page.
 #
@@ -6,7 +6,7 @@
 # Distributed under the GPL
 #
 add_header_proc do
-	if @conf['append-css.css'] and @conf['append-css.css'].length > 0 then
+	if @mode !~ /conf$/ and @conf['append-css.css'] and @conf['append-css.css'].length > 0 and not bot? then
 		<<-HTML if @conf['append-css.css']
 		<style type="text/css"><!--
 		#{@conf['append-css.css']}
@@ -31,14 +31,14 @@ unless @resource_loaded then
 	end
 end
 
-add_conf_proc( 'append-css', append_css_label ) do
+add_conf_proc( 'append-css', append_css_label, 'theme' ) do
 	if @mode == 'saveconf' then
 		@conf['append-css.css'] = @cgi.params['append-css.css'][0]
 	end
 
 	<<-HTML
 	#{append_css_desc}
-	<p><textarea name="append-css.css" cols="70" rows="15">#{CGI::escapeHTML( @conf['append-css.css'].to_s )}</textarea></p>
+	<p><textarea name="append-css.css" cols="60" rows="15">#{h @conf['append-css.css']}</textarea></p>
 	HTML
 end
 
