@@ -1,4 +1,4 @@
-# category.rb $Revision: 1.21.2.1 $
+# category.rb $Revision: 1.45 $
 #
 # Copyright (c) 2003 Junichiro KITA <kita@kitaj.no-ip.com>
 # Distributed under the GPL
@@ -28,7 +28,7 @@ def category_icon_init
 	@conf['category.icon'].split(/\n/).each do |l|
 		c, i = l.split
 		next if c.nil? or i.nil?
-		@category_icon[c] = i if File.exists?("#{@category_icon_dir}#{i}")
+		@category_icon[c] = i if File.exists?("#{@category_icon_dir}#{i}".untaint)
 	end
 end
 category_icon_init
@@ -55,18 +55,23 @@ def category_anchor(category)
 		else
 			""
 		end
-	if @category_icon[category]
-		%Q|<a href="#{@index}?#{period_string}category=#{CGI::escape(category)}"><img class="category" src="#{@category_icon_dir}#{@category_icon[category]}" alt="#{category}"></a>|
+	if @category_icon[category] and !@conf.mobile_agent?
+		%Q|<a href="#{h @index}?#{period_string}category=#{u category}"><img class="category" src="#{h @category_icon_url}#{h @category_icon[category]}" alt="#{h category}"></a>|
 	else
-		%Q|[<a href="#{@index}?#{period_string}category=#{CGI::escape(category)}">#{category}</a>]|
+		%Q|[<a href="#{h @index}?#{period_string}category=#{u category}">#{h category}</a>]|
 	end
 end
 
-def category_navi_anchor(info, label)
-	((!label.nil?) && label.empty?) ? '' : %Q[<span class="adminmenu">#{info.make_anchor(label)}</span>\n]
+def category_navi_anchor(info, label, mobile = false)
+	if mobile then
+		"|#{info.make_anchor(label)}"
+	else
+		((!label.nil?) && label.empty?) ? '' : %Q[<span class="adminmenu">#{info.make_anchor(label)}</span>\n]
+	end
 end
 
 def category_navi
+	mobile = @conf.mobile_agent?
 	info = Category::Info.new(@cgi, @years, @conf)
 	mode = info.mode
 
@@ -75,21 +80,23 @@ def category_navi
 	when :year, :half, :quarter, :month
 		all_diary = Category::Info.new(@cgi, @years, @conf, :year => -1, :month => -1)
 		all = Category::Info.new(@cgi, @years, @conf, :category => ['ALL'], :year => -1, :month => -1)
-		result << category_navi_anchor(info.prev, @conf['category.prev_' + mode.to_s])
-		result << category_navi_anchor(info.next, @conf['category.next_' + mode.to_s])
-		result << category_navi_anchor(all_diary, @conf['category.all_diary'])
-		result << category_navi_anchor(all, @conf['category.all'])
+		result << category_navi_anchor(info.prev, @conf['category.prev_' + mode.to_s], mobile)
+		result << category_navi_anchor(info.next, @conf['category.next_' + mode.to_s], mobile)
+		unless mobile then
+			result << category_navi_anchor(all_diary, @conf['category.all_diary'])
+			result << category_navi_anchor(all, @conf['category.all'])
+		end
 	when :all
 		year = Category::Info.new(@cgi, @years, @conf, :year => Time.now.year.to_s)
 		half = Category::Info.new(@cgi, @years, @conf, :year => Time.now.year.to_s, :month => "#{((Time.now.month - 1) / 6 + 1)}H")
 		quarter = Category::Info.new(@cgi, @years, @conf, :year => Time.now.year.to_s, :month => "#{((Time.now.month - 1) / 3 + 1)}Q")
 		month = Category::Info.new(@cgi, @years, @conf, :year => Time.now.year.to_s, :month => '%02d' % Time.now.month)
-		result << category_navi_anchor(year, @conf['category.this_year'])
-		result << category_navi_anchor(half, @conf['category.this_half'])
-		result << category_navi_anchor(quarter, @conf['category.this_quarter'])
-		result << category_navi_anchor(month, @conf['category.this_month'])
+		result << category_navi_anchor(year, @conf['category.this_year'], mobile)
+		result << category_navi_anchor(half, @conf['category.this_half'], mobile)
+		result << category_navi_anchor(quarter, @conf['category.this_quarter'], mobile)
+		result << category_navi_anchor(month, @conf['category.this_month'], mobile)
 	end
-	if !info.category.include?('ALL')
+	if !info.category.include?('ALL') and !mobile then
 		all_category = Category::Info.new(@cgi, @years, @conf, :category => ['ALL'])
 		result << category_navi_anchor(all_category, @conf['category.all_category'])
 	end
@@ -105,7 +112,7 @@ def category_list_sections
 	@categorized.keys.sort.each do |c|
 		info.category = c
 		if @category_icon[c]
-			img = %Q|<img class="category" src="#{@category_icon_dir}#{@category_icon[c]}" alt="#{c}">|
+			img = %Q|<img class="category" src="#{h @category_icon_url}#{h @category_icon[c]}" alt="#{h c}">|
 		else
 			img = ''
 		end
@@ -113,16 +120,16 @@ def category_list_sections
 <div class="conf day">
 	<h2><span class="title">#{img}#{info.make_anchor}</span></h2>
 	<div class="body">
-		<p>
+		<ul class="category">
 HTML
 		@categorized[c].keys.sort.each do |ymd|
 			text = Time.local(ymd[0,4], ymd[4,2], ymd[6,2]).strftime(@conf.date_format)
 			@categorized[c][ymd].sort.each do |idx, title, excerpt|
-				r << %Q|\t\t\t<a href="#{@conf.index}#{anchor "#{ymd}#p#{'%02d' % idx}"}" title="#{excerpt}">#{text}#p#{'%02d' % idx}</a> #{apply_plugin(title)}<br>\n|
+				r << %Q|\t\t\t<li><a href="#{h @index}#{anchor "#{ymd}#p#{'%02d' % idx}"}" title="#{h excerpt}">#{text}#p#{'%02d' % idx}</a> #{apply_plugin(title)}</li>\n|
 			end
 		end
 		r << <<HTML
-		</p>
+		</ul>
 	</div>
 </div>
 HTML
@@ -130,6 +137,27 @@ HTML
 	r
 end
 
+def category_list_sections_mobile
+	info = Category::Info.new(@cgi, @years, @conf)
+	category = info.category
+	years = info.years
+	r = ''
+
+	@categorized.keys.sort.each do |c|
+		info.category = c
+		r << "<H2>#{info.make_anchor}</H2>"
+		r << "<UL>"
+		@categorized[c].keys.sort.each do |ymd|
+			text = Time.local(ymd[0,4], ymd[4,2], ymd[6,2]).strftime(@conf.date_format)
+			@categorized[c][ymd].sort.each do |idx, title, excerpt|
+				r << %Q|<LI><A HREF="#{h @index}#{anchor "#{ymd}#p#{'%02d' % idx}"}">#{text}#p#{'%02d' % idx}</A> #{apply_plugin(title)}</LI>\n|
+			end
+		end
+		r << "</UL>"
+	end
+	r
+end
+
 def category_list
 	info = Category::Info.new(@cgi, @years, @conf)
 	@categories.map do |c|
@@ -142,21 +170,30 @@ def category_dropdown_list(label = nil, multiple = nil)
 	label ||= 'Categorize!'
 	multiple ||= false
 
-	category = Category::Info.new(@cgi, @years, @conf).category
-	category = ['ALL'] if category.empty?
+	info = Category::Info.new(@cgi, @years, @conf)
+	category = info.category
+	if category.empty?
+		return '' if @conf.mobile_agent?
+		category = ['ALL'] 
+	end
 
 	options = ''
 	(['ALL'] + @categories).each do |c|
-		options << %Q|\t\t<option value="#{CGI.escapeHTML(c)}"#{" selected" if category.include?(c)}>#{CGI.escapeHTML(c)}</option>\n|
+		options << %Q|\t\t<option value="#{h c}"#{" selected" if category.include?(c)}>#{h c}</option>\n|
 	end
 
+	params = ''
+	params << %Q[<input type="hidden" name="year" value="#{h info.year}">] if info.year
+	params << %Q[<input type="hidden" name="month" value="#{h info.month}">] if info.month
+
 	<<HTML
-<form method="get" action="#{@conf.index}?#{period_string}">
+<form method="get" action="#{h @index}"><div>
 	<select name="category"#{" multiple" if multiple}>
 #{options}
 	</select>
+	#{params}
 	<input type="submit" value="#{label}">
-</form>
+</div></form>
 HTML
 end
 
@@ -164,9 +201,6 @@ end
 #
 # misc
 #
-::TDiary::TDiaryMonth.module_eval do
-	attr_reader :diaries
-end
 
 def category_icon_save
 	@conf['category.icon'] = @category_icon.map {|c, i| "#{c} #{i}"}.join("\n")
@@ -175,10 +209,22 @@ end
 
 module Category
 
+#
+# CGI (mock-up CGI class for Cache::recreate)
+#
+class CGI
+	attr_reader :params
+	def initialize
+		@params = Hash.new([])
+	end
+end
+
 #
 # Info
 #
 class Info
+	include ERB::Util
+
 	def initialize(cgi, years, conf, args = {})
 		@cgi = cgi
 		@years = years
@@ -268,7 +314,7 @@ public
 	end
 
 	def make_anchor(label = nil)
-		a = @category.map {|c| "category=#{CGI.escape(c)}"}.join(';')
+		a = @category.map {|c| "category=#{u c}"}.join(';')
 		a << ";year=#{@year}" if @year
 		a << ";month=#{@month}" if @month
 		if label
@@ -280,9 +326,9 @@ public
 				label = label.gsub(/\$1/, @year || '*')
 			end
 		else
-			label = @category.map {|c| CGI.escapeHTML(c)}.join(':')
+			label = @category.map.join(':')
 		end
-		%Q|<a href="#{@conf.index}?#{a}">#{label}</a>|
+		%Q|<a href="#{h @conf.index}?#{h a}">#{h label}</a>|
 	end
 
 	#
@@ -362,11 +408,13 @@ end
 # Cache
 #
 class Cache
+	include ERB::Util
+
 	def initialize(conf, bind)
 		@conf = conf
 		@binding = bind                           # ...... very ugly
 		@dir = "#{conf.data_path}/category"
-		Dir.mkdir(@dir) unless File.exist?(@dir) 
+		Dir.mkdir(@dir) unless File.exist?(@dir)
 	end
 
 	def add_categories(list)
@@ -430,7 +478,7 @@ class Cache
 	# (re)create category cache
 	#
 	def recreate(years)
-		cgi = CGI::new
+		cgi = Category::CGI::new
 		def cgi.referer; nil; end
 
 		list = []
@@ -467,18 +515,24 @@ class Cache
 		end
 
 		categorized = {}
-		categories.each do |c|
-			PStore.new(cache_file(c)).transaction do |db|
-				categorized[c] = db['category']
-				db.abort
-			end
-			categorized[c].keys.each do |ymd|
-				y, m = ymd[0,4], ymd[4,2]
-				if years[y].nil? or !years[y].include?(m)
-					categorized[c].delete(ymd)
+		begin
+			categorized.clear
+			categories.each do |c|
+				PStore.new(cache_file(c)).transaction do |db|
+					categorized[c] = db['category']
+					db.abort
 				end
+				categorized[c].keys.each do |ymd|
+					y, m = ymd[0,4], ymd[4,2]
+					if years[y].nil? or !years[y].include?(m)
+						categorized[c].delete(ymd)
+					end
+				end
+				categorized.delete(c) if categorized[c].empty?
 			end
-			categorized.delete(c) if categorized[c].empty?
+		rescue NoMethodError	# when categorized[c] is nil
+			recreate(years)
+			retry
 		end
 
 		categorized
@@ -487,7 +541,7 @@ class Cache
 private
 	def cache_file(category = nil)
 		if category
-			"#{@dir}/#{CGI.escape(category)}".untaint
+			"#{@dir}/#{u category}".untaint
 		else
 			"#{@dir}/category_list"
 		end
@@ -567,8 +621,7 @@ end # module Category
 		ret << '<div class="field title">'
 		ret << "#{@category_conf_label}:\n"
 		@categories.each do |c|
-			e_c = CGI.escapeHTML(c)
-			ret << %Q!| <a href="javascript:inj_c(&quot;[#{e_c}]&quot;)">#{e_c}</a>\n!
+			ret << %Q!| <a href="javascript:inj_c(&quot;[#{h c}]&quot;)">#{h c}</a>\n!
 		end
 		ret << "|\n</div>\n<br>\n"
 	end
@@ -579,14 +632,16 @@ end
 # when update diary, update cache
 #
 add_update_proc do
-	cache = @category_cache
-	list = []
-	diary = @diaries[@date.strftime('%Y%m%d')]
-	diary.each_section do |s|
-		list |= s.categories
+	if /^(append|replace)$/ =~ @mode
+		cache = @category_cache
+		list = []
+		diary = @diaries[@date.strftime('%Y%m%d')]
+		diary.each_section do |s|
+			list |= s.categories
+		end
+		cache.add_categories(list)
+		cache.replace_sections(diary)
 	end
-	cache.add_categories(list)
-	cache.replace_sections(diary)
 end
 
 
@@ -597,7 +652,7 @@ def category_icon_find_icons
    return if @category_all_icon
 	@category_all_icon = []
 	%w(png jpg gif bmp).each do |e|
-		@category_all_icon += Dir.glob("#{@category_icon_dir}*.#{e}").map {|i| File.basename(i)}
+		@category_all_icon += Dir.glob("#{@category_icon_dir}*.#{e}".untaint).map {|i| File.basename(i)}
 	end
 	@category_all_icon.sort!
 end
@@ -605,10 +660,10 @@ end
 def category_icon_select(category)
 	options = %Q|<\t<option value="none">#{@category_icon_none_label}</option>\n|
 	@category_all_icon.each do |i|
-		options << %Q|\t<option value="#{CGI.escapeHTML(i)}"#{" selected" if @category_icon[category] == i}>#{CGI.escapeHTML(i)}</option>\n|
+		options << %Q|\t<option value="#{h i}"#{" selected" if @category_icon[category] == i}>#{h i}</option>\n|
 	end
 	<<HTML
-<select name="category.icon.#{category}">
+<select name="category.icon.#{h category}">
 #{options}
 </select>
 HTML
@@ -616,12 +671,12 @@ end
 
 def category_icon_sample
 	@category_all_icon.map do |i|
-		%Q|<img src="#{@category_icon_url}#{i}" alt="#{i}">\n|
+		%Q|<img src="#{h @category_icon_url}#{h i}" alt="#{h i}" title="#{h i}">\n|
 	end.join("/\n")
 end
 
 if @mode == 'conf' || @mode == 'saveconf'
-	add_conf_proc('category', @category_conf_label) do
+	add_conf_proc( 'category', @category_conf_label, 'basic' ) do
 		cache = @category_cache
 		if @mode == 'saveconf'
 			if @cgi.valid?( 'category_initialize' )
@@ -662,7 +717,7 @@ if @mode == 'conf' || @mode == 'saveconf'
 	end
 
 	category_icon_find_icons if @cgi.params['conf'][0] == 'category_icon'
-	add_conf_proc('category_icon', @category_icon_conf_label) do
+	add_conf_proc( 'category_icon', @category_icon_conf_label, 'basic' ) do
 		if @mode == 'saveconf'
 			unless @conf.secure
 				[
@@ -676,15 +731,16 @@ if @mode == 'conf' || @mode == 'saveconf'
 			@cgi.params.keys.each do |key|
 				next unless /\Acategory\.icon\..*\z/ === key
 				category = key.sub(/\Acategory\.icon\./, '')
-				@category_icon[category] = @cgi.params[key][0] if @cgi.params[key][0] != 'none'
+				if @cgi.params[key][0] == 'none'
+					@category_icon.delete(category)
+				else
+					@category_icon[category] = @cgi.params[key][0]
+				end
 			end
 			category_icon_save
 		end
 		category_icon_conf_html
 	end
-	if @cgi.valid?('category_initialize')
-		@category_cache.recreate(@years)
-	end
 end
 
 @categories = @category_cache.restore_categories
