@@ -1,4 +1,4 @@
-# comment_mail_qmail.rb $Revision: 1.7 $
+# comment_mail_qmail.rb $Revision: 1.10 $
 #
 # qmailȤäƥĥåߤ᡼Τ餻
 #   ư롣
@@ -30,7 +30,7 @@
 def comment_mail( text, to )
 	begin
 		qmail = @conf['comment_mail.qmail'] || '/var/qmail/bin/qmail-inject'
-		open( "|#{qmail} -f #{@conf.author_mail.untaint} #{to.join(' ')}", 'w' ) do |o|
+		open( %Q[|'#{qmail.gsub(/'/, '')}' -f '#{@conf.author_mail.gsub( /'/, '' ).untaint}' '#{to.map{|x|x.gsub(/'/,'')}.join("' '")}'], 'w' ) do |o|
 			o.write( text )
 		end
 	rescue
@@ -39,10 +39,10 @@ def comment_mail( text, to )
 end
 
 add_update_proc do
-	comment_mail_send if @mode =~ /^(comment|trackbackreceive)$/
+	comment_mail_send if @mode =~ /^(comment|trackbackreceive|pingbackreceive)$/
 end
 
-add_conf_proc( 'comment_mail', comment_mail_conf_label ) do
+add_conf_proc( 'comment_mail', comment_mail_conf_label, 'tsukkomi' ) do
 	comment_mail_basic_setting
 	comment_mail_basic_html
 end
