@@ -1,4 +1,4 @@
-# comment_mail-smtp.rb $Revision: 1.8 $
+# comment_mail-smtp.rb $Revision: 1.10 $
 #
 # SMTPץȥȤäƥĥåߤ᡼Τ餻
 #   ư
@@ -42,10 +42,10 @@ def comment_mail( text, to )
 end
 
 add_update_proc do
-	comment_mail_send if @mode =~ /^(comment|trackbackreceive)$/
+	comment_mail_send if @mode =~ /^(comment|trackbackreceive|pingbackreceive)$/
 end
 
-add_conf_proc( 'comment_mail', comment_mail_conf_label ) do
+add_conf_proc( 'comment_mail', comment_mail_conf_label, 'tsukkomi' ) do
 	comment_mail_basic_setting
 	comment_mail_basic_html
 end
