@@ -1,4 +1,4 @@
-# comment_rank.rb $Revision: 1.3.2.1 $
+# comment_rank.rb $Revision: 1.7 $
 #
 # comment_rank: ĥåߤοǥ󥭥
 #   ѥ᥿:
@@ -6,13 +6,14 @@
 #     sep:  ѥ졼(̤:)
 #     except:        ̵뤹̾(Ĥ⤢,Ƕڤä¤٤)
 #
-# Copyright (C) 2002 by TADA Tadashi <sho@spc.gr.jp>
-# You can redistribute it and/or modify it under GPL2.
+# Copyright (c) 2002 TADA Tadashi <sho@spc.gr.jp>
+# You can distribute this file under the GPL2.
+#
 #
 def comment_rank( max = 5, sep = '&nbsp;', *except )
 	name = Hash::new(0)
 	@diaries.each_value do |diary|
-		diary.each_comment( 100 ) do |comment|
+		diary.each_comment do |comment|
 			next if except.include?(comment.name)
 			name[comment.name] += 1
 		end
@@ -20,7 +21,7 @@ def comment_rank( max = 5, sep = '&nbsp;', *except )
 	result = []
 	name.sort{|a,b| (a[1])<=>(b[1])}.reverse.each_with_index do |ary,idx|
 		break if idx >= max
-		result << "<strong>#{idx+1}.</strong>#{CGI::escapeHTML( ary[0].to_s )}(#{ary[1].to_s})"
+		result << "<strong>#{idx+1}.</strong>#{h ary[0]}(#{ary[1].to_s})"
 	end
 	result.join( sep )
 end
