@@ -1,5 +1,5 @@
 =begin
-= Υ󥯸⤦äȤץ饰((-$Id: disp_referrer.rb,v 1.38.2.1 2005/07/20 08:25:01 tadatadashi Exp $-))
+= Υ󥯸⤦äȤץ饰((-$Id: disp_referrer.rb,v 1.69 2007/12/11 07:23:39 zunda Exp $-))
 
 == 
 ƥʤΥ󥯡󥸥θ̤̾Υ󥯸βˤ
@@ -7,20 +7,6 @@
 
 ǿɽǤϡ̾Υ󥯸ʳΥ󥯸򱣤ޤ
 
-== ٥ޡƥ
-٥ޡƥѤΥץѰդޤåȤ褦
-ꤷơΥǡ˽񤭹߸¤Τ桼
-  echo 'conf=disp_referrer2;dr2.cache.update=scan' | ./update.rb
-ʤɤȤȡåˡ󥸥((-̾ϥå夷ʤ-))
-᤿ǡƤΥ󥯸URL򥭥å񤭽Фޤľˡ
-  echo 'conf=disp_referrer2;dr2.cache.update=force' | (time ./update.rb) >| $log 2>&1
-ʤɤȼ¹Ԥ뤳ȤǡåˤƤURLˤĤơ󥯸ִ
-Ȥץ饰˴ޤޤƤ븡󥸥ΥꥹȤƥ󥯸
-򤷤ޤ
-
-ˤäơΥץ饰®٤βǤ**ޤ󡣤ɤ
-ꤤޤ
-
 == Acknowledgements
 This plugin uses
 * Some of the search engine names and URLs
@@ -35,7 +21,7 @@ kazuhiko.
 The author of this plugin  appreciates them.
 
 == Copyright notice
-Copyright (C) 2003 zunda <zunda at freeshell.org>
+Copyright (C) 2003-2005 zunda <zunda at freeshell.org>
 
 Please note that some methods in this plugin are written by other
 authors as written in the comments.
@@ -92,7 +78,7 @@ See ChangeLog for changes after this.
 Array#values_at()̵硢ɲäޤ
 =end
 # 1.8 feature
-unless [].respond_to?( 'values_at' ) then
+unless [].respond_to?( :values_at ) then
 	eval( <<-MODIFY_CLASS, TOPLEVEL_BINDING )
 		class Array
 			alias values_at indices
@@ -103,6 +89,7 @@ end
 # to be visible from inside classes
 Dispref2plugin = self
 Dispref2plugin_cache_path = @cache_path
+Dispref2plugin_cache_dir = @cache_dir
 Dispref2plugin_secure = @conf.secure
 
 # cache format
@@ -125,7 +112,37 @@ class DispRef2DummyPStore
 	end
 end
 
+class DispRef2CachePathDummy
+	def initialize( setup )
+		@setup = setup
+	end
+	def size
+		0
+	end
+	def caches( include_backup = true )
+		[]
+	end
+	def method_missing( name, *args )
+		nil
+	end
+end
+
 =begin
+=== Tdiary::Plugin::DispRef2CachePath
+DispRef2StoreΥѥδ򤷤ޤ
+
+--- DispRef2CachePath::new( setup )
+
+--- DispRef2CachePath#cache( date )
+     ΤΥåΥѥ֤ޤ
+
+--- DispRef2CachePath#caches
+      ¸ߤ뤽줾ΥåեΥѥ֤ޤ
+
+--- DispRef2CachePath#shrink
+      ǶȤƤʤå뤳Ȥǡ
+      å礭٤ޤޤ
+
 === Tdiary::Plugin::DispRef2PStore
 @secure=falseǤPStoreƱΥ᥽åɤ@secure=trueǤ
 ⤷ʤ᥽åɤ󶡤ޤ
@@ -137,7 +154,66 @@ end
 --- DispRef2PSTore#real?
       ʪPSToreȤtrueǤʤfalse֤ޤ
 =end
+
 unless @conf and @conf.secure then
+	class DispRef2CachePath
+		def initialize( setup )
+			@setup = setup
+		end
+		def cache( date )
+			return File.join( @setup['cache_dir'], 'volatile.tdr2.cache' ) unless date
+			begin
+				Dir.mkdir( @setup['cache_dir'] )
+			rescue Errno::EEXIST
+			end
+			File.join( @setup['cache_dir'], date.strftime( '%Y%m.tdr2.cache' ) )
+		end
+		def caches( include_backup = true )
+			if include_backup then
+				r = Dir.glob( File.join( @setup['cache_dir'], '??????.tdr2.cache*' ) )
+			else
+				r = Dir.glob( File.join( @setup['cache_dir'], '??????.tdr2.cache' ) )
+			end
+			r.collect{ |p| p.untaint }
+		end
+		def size
+			r = 0
+			caches.each do |path|
+				r += File.size( path )
+			end
+			r
+		end
+		def clear
+			# current version
+			caches.each do |path|
+				begin
+					File.unlink( path )
+				rescue Errno::ENOENT
+				end
+			end
+			# older version
+			if @setup['cache_path'] then
+				[ @setup['cache_path'], @setup['cache_path']+'~' ].each do |f|
+					File.unlink( f ) if FileTest::exist?( f )
+				end
+			end
+		end
+		def shrink
+			return if @setup['cache_max_size'] <= 0
+			size = 0
+			begin
+				caches.sort{ |a,b| File.atime( b ) <=> File.atime( a ) }.each do |path|
+					if size < @setup['cache_max_size'] then
+						size += File.size( path )
+					else
+						File.unlink( path )
+					end
+				end
+			rescue Errno::ENOENT
+			end
+		end
+	end
+
 	require 'pstore'
 	class DispRef2PStore < PStore
 		def real?
@@ -146,6 +222,9 @@ unless @conf and @conf.secure then
 		def transaction( read_only = false )
 			begin
 				super
+			rescue TypeError
+				File.unlink( self.path )
+				super
 			rescue ArgumentError
 				super()
 			end
@@ -157,6 +236,8 @@ else
 			false
 		end
 	end
+	class DispRef2CachePath < DispRef2CachePathDummy
+	end
 end
 
 =begin
@@ -267,19 +348,31 @@ class DispRef2String
 			@@have_nora = true
 		end
 		def self::escapeHTML( str )
-			Web::escapeHTML( str )
+			str ? Web::escapeHTML( str ) : ''
 		end
 		def self::unescape( str )
-			Web::unescape( str )
+			str ? Web::unescape( str ) : ''
 		end
 	rescue LoadError
-		def self::escapeHTML( str )
-			CGI::escapeHTML( str )
-		end
 		def self::unescape( str )
-			# escape ruby 1.6 bug.
-			str.gsub( /\+/, ' ').gsub(/((?:%[0-9a-fA-F]{2})+)/n) do
-				[$1.delete('%')].pack('H*')
+			if str then
+				# escape ruby 1.6 bug.
+				str.gsub( /\+/, ' ').gsub(/((?:%[0-9a-fA-F]{2})+)/n) do
+					[$1.delete('%')].pack('H*')
+				end
+			else
+				''
+			end
+		end
+		begin
+			require 'erb'
+			extend ERB::Util
+			def DispRef2String::escapeHTML( str )
+				str ? h( str ) : ''
+			end
+		rescue LoadError
+			def DispRef2String::escapeHTML( str )
+				str ? CGI::escapeHTML( str ) : ''
 			end
 		end
 	end
@@ -319,7 +412,7 @@ class DispRef2String
 		end
 		r.sub!( /\/(index\.html?)$/, '/' )	# directory index
 		r.sub!( /\/$/, '/?.*' )	# may be also from a lower level
-		"^#{r}"	# always good to put a ^
+		"\\A#{r}"	# always good to put a \A
 	end
 
 	# matchs to the regexp strings?
@@ -385,9 +478,9 @@ class DispRef2Setup < Hash
 		'short.only_normal' => true,
 			# trueξ硢ǿɽǡ̾Υ󥯸ʳ򱣤ޤ
 			# falseξϡץ饰̵ʤɽˤʤޤ
-		'antenna.url' => '(\/a\/|(?!.*\/diary\/)antenna[\/\.]|\/tama\/|www\.tdiary\.net\/?(i\/)?(\?|$)|links?|kitaj\.no-ip\.com\/iraira\/)',
+		'antenna.url' => '(\/a\/|(?!.*\/diary\/)antenna[\/\.]|\/tama\/|\Ahttp:\/\/www\.tdiary\.net\/?(i\/)?(\?|$)|links?|\Ahttp:\/\/kitaj\.no-ip\.com\/iraira\/|\Ahttp:\/\/i-know\.jp\/|\Ahttp:\/\/(www\.)?bloglines\.com\/(myblogs|public)_display|\Ahttp:\/\/del\.icio\.us\/\w+|\Ahttp:\/\/reader\.livedoor\.com\/reader\/)',
 			# ƥʤURL˰פɽʸǤ
-		'antenna.title' => '(ƥ|links?|Ƥ)',
+		'antenna.title' => '(ƥ|links?|Ƥ|antenna|entry|entries|󥯽|RSS|֥åޡ)',
 			# ƥʤִʸ˰פɽʸǤ
 		'normal.label' => Dispref2plugin.referer_today,
 			# ̾Υ󥯸ΥȥǤǥեȤǤϡΥ󥯸פǤ
@@ -425,6 +518,12 @@ class DispRef2Setup < Hash
 			# 󥸥ΥåURLɽʸǤ
 		'cache_path' => "#{Dispref2plugin_cache_path}/disp_referrer2.cache",
 			# Υץ饰ǻȤåեΥѥǤ
+			# ΥץϸߤϻȤƤޤ
+		'cache_dir' => "#{Dispref2plugin_cache_path}/disp_referrer2.d",
+			# Υץ饰ǻȤåեΥǥ쥯ȥǤ
+		'cache_max_size' => 10485760,	# 10MB
+			# åι̤(Х)Ǥۤޤ
+			# 0̤ʤ¤ޤ
 		'no_cache' => false,
 			# trueξ硢@secure=falseǤ⥭åȤޤ
 		'normal-unknown.title' => '\Ahttps?:\/\/',
@@ -439,7 +538,7 @@ class DispRef2Setup < Hash
 
 	attr_reader :is_long, :referer_table, :no_referer, :secure, :years, :conf
 
-	def initialize( conf, limit = 100, is_long = true, years = nil )
+	def initialize( conf, limit = 100, is_long = true, years = nil, mode = nil )
 		super()
 		@conf = conf
 		@years = years
@@ -448,6 +547,7 @@ class DispRef2Setup < Hash
 		@is_long = is_long
 		@limit = limit
 		@options = conf.options
+		@mode = mode
 
 		# URL tables
 		@referer_table = conf.referer_table
@@ -474,6 +574,7 @@ class DispRef2Setup < Hash
 			options_key = "disp_referrer2.#{key}"
 			self[key] = @options[options_key] if @options.has_key?( options_key )
 		end
+		self['no_cache'] = true if @conf.io_class == ::TDiary::DefaultIO
 
 		# additions
 		self['labels'] = {
@@ -498,12 +599,27 @@ class DispRef2Setup < Hash
 				self['limit'][c] = @limit || 0
 			end
 		end
-		if self['unknown.hide'] then
+		if self['unknown.hide'] and not /\A(append|replace|edit)\Z/ =~ @mode then
 			self['limit'][DispRef2URL::Unknown] = 0
 		end
 		self
 	end
 
+	def open_cache( path )
+		if self['no_cache'] then
+			DispRef2DummyPStore::new( path )
+		else
+			DispRef2PStore::new( path )
+		end
+	end
+
+	def cache_path
+		if self['no_cache'] then
+			DispRef2CachePathDummy::new( self )
+		else
+			DispRef2CachePath::new( self )
+		end
+	end
 end
 
 =begin
@@ -571,7 +687,6 @@ class DispRef2URL
 		normal.categorize
 		normal.group
 		normal.ignore_parenthesis
-		cache_path
 	)
 
 	def initialize( unescaped_url, setup = nil )
@@ -608,11 +723,7 @@ class DispRef2URL
 				db[Root_DispRef2URL] = Hash.new
 			end
 		) then
-			 unless @category == DispRef2URL::Search then
-				db[Root_DispRef2URL]["#{@url}"] = [ @category, @category_label, @title, @title_ignored, @title_group, @key ]
-			else
-				db[Root_DispRef2URL].delete( @url )
-			end
+			db[Root_DispRef2URL]["#{@url}"] = [ @category, @category_label, @title, @title_ignored, @title_group, @key ]
 			self
 		else
 			nil
@@ -629,6 +740,16 @@ class DispRef2URL
 			@key == other.key
 	end
 
+	def replace_with(other)
+		@category = other.category
+		@category_label = other.category_label
+		@title = other.title
+		@title_ignored = other.title_ignored
+		@title_group = other.title_group
+		@key = other.key
+		return self
+	end
+
 	private
 		def parse_as_search( setup )
 			# see which search engine is used
@@ -642,49 +763,53 @@ class DispRef2URL
 			title = nil
 			keyword = nil
 			cached_url = nil
-			values = query ? DispRef2String::parse_query( query ) : nil
 			catch( :done ) do
-				setup['search_engines'][engine].each do |e|
-					if( e[0] =~ urlbase ) then
-						title = eval( e[1] )
-						if e[2].empty? then
-							keyword = setup['search.unknown_keyword']
-							throw :done
-						end
-						if String == e[2].class then
-							k, c = (query ? query : @url ).instance_eval( e[2] )
-							if k then
-								keyword = k
-							else
-								keyword = setup['search.unknown_keyword']
-							end
-							cached_url = c ? c : nil
-							throw :done
-						else	# should be an Array usually
-							if not values then
-								keyword = setup['search.unknown_keyword']
-								throw :done
-							end
-							e[2].each do |k|
-								if( values[k] and not values[k][0].empty? ) then
-									unless( e[3] and e[3] =~ values[k][0] ) then
-										cached_url = nil
-										keyword = values[k][0]
-										throw :done
-									else
-										cached_url = $1
-										keyword = $` + $'
-										throw :done
-									end
+				setup['search_engines'][engine].each do |re_url, title_code, keys, cache|
+					next unless re_url =~ urlbase
+
+					title = eval( title_code )
+					throw :done if keyword
+					if String == keys.class then	# a Ruby code to extract key
+						re_url =~ urlbase
+						keyword, cached_url = (query || @url).instance_eval( keys )
+						throw :done
+					end
+					next unless query	# below is to extract keyword from query
+					values = DispRef2String::parse_query( query )
+					# an Array of keys in which keywords or recursive URL are stored
+					keys.each do |key|
+						if Symbol === key then
+							k = key.to_s
+							if values[k] and not (encoded_uri = values[k][0]).empty? then
+								begin
+									original_uri = URI::parse( urlbase ) + URI::parse( URI::decode(encoded_uri) )
+									throw :done if original_uri == urlbase	# denial of service?
+									self.replace_with( DispRef2URL.new( original_uri.to_s ).parse( setup ) )
+									return self
+								rescue URI::InvalidURIError
+									throw :done
 								end
 							end
+						elsif values[key] and not (value = values[key][0]).empty? then
+							unless cache and cache =~ value then
+								cached_url = nil
+								keyword = values[key][0]
+								throw :done
+							else
+								cached_url = $1
+								keyword = $` + $'
+								throw :done
+							end
 						end
+						next
 					end
+
 				end
+				return nil
 			end
-			return nil unless keyword
 
 			# format
+			keyword ||= setup['search.unknown_keyword']
 			@category = Search
 			@category_label = nil
 			@title = DispRef2String::normalize( setup.to_native( DispRef2String::unescape( keyword ) ) )
@@ -693,11 +818,10 @@ class DispRef2URL
 			@title_group = @title
 			@key = @title_group
 
-			self
+			return self
 		end
 
 		def parse_as_others( setup )
-
 			# try to convert with referer_table
 			matched = false
 			title = setup.to_native( DispRef2String::unescape( @url ) )
@@ -754,7 +878,7 @@ class DispRef2URL
 				@title  = title
 				@title_group = title
 				@title_ignored = nil
-				@key = url
+				@key = @url
 			elsif not ignoring then
 				@title = title
 				@title_group = title
@@ -805,9 +929,9 @@ class DispRef2Refs
 			done_flag[c] = (@setup['limit'][c] < 1)
 		end
 
-		db = @setup['no_cache'] ? DispRef2DummyPStore.new( @setup['cache_path'] ) : DispRef2PStore.new( @setup['cache_path'] )
-
 		h = Hash.new
+		date = diary.respond_to?( :date ) ? diary.date : nil
+		db = setup.open_cache( setup.cache_path.cache( date ) )
 		db.transaction do
 			diary.each_referer( diary.count_referers ) do |count, url|
 				ref = DispRef2URL.new( url )
@@ -849,9 +973,13 @@ class DispRef2Refs
 
 	# urls in the diary as a hash
 	def urls( category = nil )
+		if category then
+			category = [ category ] unless category.respond_to?( :each )
+		else
+			category = @refs.keys
+		end
 		h = Hash.new
-		category = [ category ] unless category.class == Array
-		(category ? category : @refs.keys).each do |cat|
+		category.each do |cat|
 			next unless @refs[cat]
 			@refs[cat].each do |a|
 				a[2].each do |b|
@@ -864,17 +992,17 @@ class DispRef2Refs
 
 	def to_short_html
 		return '' if not @refs[DispRef2URL::Normal] or @refs[DispRef2URL::Normal].size < 1
-		result = %Q[#{@setup['labels'][DispRef2URL::Normal]} | ]
+		result = DispRef2String::escapeHTML( @setup['labels'][DispRef2URL::Normal] ) + ' | '
 		@refs[DispRef2URL::Normal].each do |a|
-			result << %Q[<a href="#{DispRef2String::escapeHTML( a[2][0][1].url )}" title="#{DispRef2String::escapeHTML( a[2][0][1].title )}">#{a[0]}</a> | ]
+			result << %Q[<a rel="nofollow" href="#{DispRef2String::escapeHTML( a[2][0][1].url )}" title="#{DispRef2String::escapeHTML( a[2][0][1].title )}">#{a[0]}</a> | ]
 		end
 		result
 	end
 
-	def to_long_html
+	def to_long_html( label )
 		return '' if not @has_ref
 		# we always need a caption
-		result = %Q[<div class="caption">#{@setup['labels'][DispRef2URL::Normal]}</div>\n]
+		result = %Q[<div class="caption">#{DispRef2String::escapeHTML( label )}</div>\n]
 		result << others_to_long_html( DispRef2URL::Normal )
 		if( @setup['normal.categorize'] and special_categories ) then
 			special_categories.each do |cat|
@@ -894,20 +1022,20 @@ class DispRef2Refs
 			unless DispRef2URL::Normal == cat_key then
 				# to_long_html provides the catpion for normal links
 				if @setup['labels'].has_key?( cat_key ) then
-					result << %Q[<div class="caption">#{@setup['labels'][cat_key]}</div>\n]
+					result << %Q[<div class="caption">#{DispRef2String::escapeHTML( @setup['labels'][cat_key] )}</div>\n]
 				else
-					result << %Q[<div class="caption">#{cat_key}</div>\n]
+					result << %Q[<div class="caption">#{DispRef2String::escapeHTML( cat_key )}</div>\n]
 				end
 			end
 			result << '<ul>'
 			@refs[cat_key].each do |a|
 				if a[2].size == 1 then
-					result << %Q[<li><a href="#{DispRef2String::escapeHTML( a[2][0][1].url )}">#{DispRef2String::escapeHTML( a[2][0][1].title )}</a> &times;#{a[0]}</li>\n]
+					result << %Q[<li><a rel="nofollow" href="#{DispRef2String::escapeHTML( a[2][0][1].url )}">#{DispRef2String::escapeHTML( a[2][0][1].title )}</a> &times;#{a[0]}</li>\n]
 				elsif not a[2][0][1].title_ignored then
-					result << %Q[<li><a href="#{DispRef2String::escapeHTML( a[2][0][1].url )}">#{DispRef2String::escapeHTML( a[1] )}</a> &times;#{a[0]} : #{a[2][0][0]}]
+					result << %Q[<li><a rel="nofollow" href="#{DispRef2String::escapeHTML( a[2][0][1].url )}">#{DispRef2String::escapeHTML( a[1] )}</a> &times;#{a[0]} : #{a[2][0][0]}]
 					a[2][1..-1].each do |b|
 						title = (b[1].title != a[1]) ? %Q[ title="#{DispRef2String::escapeHTML( b[1].title )}"] : ''
-						result << %Q[, <a href="#{DispRef2String::escapeHTML( b[1].url )}"#{title}>#{b[0]}</a>]
+						result << %Q[, <a rel="nofollow" href="#{DispRef2String::escapeHTML( b[1].url )}"#{title}>#{b[0]}</a>]
 					end
 					result << "</li>\n"
 				else
@@ -916,7 +1044,7 @@ class DispRef2Refs
 					a[2][0..-1].each do |b|
 						title = (b[1].title != a[1]) ? %Q[ title="#{DispRef2String::escapeHTML( b[1].title )}"] : ''
 						result << comma if comma
-						result << %Q[<a href="#{DispRef2String::escapeHTML( b[1].url )}"#{title}>#{b[0]}</a>]
+						result << %Q[<a rel="nofollow" href="#{DispRef2String::escapeHTML( b[1].url )}"#{title}>#{b[0]}</a>]
 						comma = ', '
 					end
 					result << "</li>\n"
@@ -927,7 +1055,7 @@ class DispRef2Refs
 
 		def search_to_long_html
 			return '' unless @refs[DispRef2URL::Search] and @refs[DispRef2URL::Search].size > 0
-			result = %Q[<div class="caption">#{@setup['labels'][DispRef2URL::Search]}</div>\n]
+			result = %Q[<div class="caption">#{DispRef2String::escapeHTML( @setup['labels'][DispRef2URL::Search] )}</div>\n]
 			result << ( @setup['search.expand'] ? "<ul>\n" : '<ul><li>' )
 			sep = nil
 			@refs[DispRef2URL::Search].each do |a|
@@ -936,18 +1064,18 @@ class DispRef2Refs
 					result << '<li>'
 					result << DispRef2String::escapeHTML( a[1] )
 				else
-					result << %Q[<a href="#{DispRef2String::escapeHTML( a[2][0][1].url )}">#{DispRef2String::escapeHTML( a[1] )}</a>]
+					result << %Q[<a rel="nofollow" href="#{DispRef2String::escapeHTML( a[2][0][1].url )}">#{DispRef2String::escapeHTML( a[1] )}</a>]
 				end
 				result << %Q[ &times;#{a[0]} ]
 				if @setup['search.expand'] then
 					result << ' : '
 					if a[2].size < 2 then
-						result << %Q[<a href="#{DispRef2String::escapeHTML( a[2][0][1].url )}">#{DispRef2String::escapeHTML( a[2][0][1].title_ignored )}</a>]
+						result << %Q[<a rel="nofollow" href="#{DispRef2String::escapeHTML( a[2][0][1].url )}">#{DispRef2String::escapeHTML( a[2][0][1].title_ignored )}</a>]
 					else
 						comma = nil
 						a[2].each do |b|
 							result << comma if comma
-							result << %Q[<a href="#{DispRef2String::escapeHTML( b[1].url )}">#{DispRef2String::escapeHTML( b[1].title_ignored )}</a> &times;#{b[0]}]
+							result << %Q[<a rel="nofollow" href="#{DispRef2String::escapeHTML( b[1].url )}">#{DispRef2String::escapeHTML( b[1].title_ignored )}</a> &times;#{b[0]}]
 							comma = ', ' unless comma
 						end
 					end
@@ -969,20 +1097,12 @@ end
       󥯸ΥåDispRef2SetupΥ󥹥((|setup|))ˤ
       äƴޤ
 
---- DispRef2Cache#update
-      åƤ򸽺ߤ˽äƹޤ줿URLο
-      ֤ޤ
-
---- DispRef2Cache#size
-      åե礭Хñ̤֤ޤ
-
---- DispRef2Cache#entries
-      å夵ƤURLο֤ޤ
-
---- DispRef2Cache#urls( category = nil )
+--- DispRef2Cache#urls( category = nil, nmonth = 2 )
       å夵ƤURLξΤƥ꡼((|category|))
       פΤURL򥭡ͤȤϥåȤ֤
       ޤ((|category|))nilξƤURLξ֤ޤ
+      ((|nmonth|))nilǤϤʤϡǶNMONTHʬΥå
+      ޤ
       * ƥ꡼
       * ƥ꡼Υ٥(뤤nil)
       * ִʸ
@@ -990,141 +1110,36 @@ end
       * 롼Τʸ
       * 롼פݤΥ
 
---- DispRef2Cache#unknown_urls
-      å夵ƤURLΤִǤʤäΤURL 
-      ֤ޤִǤʤäURL̵ˤ϶֤ޤ
-
---- DispRef2Cache#scan
-      ߤ뤹٤Ƥ顢URLФƥå˵Ͽޤ
-      ִϤޤ
-
 =end
 # cache management
 class DispRef2Cache
 	def initialize( setup )
 		@setup = setup
-	end
-
-	# updates the cache according to the current setup
-	def update
-		return 0 if @setup.secure or @setup['no_cache']
-		db = DispRef2PStore.new( @setup['cache_path'] )
-		r = 0
-		db.transaction do
-			db[Root_DispRef2URL] = Hash.new unless db[Root_DispRef2URL]
-			begin
-				db[Root_DispRef2URL].each_key do |url|
-					ref = DispRef2URL::new( url )
-					t = ref.restore( db )
-					orig = t ? t.dup : nil
-					new = ref.parse( @setup )
-					if orig != new then
-						r += 1
-						ref.store( db )
-					end
-				end
-			rescue PStore::Error
-			end
-		end
-		db = nil
-		r
-	end
-
-	# scan the diary
-	def scan
-		return 0 unless @setup.years
-
-		cgi = CGI::new
-		def cgi.referer; nil; end
-		
-		db = DispRef2PStore.new( @setup['cache_path'] )
-		r = 0
-		db.transaction do
-			db[Root_DispRef2URL] = Hash.new unless db[Root_DispRef2URL]
-			begin
-				@setup.years.each do |y, ms|
-					ms.each do |m|
-						ym = "#{y}#{m}"
-						cgi.params['date'] = [ym]
-						TDiaryMonth.new( cgi, '', @setup.conf ).diaries.each do |ymd, diary|
-							diary.each_referer( diary.count_referers ) do |count, url|
-								unless db[Root_DispRef2URL].has_key?( url ) then
-									db[Root_DispRef2URL][url] = nil
-									r += 1
-								end
-							end
-						end
-					end
-				end
-			rescue PStore::Error
-			end
-		end
-		db = nil
-		r
-	end
-
-	# size of cache in bytes
-	def size
-		return 0 if @setup.secure or @setup['no_cache'] or not FileTest::exist?( @setup['cache_path'] )
-
-		FileTest.size( @setup['cache_path'] )
-	end
-
-	# number of urls in the cache
-	def entries
-		return 0 if @setup.secure or @setup['no_cache'] or not FileTest::exist?( @setup['cache_path'] )
-
-		r = 0
-		db = DispRef2PStore.new( @setup['cache_path'] )
-		db.transaction( true ) do
-			begin
-				r = db[Root_DispRef2URL].size
-			rescue PStore::Error
-				r = 0
-			end
-		end
-		db = nil
-		r
+		@cache = @setup.cache_path
 	end
 
 	# cached urls as a hash
-	def urls( category = nil )
-		return {} if @setup.secure or @setup['no_cache'] or not FileTest::exist?( @setup['cache_path'] )
-
+	def urls( category = nil, nmonth = 2 )
 		h = Hash.new
-		db = DispRef2PStore.new( @setup['cache_path'] )
-		db.transaction( true ) do
-			begin
-				db[Root_DispRef2URL].each_pair do |url, data|
-					h[url] = data if not category or category == data[0]
+    if nmonth then
+			caches = @cache.caches( false ).sort{ |a,b| b<=>a }[0...nmonth]
+		else
+			caches = @cache.caches( false )
+		end
+		caches.each do |path|
+			db = @setup.open_cache( path )
+			db.transaction( true ) do
+				begin
+					db[Root_DispRef2URL].each_pair do |url, data|
+						h[url] = data if not category or category == data[0]
+					end
+				rescue PStore::Error
 				end
-			rescue PStore::Error
 			end
 		end
-		db = nil
 		h
 	end
 
-	# cached unknown urls as an array
-	def unknown_urls
-		return [] if @setup.secure or @setup['no_cache'] or not FileTest::exist?( @setup['cache_path'] )
-
-		r = Array.new
-		db = DispRef2PStore.new( @setup['cache_path'] )
-		db.transaction( true ) do
-			begin
-				db[Root_DispRef2URL].each_pair do |url, data|
-					next if DispRef2String::url_match?( url, @setup.no_referer )
-					next if DispRef2String::url_match?( url, @setup['reflist.ignore_urls'] )
-					r << url if DispRef2URL::Unknown == data[0] or @setup['normal-unknown.title.regexp'] =~ data[2]
-				end
-			rescue PStore::Error
-			end
-		end
-		db = nil
-		r
-	end
-
 end
 
 =begin
@@ -1168,8 +1183,6 @@ class DispRef2SetupIF
 		@conf = conf
 		@conf['disp_referrer2.reflist.ignore_urls'] ||= ''
 		@mode = mode
-		@updated_url = nil
-		@scanned_url = nil
 		@need_cache_update = false
 		if @cgi.params['dr2.change_mode'] and @cgi.params['dr2.change_mode'][0] then
 			case @cgi.params['dr2.new_mode'][0]
@@ -1193,7 +1206,7 @@ class DispRef2SetupIF
 			@current_mode = Options
 		end
 		if not @setup.secure and not @setup['no_cache'] then
-			@cache = DispRef2Cache.new( @setup )
+			@cache = @setup.cache_path
 		else
 			@cache = nil
 		end
@@ -1211,17 +1224,15 @@ class DispRef2SetupIF
 			end
 		end
 
-		# update cache
+		# clear cache
 		if @mode == 'saveconf' and not @setup.secure then
 			if not @setup['no_cache'] then
 				unless @cache then
 					@need_cache_update = true
-					@cache = DispRef2Cache.new( @setup )
+					@cache = @setup.cache_path
 				end
 				if not 'never' == @cgi.params['dr2.cache.update'][0] and ('force' == @cgi.params['dr2.cache.update'][0] or @need_cache_update) then
-					@updated_url = @cache.update
-				elsif 'scan' == @cgi.params['dr2.cache.update'][0] then
-					@scanned_url = @cache.scan
+					@cache.clear
 				end
 			else
 				if @setup['no_cache'] then
@@ -1250,19 +1261,17 @@ class DispRef2SetupIF
 			r << Disp_referrer2_without_Nora
 		end
 		if @cache then
-			r << sprintf( Disp_referrer2_scanned_urls, @scanned_url ) if @scanned_url
-			r << sprintf( Disp_referrer2_updated_urls, @updated_url ) if @updated_url
-			r << sprintf( Disp_referrer2_cache_info, DispRef2String::bytes( @cache.size ), DispRef2String::comma( @cache.entries ) )
-			r << sprintf( Disp_referrer2_update_info, "#{@conf.update}?conf=referer" )
+			r << sprintf( Disp_referrer2_cache_info, DispRef2String::bytes( @cache.size ) )
+			r << sprintf( Disp_referrer2_update_info, "#{DispRef2String::escapeHTML(@conf.update)}?conf=referer" )
 		end
 		r << "<p>\n"
 		case @current_mode
 		when Options
-			r << sprintf( Disp_referrer2_move_to_refererlist, "#{@conf.update}?conf=disp_referrer2;dr2.new_mode=#{RefList};dr2.change_mode=true" )
+			r << sprintf( Disp_referrer2_move_to_refererlist, "#{DispRef2String::escapeHTML(@conf.update)}?conf=disp_referrer2;dr2.new_mode=#{RefList};dr2.change_mode=true" )
 		when RefList
-			r << sprintf( Disp_referrer2_move_to_config, "#{@conf.update}?conf=disp_referrer2;dr2.new_mode=#{Options};dr2.change_mode=true" )
+			r << sprintf( Disp_referrer2_move_to_config, "#{DispRef2String::escapeHTML(@conf.update)}?conf=disp_referrer2;dr2.new_mode=#{Options};dr2.change_mode=true" )
 		end
-		r << sprintf( Disp_referrer2_also_todayslink, "#{@conf.update}?conf=referer" )
+		r << sprintf( Disp_referrer2_also_todayslink, "#{DispRef2String::escapeHTML(@conf.update)}?conf=referer" )
 		r << %Q{<input type="hidden" name="saveconf" value="ok"></p><hr>\n}
 		r
 	end
@@ -1293,6 +1302,24 @@ class DispRef2SetupIF
 			end
 		end
 
+		# numeric options
+		%w( cache_max_size ).each do |key|
+			tdiarykey = 'disp_referrer2.' + key
+			v = @cgi.params['dr2.' + key][0]
+			next unless v
+			f = 1
+			if v.gsub!( /M\Z/, '' ) then
+				f = 1024*1024
+			elsif v.gsub!( /K\Z/, '' ) then
+				f = 1024
+			end
+			if /\A\d+\Z/ =~ v then
+				@conf[tdiarykey] = v.to_i * f
+				@need_cache_update = true if DispRef2URL::Cached_options.include?( key )
+				dirty = true
+			end
+		end
+
 		# update @setup
 		@setup.update! if dirty
 	end
@@ -1330,7 +1357,7 @@ class DispRef2SetupIF
 					unless @cgi.params["dr2.#{i}.reg"][0].empty? then
 						reg = @setup.to_native( @cgi.params["dr2.#{i}.reg"][0] ).strip
 						unless reg.empty? then
-							@conf['disp_referrer2.reflist.ignore_urls'] << reg + "\n"
+							@conf['disp_referrer2.reflist.ignore_urls'] = @conf['disp_referrer2.reflist.ignore_urls'].split( /\n/ ).push( reg ).uniq.join( "\n" )
 							dirty = true
 						end
 					end
@@ -1385,7 +1412,7 @@ class DispRef2Latest < TDiary::TDiaryLatest
 		@setup = setup
 	end
 
-	# correct unknown URLs from the newest diaries
+	# collect unknown URLs from the newest diaries
 	def unknown_urls
 		r = Array.new
 		self.latest( @conf.latest_limit ) do |diary|
@@ -1394,13 +1421,11 @@ class DispRef2Latest < TDiary::TDiaryLatest
 			h.each_key do |url|
 				next unless @setup['normal-unknown.title.regexp'] =~ h[url][2]
 				next if DispRef2String::url_match?( url, @setup.no_referer )
-				next if DispRef2String::url_match?( url, @setup['reflist.ignore_urls'] )
 				r << url
 			end
 			h = nil
 			refs.urls( DispRef2URL::Unknown ).each_key do |url|
 				next if DispRef2String::url_match?( url, @setup.no_referer )
-				next if DispRef2String::url_match?( url, @setup['reflist.ignore_urls'] )
 				r << url
 			end
 		end
@@ -1421,8 +1446,8 @@ end
 =end
 
 # for configuration interface
-add_conf_proc( 'disp_referrer2', Disp_referrer2_name ) do
-	setup = DispRef2Setup.new( @conf, 100, true, @years )
+add_conf_proc( 'disp_referrer2', Disp_referrer2_name, 'referer' ) do
+	setup = DispRef2Setup.new( @conf, 100, true, @years, @mode )
 	wwwif = DispRef2SetupIF.new( @cgi, setup, @conf, @mode )
 	wwwif.show_html
 end
@@ -1430,18 +1455,22 @@ end
 # for one-day diary
 def referer_of_today_long( diary, limit = 100 )
 	return '' if bot?
-	setup = DispRef2Setup.new( @conf, limit, true )
-	DispRef2Refs.new( diary, setup ).to_long_html
+	setup = DispRef2Setup.new( @conf, limit, true, nil, @mode )
+	r = ''
+	r << DispRef2Refs.new( diary, setup ).to_long_html( referer_today )
+	r << DispRef2Refs.new( @referer_volatile, setup ).to_long_html( volatile_referer ) if @referer_volatile and latest_day?( diary )
+	setup.cache_path.shrink
+	r
 end
 
 # for newest diary
-alias dispref2_original_referer_of_today_short referer_of_today_short
-def referer_of_today_short( diary, limit = 10 )
-	return '' if bot?
-	return dispref2_original_referer_of_today_short( diary, limit ) if @options.has_key?( 'disp_referrer2.short.only_normal' ) and not @options['disp_referrer2.short.only_normal']
-	setup = DispRef2Setup.new( @conf, limit, false )
-	DispRef2Refs.new( diary, setup ).to_short_html
-end
+#alias dispref2_original_referer_of_today_short referer_of_today_short
+#def referer_of_today_short( diary, limit = 10 )
+#	return '' if bot?
+#	return dispref2_original_referer_of_today_short( diary, limit ) if @options.has_key?( 'disp_referrer2.short.only_normal' ) and not @options['disp_referrer2.short.only_normal']
+#	setup = DispRef2Setup.new( @conf, limit, false, nil, @mode )
+#	DispRef2Refs.new( diary, setup ).to_short_html
+#end
 
 # we have to know the unknown urls at this moment in a secure diary
 if @conf.secure and (\
@@ -1450,7 +1479,7 @@ if @conf.secure and (\
 		or ( @cgi.params['dr2.current_mode'] \
 		and DispRef2SetupIF::RefList == @cgi.params['dr2.current_mode'][0] ) )
 then
-	setup = DispRef2Setup.new( @conf, 100, true )
+	setup = DispRef2Setup.new( @conf, 100, true, @mode )
 	DispRef2Latest_cache = DispRef2Latest.new( @cgi, 'latest.rhtml', @conf, setup )
 else
 	DispRef2Latest_cache = nil
