@@ -1,4 +1,4 @@
-# ja/category.rb $Revision: 1.7.2.1 $
+# ja/category.rb $Revision: 1.13 $
 #
 # Copyright (c) 2004 Junichiro KITA <kita@kitaj.no-ip.com>
 # Distributed under the GPL
@@ -22,18 +22,18 @@ def category_title
 	end
 	period = " (#{period})" if period
 
-	"[#{CGI.escapeHTML(info.category.join('|'))}#{period}]"
+	"[#{info.category.join('|')}#{period}]"
 end
 
 def category_init_local
-	@conf['category.prev_year'] ||= '&laquo;($1)'
-	@conf['category.next_year'] ||= '($1)&raquo;'
-	@conf['category.prev_half'] ||= '&laquo;($1-$2)'
-	@conf['category.next_half'] ||= '($1-$2)&raquo;'
-	@conf['category.prev_quarter'] ||= '&laquo;($1-$2)'
-	@conf['category.next_quarter'] ||= '($1-$2)&raquo;'
-	@conf['category.prev_month'] ||= '&laquo;($1-$2)'
-	@conf['category.next_month'] ||= '($1-$2)&raquo;'
+	@conf['category.prev_year'] ||= '<< ($1)'
+	@conf['category.next_year'] ||= '($1) >>'
+	@conf['category.prev_half'] ||= '<< ($1-$2)'
+	@conf['category.next_half'] ||= '($1-$2) >>'
+	@conf['category.prev_quarter'] ||= '<< ($1-$2)'
+	@conf['category.next_quarter'] ||= '($1-$2) >>'
+	@conf['category.prev_month'] ||= '<< ($1-$2)'
+	@conf['category.next_month'] ||= '($1-$2) >>'
 	@conf['category.this_year'] ||= 'this year'
 	@conf['category.this_half'] ||= 'this half'
 	@conf['category.this_quarter'] ||= 'this quarter'
@@ -52,9 +52,9 @@ def category_conf_html
 To use the category feature, you should create category index.
 Check the box below to create category index.
 </p>
-<p>
-<input type="checkbox" name="category_initialize" value="1">Rebuild category Index
-</p>
+<p><label for="category_initialize">
+<input type="checkbox" id="category_initialize" name="category_initialize" value="1">Rebuild category Index
+</label></p>
 <p>
 It takes several or several tens of second to create it.
 </p>
@@ -70,20 +70,6 @@ Category names can be shown under the 'Article' form.
 </select>
 </p>
 
-<h3 class="subtitle">Header</h3>
-<p>
-This text is inserted into top of category view.
-"&lt;%= category_navi %&gt;" genaretes navigation buttons for category, 
-and "&lt;%= category_list %&gt;" lists all category names.
-You can use plugins and write any HTML tags.
-</p>
-
-<p>Header 1: inserted under the navigtion buttons.</p>
-<textarea name="category.header1" cols="70" rows="8">#{CGI.escapeHTML(@conf['category.header1'])}</textarea>
-
-<p>Header 2: inserted under the &lt;H1&gt;.</p>
-<p><textarea name="category.header2" cols="70" rows="8">#{CGI.escapeHTML(@conf['category.header2'])}</textarea></p>
-
 <h3 class="subtitle">Default period</h3>
 <p>
 Specify the default display period for category view.
@@ -105,6 +91,22 @@ HTML
 	r << <<HTML
 </select></p>
 
+<h3 class="subtitle">Header</h3>
+<p>
+This text is inserted into top of category view.
+"&lt;%= category_navi %&gt;" genaretes navigation buttons for category, 
+and "&lt;%= category_list %&gt;" lists all category names.
+You can use plugins and write any HTML tags.
+</p>
+
+<h4>Header 1</h4>
+<p>Inserted under the navigtion buttons.</p>
+<p><textarea name="category.header1" cols="60" rows="8">#{h @conf['category.header1']}</textarea></p>
+
+<h4>Header 2</h4>
+<p>Inserted under the &lt;H1&gt;.</p>
+<p><textarea name="category.header2" cols="60" rows="8">#{h @conf['category.header2']}</textarea></p>
+
 <h3 class="subtitle">Button labels</h3>
 <p>
 Specify button labels.
@@ -133,8 +135,8 @@ HTML
 		r << <<HTML
 <tr>
 	<td>#{button}</td>
-	<td><input type="text" name="#{name}" value="#{CGI.escapeHTML(@conf[name])}" size="30"></td>
-	<td><p><span class="adminmenu"><a>#{@conf[name].sub(/\$1/, "2004").sub(/\$2/, "2")}</a></span></p></td>
+	<td><input type="text" name="#{name}" value="#{h @conf[name]}" size="30"></td>
+	<td><p><span class="adminmenu"><a>#{@conf[name].sub(/\$1/, "2007").sub(/\$2/, "2")}</a></span></p></td>
 </tr>
 HTML
 	end
@@ -156,9 +158,9 @@ Specify the directory and url of category icons.
 <p>
 <dl>
 <dt>Directory:</dt>
-<dd><input name="category.icon_dir" value="#{@category_icon_dir}" size="30"></dd>
+<dd><input name="category.icon_dir" value="#{h @category_icon_dir}" size="30"></dd>
 <dt>URL:</dt>
-<dd><input name="category.icon_url" value="#{@category_icon_url}" size="30"></dd>
+<dd><input name="category.icon_url" value="#{h @category_icon_url}" size="30"></dd>
 </dl>
 </p>
 <hr>
@@ -169,7 +171,7 @@ HTML
 	@categories.each do |c|
 		str << %Q|\t<tr>\n\t\t<td>#{c}</td>\n\t\t<td>\n|
 		str << category_icon_select(c)
-		str << %Q|<img src="#{@category_icon_url}#{@category_icon[c]}">| if @category_icon[c]
+		str << %Q|<img src="#{h @category_icon_url}#{h @category_icon[c]}">| if @category_icon[c]
 		str << %Q|</td>\n\t</tr>\n|
 	end
 	<<HTML
