@@ -1,5 +1,5 @@
 =begin
-= A little bit more powerful display of referrers((-$Id: disp_referrer.rb,v 1.9 2004/06/12 10:45:28 zunda Exp $-))
+= A little bit more powerful display of referrers((-$Id: disp_referrer.rb,v 1.19 2007/12/07 13:34:17 zunda Exp $-))
 English resource
 
 == Copyright notice
@@ -69,26 +69,22 @@ Disp_referrer2_with_Nora = <<'_END'.taint
 </p>
 _END
 Disp_referrer2_without_Nora = <<'_END'.taint
-<p>
+<!-- p>
 	Please install the 
-	<a href="http://raa.ruby-lang.org/list.rhtml?name=Nora">Nora</a>
-	library if you feel the pages show too slowly.
-</p>
-_END
-Disp_referrer2_scanned_urls = <<-'_END'.taint
-<p>%d URL(s) in the diary are added to the cache.</p>
-_END
-Disp_referrer2_updated_urls = <<-'_END'.taint
-<p>%d URL(s) in the cache are updated.</p>
+	<a href="http://www.moonwolf.com/ruby/archive/nora-20040830.tar.gz">Nora
+	library</a> if you feel the pages show too slowly.
+</p -->
 _END
 Disp_referrer2_cache_info = <<'_END'.taint
 <p>
-	The cache has %2$s URL(s) in %1$s byte(s).
+	Total size of the caches is %1$s byte(s).
 </p>
 _END
 Disp_referrer2_update_info = <<'_END'.taint
 <p>
-	Please <a href="%2$s">update the cache</a>
+	Please clear the cache by checking this box:
+  <label for="dr2.cache.update"><input id="dr2.cache.update" name="dr2.cache.update" value="force" type="checkbox">clear the cache</label>,
+	and clicking OK
 	after editing the <a href="%1$s">today's link</a> lists.
 </p>
 _END
@@ -116,54 +112,54 @@ class DispRef2SetupIF
 			<input name="dr2.current_mode" value="#{Options}" type="hidden">
 			<table>
 			<tr>
-				<td><input name="dr2.unknown.divide" value="true" type="radio"#{' checked'if @setup['unknown.divide']}>Separate #{@setup['unknown.label']}
-				<td><input name="dr2.unknown.divide" value="false" type="radio"#{' checked'if not @setup['unknown.divide']}>Treat #{@setup['unknown.label']} as normal links.
+				<td><label for="dr2.unknown.divide.true"><input id="dr2.unknown.divide.true" name="dr2.unknown.divide" value="true" type="radio"#{' checked'if @setup['unknown.divide']}>Separate #{DispRef2String::escapeHTML(@setup['unknown.label'])}</label>
+				<td><label for="dr2.unknown.divide.false"><input id="dr2.unknown.divide.false" name="dr2.unknown.divide" value="false" type="radio"#{' checked'if not @setup['unknown.divide']}>Treat #{DispRef2String::escapeHTML(@setup['unknown.label'])}</label> as normal links.
 			</table>
 			<table>
 			<tr>
-				<td><input name="dr2.unknown.hide" value="false" type="radio"#{' checked'if not @setup['unknown.hide']}>Show
-				<td><input name="dr2.unknown.hide" value="true" type="radio"#{' checked'if @setup['unknown.hide']}>Hide
-				separated #{@setup['unknown.label']}.
+				<td><label for="dr2.unknown.hide.false"><input id="dr2.unknown.hide.false" name="dr2.unknown.hide" value="false" type="radio"#{' checked'if not @setup['unknown.hide']}>Show</label>
+				<td><label for="dr2.unknown.hide.true"><input id="dr2.unknown.hide.true" name="dr2.unknown.hide" value="true" type="radio"#{' checked'if @setup['unknown.hide']}>Hide</label>
+				separated #{DispRef2String::escapeHTML(@setup['unknown.label'])}.
 			<tr>
-				<td><input name="dr2.normal.categorize" value="true" type="radio"#{' checked'if @setup['normal.categorize']}>Use
-				<td><input name="dr2.normal.categorize" value="false" type="radio"#{' checked'if not @setup['normal.categorize']}>Don't use
+				<td><label for="dr2.normal.categorize.true"><input id="dr2.normal.categorize.true" name="dr2.normal.categorize" value="true" type="radio"#{' checked'if @setup['normal.categorize']}>Use</label>
+				<td><label for="dr2.normal.categorize.false"><input id="dr2.normal.categorize.false" name="dr2.normal.categorize" value="false" type="radio"#{' checked'if not @setup['normal.categorize']}>Don't use</label>
 				strings inside [ and ] to categorize normal links.
 			<tr>
-				<td><input name="dr2.long.only_normal" value="false" type="radio"#{' checked'if not @setup['long.only_normal']}>Show
-				<td><input name="dr2.long.only_normal" value="true" type="radio"#{' checked'if @setup['long.only_normal']}>Hide
+				<td><label for="dr2.long.only_normal.false"><input id="dr2.long.only_normal.false" name="dr2.long.only_normal" value="false" type="radio"#{' checked'if not @setup['long.only_normal']}>Show</label>
+				<td><label for="dr2.long.only_normal.true"><input id="dr2.long.only_normal.true" name="dr2.long.only_normal" value="true" type="radio"#{' checked'if @setup['long.only_normal']}>Hide</label>
 				links other than normal URLs in the daily view.
 			<tr>
-				<td><input name="dr2.short.only_normal" value="false" type="radio"#{' checked'if not @setup['short.only_normal']}>Show
-				<td><input name="dr2.short.only_normal" value="true" type="radio"#{' checked'if @setup['short.only_normal']}>Hide
+				<td><label for="dr2.short.only_normal.false"><input id="dr2.short.only_normal.false" name="dr2.short.only_normal" value="false" type="radio"#{' checked'if not @setup['short.only_normal']}>Show</label>
+				<td><label for="dr2.short.only_normal.true"><input id="dr2.short.only_normal.true" name="dr2.short.only_normal" value="true" type="radio"#{' checked'if @setup['short.only_normal']}>Hide</label>
 				links other than normal URLs in the latest view.
 			</table>
 			<h3>Grouping of normal links</h3>
 			<table>
 			<tr>
-				<td><input name="dr2.normal.group" value="true" type="radio"#{' checked'if @setup['normal.group']}>Group with the title strings
-				<td><input name="dr2.normal.group" value="false" type="radio"#{' checked'if not @setup['normal.group']}>Show each URLs
+				<td><label for="dr2.normal.group.true"><input id="dr2.normal.group.true" name="dr2.normal.group" value="true" type="radio"#{' checked'if @setup['normal.group']}>Group with the title strings</label>
+				<td><label for="dr2.normal.group.false"><input id="dr2.normal.group.false" name="dr2.normal.group" value="false" type="radio"#{' checked'if not @setup['normal.group']}>Show each URLs</label>
 				of normal links.
 			<tr>
-				<td><input name="dr2.normal.ignore_parenthesis" value="true" type="radio"#{' checked'if @setup['normal.ignore_parenthesis']}>Ignore
-				<td><input name="dr2.normal.ignore_parenthesis" value="false" type="radio"#{' checked'if not @setup['normal.ignore_parenthesis']}>don't ignore
+				<td><label for="dr2.normal.ignore_parenthesis.true"><input id="dr2.normal.ignore_parenthesis.true" name="dr2.normal.ignore_parenthesis" value="true" type="radio"#{' checked'if @setup['normal.ignore_parenthesis']}>Ignore</label>
+				<td><label for="dr2.normal.ignore_parenthesis.false"><input id="dr2.normal.ignore_parenthesis.false" name="dr2.normal.ignore_parenthesis" value="false" type="radio"#{' checked'if not @setup['normal.ignore_parenthesis']}>don't ignore</label>
 				the last parenthesis when grouping normal links with the titles.
 			</table>
 			<h3>Grouping of links from antennae</h3>
 			<table>
 			<tr>
-				<td><input name="dr2.antenna.group" value="true" type="radio"#{' checked'if @setup['antenna.group']}>Group with the title strings
-				<td><input name="dr2.antenna.group" value="false" type="radio"#{' checked'if not @setup['antenna.group']}>Show each URLs
+				<td><label for="dr2.antenna.group.true"><input id="dr2.antenna.group.true" name="dr2.antenna.group" value="true" type="radio"#{' checked'if @setup['antenna.group']}>Group with the title strings</label>
+				<td><label for="dr2.antenna.group.false"><input id="dr2.antenna.group.false" name="dr2.antenna.group" value="false" type="radio"#{' checked'if not @setup['antenna.group']}>Show each URLs</label>
 				of links from antennae.
 			<tr>
-				<td><input name="dr2.antenna.ignore_parenthesis" value="true" type="radio"#{' checked'if @setup['antenna.ignore_parenthesis']}>ignore
-				<td><input name="dr2.antenna.ignore_parenthesis" value="false" type="radio"#{' checked'if not @setup['antenna.ignore_parenthesis']}>don't ignore
+				<td><label for="dr2.antenna.ignore_parenthesis.true"><input id="dr2.antenna.ignore_parenthesis.true" name="dr2.antenna.ignore_parenthesis" value="true" type="radio"#{' checked'if @setup['antenna.ignore_parenthesis']}>ignore</labe>
+				<td><label for="dr2.antenna.ignore_parenthesis.false"><input id="dr2.antenna.ignore_parenthesis.false" name="dr2.antenna.ignore_parenthesis" value="false" type="radio"#{' checked'if not @setup['antenna.ignore_parenthesis']}>don't ignore</labe>
 				the last parenthesis when grouping links from antennae with the titles.
 			</table>
 			<h3>Keywords from search engines</h3>
 			<table>
 			<tr>
-				<td><input name="dr2.search.expand" value="true" type="radio"#{' checked'if @setup['search.expand']}>Show
-				<td><input name="dr2.search.expand" value="false" type="radio"#{' checked'if not @setup['search.expand']}>Don't show
+				<td><label for="dr2.search.expand.true"><input id="dr2.search.expand.true" name="dr2.search.expand" value="true" type="radio"#{' checked'if @setup['search.expand']}>Show</label>
+				<td><Label for="dr2.search.expand.false"><input id="dr2.search.expand.false" name="dr2.search.expand" value="false" type="radio"#{' checked'if not @setup['search.expand']}>Don't show</label>
 				the search engine names.
 			</table>
 		_HTML
@@ -172,23 +168,19 @@ class DispRef2SetupIF
 			<h3>Cache</h3>
 			<table>
 			<tr>
-				<td><input name="dr2.no_cache" value="false" type="radio"#{' checked'if not @setup['no_cache']}>Use
-				<td><input name="dr2.no_cache" value="true" type="radio"#{' checked'if @setup['no_cache']}>Don't use
+				<td><label for="dr2.no_cache.false"><input id="dr2.no_cache.false" name="dr2.no_cache" value="false" type="radio"#{' checked'if not @setup['no_cache']}>Use</label>
+				<td><label for="dr2.no_cache.true"><input id="dr2.no_cache.true" name="dr2.no_cache" value="true" type="radio"#{' checked'if @setup['no_cache']}>Don't use</label>
 				cache.
-			</table>
-			<table>
 			<tr>
-				<td><input name="dr2.cache.update" value="force" type="radio">update
-				<td><input name="dr2.cache.update" value="auto" type="radio" checked>update if needed
-				<td><input name="dr2.cache.update" value="never" type="radio">don't update
+				<td>Limit cache size to
+				<td colspan="3"><input name="dr2.cache_max_size" value="#{DispRef2String::escapeHTML(@setup['cache_max_size'])}" type="text">Bytes.
+			<tr>
+				<td><label for="dr2.cache.update.force"><input id="dr2.cache.update.force" name="dr2.cache.update" value="force" type="radio">clear</label>
+				<td><label for="dr2.cache.update.auto"><input id="dr2.cache.update.auto" name="dr2.cache.update" value="auto" type="radio" checked>clear if needed</label>
+				<td><label for="dr2.cache.update.never"><input id="dr2.cache.update.never" name="dr2.cache.update" value="never" type="radio">don't clear</label>
 				the cache at this time.
 			</table>
-			<p>
-				Updating the cache sometimes takes time.
-				Please wait after clicking the OK button.
-				On the other hand, referrers might not shown correctly when
-				the cache is not updated.
-			</p>
+			<p>Cache size limit is an approximation. There is a chance that the cache size is bigger than the configured value. Setting the limit to zero disalbes limitation. K or M can be suffixed meaning Kbytes or Mbytes.</p>
 		_HTML
 		end # unless @setup.secure
 		r
@@ -197,25 +189,18 @@ class DispRef2SetupIF
 	# shows URL list to be added to the referer_table or no_referer
 	def show_unknown_list
 		if @setup.secure then
-			urls = DispRef2Latest_cache.unknown_urls
-		elsif @setup['no_cache'] then
 			urls = DispRef2Latest.new( @cgi, 'latest.rhtml', @conf, @setup ).unknown_urls
 		else
-			urls = DispRef2Cache.new( @setup ).unknown_urls
+			urls = DispRef2Cache.new( @setup ).urls( DispRef2URL::Unknown ).keys
+			if urls.size == 0 then
+				urls = DispRef2Latest.new( @cgi, 'latest.rhtml', @conf, @setup ).unknown_urls
+			end
 		end
+		urls.reject!{ |url| DispRef2String::url_match?( url, @setup['reflist.ignore_urls'] ) }
 		r = <<-_HTML
 			<h3>URL Conversion</h3>
 			<input name="dr2.current_mode" value="#{RefList}" type="hidden">
-		_HTML
-		if @cache then
-			r << "<p>Picking up #{@setup['unknown.label']} from the cache."
-		else
-			r << "<p>Picking up #{@setup['unknown.label']} from the latest view."
-		end
-		r << <<-_HTML
-			URLs that match the Excluding list or the Ignore list are not
-			listed here.
-		</p>
+			<p>URLs that match the Ignore list are not listed here.</p>
 		<p>
 			If you don't want to see the URLs that you neither put into the
 			Conversion list or the Excluding list can be put in the Ignore
@@ -242,7 +227,7 @@ class DispRef2SetupIF
 					a script fragment like &quot;sprintf('[tdiary:%d]', $1.to_i+1)&quot;.
 				</p>
 			_HTML
-			if ENV['AUTH_TYPE'] and ENV['REMOTE_USER'] and @setup['configure.use_link'] then
+			if @cgi.auth_type and @cgi.remote_user and @setup['configure.use_link'] then
 				r << <<-_HTML
 					<p>
 						[NOTE] Be aware that by clicking the URLs below, the author
@@ -254,23 +239,23 @@ class DispRef2SetupIF
 			r << <<-_HTML
 				<p>
 					Please edit URLs not shown here through &quot;<a
-					href="#{@conf.update}?conf=referer">Today's link</a>&quot;
+					href="#{DispRef2String::escapeHTML(@conf.update)}?conf=referer">Today's link</a>&quot;
 				</p>
 				<dl>
 			_HTML
 			i = 0
 			urls.sort.each do |url|
 				shown_url = DispRef2String::escapeHTML( @setup.to_native( DispRef2String::unescape( url ) ) )
-				if ENV['AUTH_TYPE'] and ENV['REMOTE_USER'] and @setup['configure.use_link'] then
-					r << "<dt><a href=\"#{url}\">#{shown_url}</a>"
+				if @cgi.auth_type and @cgi.remote_user and @setup['configure.use_link'] then
+					r << "<dt><a href=\"#{DispRef2String::escapeHTML(url)}\">#{shown_url}</a>"
 				else
 					r << "<dt>#{shown_url}"
 				end
 				r << <<-_HTML
 					<dd>
 						Add this URL to
-						<input name="dr2.#{i}.noref" value="true" type="checkbox">Excluding list
-						<input name="dr2.#{i}.ignore" value="true" type="checkbox">Ignore list<br>
+						<label for="dr2.#{i}.noref"><input id="dr2.#{i}.noref" name="dr2.#{i}.noref" value="true" type="checkbox">Excluding list</label>
+						<label for="dr2.#{i}.ignore"><input id="dr2.#{i}.ignore" name="dr2.#{i}.ignore" value="true" type="checkbox">Ignore list</label><br>
 						<input name="dr2.#{i}.reg" value="#{DispRef2String::escapeHTML( DispRef2String::url_regexp( url ) )}" type="text" size="70"><br>
 						<input name="dr2.#{i}.title" value="" type="text" size="70">
 				_HTML
@@ -280,17 +265,9 @@ class DispRef2SetupIF
 				<input name="dr2.urls" type="hidden" value="#{i}">
 				</dl>
 			_HTML
-			unless @setup.secure or @setup['no_cache'] then
-				r << <<-_HTML
-					<p>
-						Updating the cache might take some time. Please wait after
-						clicking the OK button.
-					</p>
-				_HTML
-			end
 		else
 			r << <<-_HTML
-				<p>Currently there is no #{@setup['unknown.label']}.</p>
+				<p>Currently there is no #{DispRef2String::escapeHTML(@setup['unknown.label'])}.</p>
 			_HTML
 		end
 		r << <<-_HTML
@@ -300,9 +277,9 @@ class DispRef2SetupIF
 			<ul>
 			<li>URL:
 				<input name="dr2.antenna.url" value="#{DispRef2String::escapeHTML( @setup.to_native( @setup['antenna.url'] ) )}" type="text" size="70">
-				<input name="dr2.antenna.url.default" value="true" type="checkbox">Use default
+				<label for="dr2.antenna.url.default"><input id="dr2.antenna.url.default" name="dr2.antenna.url.default" value="true" type="checkbox">Use default</label>
 			<li>Title:<input name="dr2.antenna.title" value="#{DispRef2String::escapeHTML( @setup.to_native( @setup['antenna.title'] ) )}" type="text" size="70">
-				<input name="dr2.antenna.title.default" value="true" type="checkbox">Use default
+				<label for="dr2.antenna.title.default"><input id="dr2.antenna.title.default" name="dr2.antenna.title.default" value="true" type="checkbox">Use default</label>
 			</ul>
 			_HTML
 		r
@@ -314,6 +291,9 @@ end
 # key: company name
 # value: array of:
 # [0]:url regexp [1]:title [2]:keys for search keyword [3]:cache regexp
+# keys - an Array of Strings for usual keys
+#      - a String as a Ruby code to be sent to URL after regexp matching
+#      - a Symbol to indicate the key contains URL to be recursively converted
 DispReferrer2_Google_cache = /cache:[^:]+:([^+]+)+/
 DispReferrer2_Engines = {
 	'google' => [
