@@ -1,5 +1,5 @@
 =begin
-= Weather-of-today plugin((-$Id: weather.rb,v 1.2 2003/11/25 12:41:52 zunda Exp $-))
+= Weather-of-today plugin((-$Id: weather.rb,v 1.9 2008/01/19 10:23:55 zunda Exp $-))
 Records the weather when the diary is first updated for the date and
 displays it.
 
@@ -36,6 +36,7 @@ We want Japanese displayed in a diary written in Japanese.
     given string. No translations are defined for English. Please see an
 		example in the Japanese resource.
 =end
+require 'erb'
 
 class Weather
 	Words_en = []
@@ -53,31 +54,32 @@ Weather of a date.
       Returns a CHTML fragment to be shown on a mobile browser.
 =end
 class Weather
+	include ERB::Util
 
 	def error_html_string
-		%Q|#{HTML_START}Weather error:<a href="#{@url}">#{CGI::escapeHTML( @error )}</a>#{HTML_END}|
+		%Q|<span class="weather">Weather error:<a href="#{h(@url)}">#{h( @error )}</a></span>|
 	end
 
 	# edit this method to define how you show the weather
 	def html_string
-		r = "#{HTML_START}"
+		r = '<span class="weather">'
 
 		# weather
-		r << %Q|<a href="#{@url}">|
+		r << %Q|<a href="#{h(@url)}">|
 		has_condition = false
 		if @data['weather'] then
-			r << CGI::escapeHTML( WeatherTranslator::S.new( @data['weather']).translate( Words_en ).compact.capitalize )
+			r << %Q|<span class="weather">#{h( WeatherTranslator::S.new( @data['weather']).translate( Words_en ).compact.capitalize )}</span>|
 			has_condition = true
 		elsif @data['condition'] then
-			r << CGI::escapeHTML( WeatherTranslator::S.new( @data['condition']).translate( Words_en ).compact.capitalize )
+			r << %Q|<span class="condition">#{h( WeatherTranslator::S.new( @data['condition']).translate( Words_en ).compact.capitalize )}</span>|
 			has_condition = true
 		end
 
 		# temperature
 		if @data['temperature(C)'] and t = @data['temperature(C)'].scan(/-?[\d.]+/)[-1] then
 			r << ', ' if has_condition
-			r << %Q| #{sprintf( '%.0f', 9.0/5.0 * t.to_f + 32.0 )} deg-F|
-			#r << %Q| #{sprintf( '%.0f', t )} deg-C|
+			r << %Q| <span class="temperature">#{sprintf( '%.0f', 9.0/5.0 * t.to_f + 32.0 )} deg-F</span>|
+			#r << %Q| <span class="temperature">#{sprintf( '%.0f', t )} deg-C</span>|
 		end
 		r << '</a>'
 
@@ -96,7 +98,7 @@ class Weather
 			ENV['TZ'] = tzbak
 		end
 
-		r << "#{HTML_END}\n"
+		r << "</span>"
 	end
 
 	# edit this method to define how you show the weather for a mobile agent
@@ -105,15 +107,13 @@ class Weather
 
 		# weather
 		if @data['weather'] then
-			r << "#{I_HTML_START}"
-			r << %Q|<A HREF="#{@url}">|
-			r << CGI::escapeHTML( WeatherTranslator::S.new( @data['weather']).translate( Words_en ).compact.capitalize )
-			r << "</A>#{I_HTML_END}\n"
+			r << %Q|<A HREF="#{u(@url)}">|
+			r << h( WeatherTranslator::S.new( @data['weather']).translate( Words_en ).compact.capitalize )
+			r << "</A>"
 		elsif @data['condition'] then
-			r << "#{I_HTML_START}"
-			r << %Q|<A HREF="#{@url}">|
-			r << CGI::escapeHTML( WeatherTranslator::S.new( @data['condition']).translate( Words_en ).compact.capitalize )
-			r << "</A>#{I_HTML_END}\n"
+			r << %Q|<A HREF="#{u(@url)}">|
+			r << h( WeatherTranslator::S.new( @data['condition']).translate( Words_en ).compact.capitalize )
+			r << "</A>"
 		end
 
 	end
@@ -141,6 +141,14 @@ def weather_configure_html( conf )
 		file in the directory tdiary.rb is: e.g. ENV['TZ'] = 'US/Pacific',
 		or write it down the box below.</p>
 	<p><input name="weather.tz" value="#{conf['weather.tz']}"></p>
+	<h4>Display on a normal browser</h4>
+	<p>Select from below:</p>
+	<p><select name="weather.in_title">
+		<option value="false"#{' selected'unless conf['weather.in_title']}>
+		Show weather above text
+		<option value="true"#{' selected'if conf['weather.in_title']}>
+		Show weather at right of title
+	</select></p>
 	<h4>Display on a mobile browser</h4>
 	<p>Select from below:</p>
 	<p><select name="weather.show_mobile">
@@ -149,6 +157,14 @@ def weather_configure_html( conf )
 		<option value="false"#{' selected'unless conf['weather.show_mobile']}>
 		Do not show the weather on a mobile browser.
 	</select></p>
+	<h4>Display to search engine robots</h4>
+	<p>Select from below:</p>
+	<p><select name="weather.show_robot">
+		<option value="true"#{' selected'if conf['weather.show_robot']}>
+		Let robots know the weather.
+		<option value="false"#{' selected'unless conf['weather.show_robot']}>
+		Hide the weather from robots.
+	</select></p>
 	<h4>Other configurations</h4>
 	<p>Other options can be configured by means of the tdiary.conf file.
 		Please have a look in the plugin file: weather.rb if you want.</p>
