@@ -1,4 +1,4 @@
-# gradation.rb $Revision: 1.1 $
+# gradation.rb $Revision: 1.3 $
 #
 # gradation.rb: ʸ򥰥ǡɽ
 #   ѥ᥿:
@@ -6,10 +6,8 @@
 #     first_color: ǡ󳫻Ͽ(16 6)
 #     last_color:  ǡλ(16 6)
 #
-# Copyright (C) 2002 by zoe <http://www.kasumi.sakura.ne.jp/~zoe/tdiary/>
-#
-# Original: http://www.kasumi.sakura.ne.jp/~zoe/tdiary/?date=20011229#p07
-# Modified: by TADA Tadashi <http://sho.tdiary.net/>
+# Copyright (c) 2002 TADA Tadashi <sho@spc.gr.jp>
+# You can distribute this file under the GPL2.
 #
 def gradation( str, first_color, last_color )
 	ary = str.split( // )
@@ -23,7 +21,7 @@ def gradation( str, first_color, last_color )
 	bd = ((last_color[4..5].hex - b)/len)
 	ary.each do |x|
 		c = sprintf( '%02x%02x%02x', r, g, b )
-		result << %Q[<span style="color: ##{c}">#{x}</span>]
+		result << %Q[<span style="color: ##{c}">#{h x}</span>]
 		r += rd
 		g += gd
 		b += bd
