@@ -1,4 +1,4 @@
-# gradient.rb $Revision: 1.1.4.1 $
+# gradient.rb $Revision: 1.3 $
 #
 # gradient.rb: ʸ礭Ѳʤɽ
 #   ѥ᥿:
@@ -9,8 +9,8 @@
 #   : ֤ʤȤǤޤפ10pt30pt˳
 #     <%=gradient 'ʤȤǤޤ', 10, 30 %>
 #
-# Copyright (C) 2002 by TADA Tadashi <sho@spc.gr.jp>
-# You can redistribute it and/or modify it under GPL2.
+# Copyright (c) 2002 TADA Tadashi <sho@spc.gr.jp>
+# You can distribute this file under the GPL2.
 #
 def gradient( str, first_size, last_size )
 	ary = str.split( // )
@@ -20,7 +20,7 @@ def gradient( str, first_size, last_size )
 	sd = ( last_size - first_size ).to_f / len
 	ary.each do |x|
 		s = sprintf( '%d',fontsize.round )
-		result << %Q[<span style="font-size: #{s}pt;">#{x}</span>]
+		result << %Q[<span style="font-size: #{s}pt;">#{h x}</span>]
 		fontsize += sd
 	end
 	result
