@@ -1,4 +1,4 @@
-# highlight.rb $Revision: 1.2.2.3 $
+# highlight.rb $Revision: 1.13 $
 #
 # Highlighting the element jumped from other pages.
 #
@@ -6,7 +6,7 @@
 # Copyright (C) 2003 by Kazuhiro NISHIYAMA
 # You can redistribute it and/or modify it under GPL2.
 #
-if @mode == 'day' then
+if @mode == 'day' and not bot? then
 	add_footer_proc do
 		<<-SCRIPT
 			<script type="text/javascript"><!--
@@ -24,6 +24,13 @@ if @mode == 'day' then
 			
 				saveClass = highlightElem.className;
 				highlightElem.className = "highlight";
+
+				if (highlightElem.tagName == 'H3') {
+					var diary_title = "#{(@conf.html_title.gsub(/\\/, '\\\\\\') || '').gsub(/&/n, '&amp;').gsub(/"/n, '&quot;').gsub(/>/n, '&gt;').gsub(/</n, '&lt;')} (#{@date.strftime('%Y-%m-%d')})";
+					var sanchor_length = "#{apply_plugin( @conf.section_anchor ).gsub(/<[^>]+?>/, '').gsub(/\"/, '\"')}".length;
+					var section_title = highlightElem.innerHTML.replace(/<[^>]+?>/g, '').substr(sanchor_length + 1).replace(/[ ]*$/, '');;
+					document.title = (section_title + ' - ' + diary_title).replace(/&lt;/g, '<').replace(/&gt;/g, '>').replace(/&quot;/g, '"').replace(/&amp;/g, '&');
+				}
 			}
 					
 			function getHighlightElement(name) {
