@@ -1,5 +1,5 @@
 #
-# Japanese resource of amazon plugin $Revision: 1.3.2.8 $
+# Japanese resource of amazon plugin $Revision: 1.13 $
 #
 # Copyright (C) 2002 HAL99 <hal99@mtj.biglobe.ne.jp>
 # You can redistribute it and/or modify it under GPL2.
@@ -20,6 +20,9 @@
 #     asin:    ASINޤISBN(ɬ)
 #     comment: (ά)
 #
+# isbn_detail: ꤷISBNνҤդǾܺɽ
+#     asin:    ASINޤISBN(ɬ)
+#
 # isbn: amazon˥ʤʰץС
 #     asin:    ASINޤISBN(ɬ)
 #     comment: (ɬ)
@@ -38,8 +41,6 @@
 #                                Υץ̤ѹǽǤ
 #   @options['amazon.hideconf']: ̾ǥIDԲǽ
 #                                ˤ硢trueꤷޤ
-#   @options['amazon.proxy']:    host:post׷HTTP proxyꤹ
-#                                ProxyͳAmazonξޤ
 #   @options['amazon.imgsize']:  ɽ륤᡼Υꤷޤ
 #                                (0:  1:  2:)
 #   @options['amazon.hidename']: class="amazon"ΤȤ˾̾ɽ
@@ -76,15 +77,3 @@
 @amazon_label_usedefault = 'ǥեȤΥ᡼Ȥ'
 @amazon_label_clearcache = 'åκ'
 @amazon_label_clearcache_desc = '᡼ϢΥå(Amazonɽ̷⤬˻Ʋ)'
-
-begin
-	require 'uconv'
-	@amazon_encoder = Proc::new {|s| Uconv.u8toeuc( s ) }
-rescue LoadError
-	begin
-		require 'nkf'
-		@amazon_encoder = Proc::new {|s| NKF::nkf( '-We', s ) }
-	rescue LoadError
-		@amazon_encoder = Proc::new {|s| s }
-	end
-end
