@@ -1,4 +1,4 @@
-# ja/category.rb $Revision: 1.8.2.1 $
+# ja/category.rb $Revision: 1.13 $
 #
 # Copyright (c) 2004 Junichiro KITA <kita@kitaj.no-ip.com>
 # Distributed under the GPL
@@ -22,18 +22,18 @@ def category_title
 	end
 	period = " (#{period})" if period
 
-	"[#{CGI.escapeHTML(info.category.join('|'))}#{period}]"
+	"[#{info.category.join('|')}#{period}]"
 end
 
 def category_init_local
-	@conf['category.prev_year'] ||= '&laquo;($1)'
-	@conf['category.next_year'] ||= '($1)&raquo;'
-	@conf['category.prev_half'] ||= '&laquo;($1-$2)'
-	@conf['category.next_half'] ||= '($1-$2)&raquo;'
-	@conf['category.prev_quarter'] ||= '&laquo;($1-$2)'
-	@conf['category.next_quarter'] ||= '($1-$2)&raquo;'
-	@conf['category.prev_month'] ||= '&laquo;($1-$2)'
-	@conf['category.next_month'] ||= '($1-$2)&raquo;'
+	@conf['category.prev_year'] ||= '<< ($1)'
+	@conf['category.next_year'] ||= '($1) >>'
+	@conf['category.prev_half'] ||= '<< ($1-$2)'
+	@conf['category.next_half'] ||= '($1-$2) >>'
+	@conf['category.prev_quarter'] ||= '<< ($1-$2)'
+	@conf['category.next_quarter'] ||= '($1-$2) >>'
+	@conf['category.prev_month'] ||= '<< ($1-$2)'
+	@conf['category.next_month'] ||= '($1-$2) >>'
 	@conf['category.this_year'] ||= 'ǯ'
 	@conf['category.this_half'] ||= 'Ⱦ'
 	@conf['category.this_quarter'] ||= 'Ⱦ'
@@ -53,9 +53,9 @@ def category_conf_html
 ƥꥤǥåˤ
 ʲΥåƤOKܥ򲡤Ƥ
 </p>
-<p>
-<input type="checkbox" name="category_initialize" value="1">ƥꥤǥåκ
-</p>
+<p><label for="category_initialize">
+<input type="checkbox" id="category_initialize" name="category_initialize" value="1">ƥꥤǥåκ
+</label></p>
 <p>
 ̤䥵ФǽˤޤääǥǥåκϽλޤ
 </p>
@@ -72,23 +72,9 @@ def category_conf_html
 </select>
 </p>
 
-<h3 class="subtitle">إå</h3>
+<h3 class="subtitle">ɽ֤ν</h3>
 <p>
-̾ɽʸϤꤷޤ
-&lt;%= category_navi %&gt;פǡƥòʥӥܥɽ뤳ȤǤޤ
-ޤ&lt;%= category_list%&gt;פǥƥ̾ɽ뤳ȤǤޤ
-¾Ƽץ饰HTML򵭽ҤǤޤ
-</p>
-
-<p>إå1ʥӥܥΤɽޤ</p>
-<textarea name="category.header1" cols="70" rows="8">#{CGI.escapeHTML(@conf['category.header1'])}</textarea>
-
-<p>إå2H1Τɽޤ</p>
-<p><textarea name="category.header2" cols="70" rows="8">#{CGI.escapeHTML(@conf['category.header2'])}</textarea></p>
-
-<h3 class="subtitle">ǥեȤɽ</h3>
-<p>
-ƥɽ⡼ɤΥǥեȤɽ֤ꤷޤ
+ƥɽ̤ɽΡǽɽ֤ꤷޤ
 </p>
 <p>
 <select name="category.period">
@@ -109,6 +95,22 @@ HTML
 </select>
 </p>
 
+<h3 class="subtitle">إå</h3>
+<p>
+̾ɽʸϤꤷޤ
+&lt;%= category_navi %&gt;פǡƥòʥӥܥɽ뤳ȤǤޤ
+ޤ&lt;%= category_list%&gt;פǥƥ̾ɽ뤳ȤǤޤ
+¾Ƽץ饰HTML򵭽ҤǤޤ
+</p>
+
+<h4>إå1</h4>
+<p>ʥӥܥΤɽޤ</p>
+<p><textarea name="category.header1" cols="60" rows="5">#{h @conf['category.header1']}</textarea></p>
+
+<h4>إå2</h4>
+<p>H1Τɽޤ</p>
+<p><textarea name="category.header2" cols="60" rows="5">#{h @conf['category.header2']}</textarea></p>
+
 <h3 class="subtitle">ܥ٥</h3>
 <p>
 ʥӥܥΥ٥ꤷޤ
@@ -137,8 +139,8 @@ HTML
 		r << <<HTML
 <tr>
 	<td>#{button}</td>
-	<td><input type="text" name="#{name}" value="#{CGI.escapeHTML(@conf[name])}" size="30"></td>
-	<td><p><span class="adminmenu"><a>#{@conf[name].sub(/\$1/, "2004").sub(/\$2/, "2")}</a></span></p></td>
+	<td><input type="text" name="#{name}" value="#{h @conf[name]}" size="30"></td>
+	<td><p><span class="adminmenu"><a>#{@conf[name].sub(/\$1/, "2007").sub(/\$2/, "2")}</a></span></p></td>
 </tr>
 HTML
 	end
@@ -160,9 +162,9 @@ def category_icon_conf_html
 <p>
 <dl>
 <dt>ǥ쥯ȥ:</dt>
-<dd><input name="category.icon_dir" value="#{@category_icon_dir}" size="30"></dd>
+<dd><input name="category.icon_dir" value="#{h @category_icon_dir}" size="30"></dd>
 <dt>URL:</dt>
-<dd><input name="category.icon_url" value="#{@category_icon_url}" size="30"></dd>
+<dd><input name="category.icon_url" value="#{h @category_icon_url}" size="30"></dd>
 </dl>
 </p>
 <hr>
@@ -173,7 +175,7 @@ HTML
 	@categories.each do |c|
 		str << %Q|\t<tr>\n\t\t<td>#{c}</td>\n\t\t<td>\n|
 		str << category_icon_select(c)
-		str << %Q|<img src="#{@category_icon_url}#{@category_icon[c]}">| if @category_icon[c]
+		str << %Q|<img src="#{h @category_icon_url}#{h @category_icon[c]}">| if @category_icon[c]
 		str << %Q|</td>\n\t</tr>\n|
 	end
 	r << <<HTML
