@@ -1,12 +1,4 @@
 # ping.rb Japanese resources
-begin
-	require 'uconv'
-	@ping_encode = 'UTF-8'
-	@ping_encoder = Proc::new {|s| Uconv.euctou8( s ) }
-rescue LoadError
-	@ping_encode = @conf.encoding
-	@ping_encoder = Proc::new {|s| s }
-end
 
 if /conf/ =~ @mode then
 	@ping_label_conf = ''
