@@ -1,9 +1,10 @@
-# kw.rb $Revision: 1.8.2.2 $
+# kw.rb $Revision: 1.16 $
 #
 # kw: keyword link generator
 #   Parameters:
 #     keyword: keyword or InterWikiName (separated by ':').
 #     name: anchor string (optional).
+#     title: title attribute (optional).
 #
 # @options['kw.dic']
 #   array of dictionary table array. an item of array is:
@@ -14,7 +15,7 @@
 #          If keyword is 'foo', it has key nil.
 #          If keyword is 'google:foo', it has key 'google'.
 #   URL:   the URL for link. '$1' is replace by keyword.
-#   style: encoding style as: 'euc-jp', 'sjis', 'jis' or nil.
+#   style: encoding style as: 'euc-jp', 'sjis', 'jis', 'utf-8' or nil.
 #
 #   if there isn't @options['kw.dic'], the plugin links to google.
 #
@@ -33,7 +34,7 @@ def kw_parse( str )
 	str.each do |pair|
 		k, u, s = pair.sub( /[\r\n]+/, '' ).split( /[ \t]+/, 3 )
 		k = nil if k == '' or k == 'nil'
-		s = nil if s != 'euc-jp' && s != 'sjis' && s != 'jis'
+		s = nil if s != 'euc-jp' && s != 'sjis' && s != 'jis' && s != 'utf-8'
 		kw_list << [k, u, s] if u
 	end
 	kw_list
@@ -60,7 +61,7 @@ def kw_generate_dic
 	kw_dic
 end
 
-def kw( keyword, name = nil )
+def kw( keyword, name = nil, title = nil )
 	@kw_dic = kw_generate_dic unless @kw_dic
 	show_inter = @options['kw.show_inter'] == nil ? true : @options['kw.show_inter']
 
@@ -71,15 +72,18 @@ def kw( keyword, name = nil )
 	end
 	keyword = key unless show_inter
 	name = keyword unless name
+	title = title ? %Q[ title="#{h title}"] : ''
 	begin
-		key = CGI::escape( case @kw_dic[inter][1]
+		key = u( case @kw_dic[inter][1]
 			when 'euc-jp'
-				#NKF::nkf( '-e', key )
+				#NKF::nkf( '-m0 -e', key )
 				key
 			when 'sjis'
-				NKF::nkf( '-s', key )
+				NKF::nkf( '-m0 -s', key )
 			when 'jis'
-				NKF::nkf( '-j', key )
+				NKF::nkf( '-m0 -j', key )
+			when 'utf-8'
+				NKF::nkf( '-m0 -w', key )
 			else # none
 				key
 		end )
@@ -87,7 +91,7 @@ def kw( keyword, name = nil )
 		inter = nil
 		retry
 	end
-	%Q[<a href="#{CGI::escapeHTML( @kw_dic[inter][0].sub( /\$1/, key ) )}">#{name}</a>]
+	%Q[<a href="#{h @kw_dic[inter][0].sub( /\$1/, key )}"#{title}>#{h name}</a>]
 end
 
 #
@@ -95,7 +99,7 @@ end
 #
 unless @resource_loaded then
 	def kw_label
-		"ɥץ饰"
+		""
 	end
 
 	def kw_desc
@@ -129,7 +133,7 @@ add_conf_proc( 'kw', kw_label ) do
 	end
 	<<-HTML
 	#{kw_desc}
-	<p><textarea name="kw.dic" cols="60" rows="10">#{CGI::escapeHTML( dic.collect{|a|a.flatten.join( " " )}.join( "\n" ) )}</textarea></p>
+	<p><textarea name="kw.dic" cols="60" rows="10">#{h dic.collect{|a|a.flatten.join( " " )}.join( "\n" )}</textarea></p>
 	HTML
 end
 
