@@ -1,4 +1,4 @@
-# random_google.rb $Revision: 1.4 $
+# random_google.rb $Revision: 1.7 $
 #
 # random_google: ФñgoogleǸ󥯤
 #
@@ -70,10 +70,10 @@ if /(latest|day)/ === @mode and ! @conf.bot? and ! @conf.mobile_agent?
 				r << words.delete_at(rand(words.size))
 			end
 			append = @conf['random_google.append'].split
-			rr = (r.compact.map {|i| CGI::escape(i)} + append).join('+')
-			rrr = r.compact.map {|i| CGI::escapeHTML(i)}.join(' ')
-			caption = @conf['random_google.caption'].gsub(/\$1/, rrr)
-			popup = @conf['random_google.popup'].gsub(/\$1/, rrr)
+			rr = (r.compact + append).map {|i| u(i)}.join('+')	# URL-escaped
+			rrr = r.compact.map.join(' ')
+			caption = @conf['random_google.caption'].gsub(/\$1/, h(rrr)) # only the words picked up are escaped
+			popup = h(@conf['random_google.popup'].gsub(/\$1/, rrr)) # escaped
 			<<-HTML
 			<div class="body-enter">
 			[<a href="http://www.google.com/search?lr=lang_ja&amp;ie=euc-jp&amp;q=#{rr}" title="#{popup}">
@@ -119,18 +119,18 @@ add_conf_proc('RandomGoogle', 'Ϣ뤫⤷ʤڡ') do
 
 	<h3 class="subtitle">ɽϢ</h3>
 	#{"<p>googleؤΥ󥯤򼨤ʸȥ󥯤ξ˥ޥݥ󥿤֤˥ݥåץåפʸꤷޤʸ $1 Ф줿ɤִޤ</p>" unless @conf.mobile_agent?}
-	<p>󥯡<input name="random_google_caption" size="70" value="#{@conf['random_google.caption']}"></p>
-	<p>ݥåץåס<input name="random_google_popup" size="70" value="#{@conf['random_google.popup']}"></p>
+	<p>󥯡<input name="random_google_caption" size="70" value="#{h @conf['random_google.caption']}"></p>
+	<p>ݥåץåס<input name="random_google_popup" size="70" value="#{h @conf['random_google.popup']}"></p>
 
 	<h3 class="subtitle">ɲä륭</h3>
 	#{"<p>ɲäɤꤷޤʣꤹϥɤ򥹥ڡǶڤäƻꤷƤ</p>" unless @conf.mobile_agent?}
 	#{"<p>)</p><pre>-site:example.com</pre>" unless @conf.mobile_agent?}
-	<p><input name="random_google_append" size="70" value="#{@conf['random_google.append']}"></p>
+	<p><input name="random_google_append" size="70" value="#{h @conf['random_google.append']}"></p>
 
 	<h3 class="subtitle">륭</h3>
 	#{"<p>ɤꤷޤʣꤹϥɤ򥹥ڡǶڤäƻꤷƤ</p>" unless @conf.mobile_agent?}
 	#{"<p>)</p><pre>a the</pre>" unless @conf.mobile_agent?}
-	<p><input name="random_google_exception" size="70" value="#{@conf['random_google.exception']}"></p>
+	<p><input name="random_google_exception" size="70" value="#{h @conf['random_google.exception']}"></p>
 	HTML
 
 	unless @conf.secure
@@ -149,7 +149,7 @@ add_conf_proc('RandomGoogle', 'Ϣ뤫⤷ʤڡ') do
 	<h3 class="subtitle">ǲϴΥѥ</h3>
 	#{"<p>ѤǲϴХѥǻꤷޤ</p>" unless @conf.mobile_agent?}
 	#{"<p>)</p><pre>/usr/local/bin/chasen</pre>" unless @conf.mobile_agent?}
-	<p><input name="random_google_analyzer_path" size="70" value="#{@conf['random_google.analyzer_path']}"></p>
+	<p><input name="random_google_analyzer_path" size="70" value="#{h @conf['random_google.analyzer_path']}"></p>
 	HTML
 	end
 	r
