@@ -1,7 +1,6 @@
 #!/usr/bin/env ruby
-$KCODE = 'n'
 
-# squeeze.rb $Revision: 1.18 $
+# squeeze.rb $Revision: 1.24 $
 #
 # Create daily HTML file from tDiary database.
 #
@@ -15,108 +14,8 @@ $KCODE = 'n'
 # The original version of this file was distributed with squeeze 
 # version 1.0.4 by TADA Tadashi <sho@spc.gr.jp> with GPL2.
 #
-=begin ChangeLog
-2003-11-15  Masao Mutoh <mutoh@highway.ne.jp>
-        * Replace header documents to URLs.
 
-2003-08-05  Kazuhiko  <kazuhiko@fdiary.net>
-	* make html when receiving TrackBack Ping
-
-2003-07-31 zunda <zunda at freeshell.org>
-	* sets mtime and atime of the output files
-	* exit( 1 ) with an error
-
-2003-06-30 MUTOH Masao	<mutoh@highway.ne.jp>
-	* fix path of default output_path on CGI or CMD mode.
-	  Pointed out by OGAWA KenIchi.
-
-2003-05-17 TADA Tadashi <sho@spc.gr.jp>
-	* fix path of theme on CGI or CMD mode.
-
-2003-04-28 TADA Tadashi <sho@spc.gr.jp>
-	* enable running on secure mode.
-
-2003-02-17 TADA Tadashi <sho@spc.gr.jp>
-	* add suffix option.
-
-2002-11-20 TADA Tadashi <sho@spc.gr.jp>
-	* make CGI object in YATDiarySqueeze and YATDiarySqueezeMain.
-
-2002-11-13 TADA Tadashi <sho@spc.gr.jp>
-	* set make @diaries in TDiaryYAsqueeze.
-
-2002-11-11 TADA Tadashi <sho@spc.gr.jp>
-	* support TDiary::TDiaryBase#mode for date display in HTML title.
-
-2002-10-23 TADA Tadashi <sho@spc.gr.jp>
-	* support Config#hide_comment_form.
-
-2002-10-22 TADA Tadashi <sho@spc.gr.jp>
-	* rename to squeeze.rb.
-
-2002-08-22 TADA Tadashi <sho@spc.gr.jp>
-	* add tdiary path to $:.
-
-2002-08-16 TADA Tadashi <sho@spc.gr.jp>
-	* ignore parser cache.
-	* hide comment form.
-
-2002-08-13 TADA Tadashi <sho@spc.gr.jp>
-	* for tDiary 1.5. thanks NISHIO Mizuho <gha@intrastore.cdc.com>.
-
-2002-05-19 MUTOH Masao	<mutoh@highway.ne.jp>
-	* ɥȥåץǡ
-
-2002-04-29 MUTOH Masao	<mutoh@highway.ne.jp>
-	* yasqueeze.rbȤʸɤISO-2022-JPäΤEUC-JPľ
-	* version 1.3.1
-
-2002-04-14 MUTOH Masao	<mutoh@highway.ne.jp>
-	* @optionsꤷʤƤǥեȤư򤹤褦ˤ
-		- output_path = (@data_path)/cache/html
-		- all_data = false
-		- compat_path = false
-	* version 1.3.0
-
-2002-04-01 MUTOH Masao	<mutoh@highway.ne.jp>
-	* ɥȺ
-	* ܥեΥإåʬΥɥȤ򽼼¤
-
-2002-03-31 MUTOH Masao	<mutoh@highway.ne.jp>
-	* TAB  ڡ
-	* ɥȥå
-
-2002-03-29 MUTOH Masao	<mutoh@highway.ne.jp>
-	* ϥեդξǥȤ褦ˤ
-	* squeeze.rbƱͤΥޥɥץ򥵥ݡȤ
-	 ʤ --deleteץϤʤ--allץѰա
-	* ޥɥ饤󥪥ץɲäȤפˤʤä--nohtmlץ
-	  ʤ
-	* ɥȺƸľ
-	* tdiary.conf@optionsб
-	* add_update_proc do end б
-	* version 1.2.0
-
-2002-03-21 MUTOH Masao	<mutoh@highway.ne.jp>
-	* ɽоݤ˴ޤ뤫ɤǤ褦ˤ
-	* ե¸ǥ쥯ȥιtDiaryɸΤΤversion 1.0.0
-	  ΤΤǤ褦ˤ
-	* ɥȤ򥽡ɤФ
-	* version 1.1.0
-
-2002-03-19 MUTOH Masao <mutoh@highway.ne.jp>
-	* version 1.0.0
-=end
-
-
-$KCODE= 'e'
-
-mode = ""
-if $0 == __FILE__
-	mode = ENV["REQUEST_METHOD"]? "CGI" : "CMD"
-else
-	mode = "PLUGIN"
-end
+mode = defined?(TDiary) ? "PLUGIN" : ENV["REQUEST_METHOD"]? "CGI" : "CMD"
 
 if mode == "CMD" || mode == "CGI"
 	output_path = "./html/"
@@ -129,7 +28,7 @@ if mode == "CMD" || mode == "CGI"
 
 	if mode == "CMD"
 		def usage
-			puts "squeeze $Revision: 1.18 $"
+			puts "squeeze $Revision: 1.24 $"
 			puts " making html files from tDiary's database."
 			puts " usage: ruby squeeze.rb [-p <tDiary path>] [-c <tdiary.conf path>] [-a] [-s] [-x suffix] <dest path>"
 			exit
@@ -165,26 +64,36 @@ if mode == "CMD" || mode == "CGI"
 		usage unless output_path
 		output_path = File::expand_path(output_path)
 		output_path += '/' if /\/$/ !~ output_path
+
+		tdiary_conf = tdiary_path unless tdiary_conf
+		Dir::chdir( tdiary_conf )
+		ARGV << '' # dummy argument against cgi.rb offline mode.
+		$:.unshift tdiary_path
 	else
 		@options = Hash.new
 		File::readlines("tdiary.conf").each {|item| 
 			if item =~ /@options/
-				eval(item)
+				begin
+					eval(item)
+				rescue SyntaxError
+				end
 			end
 		}
 		output_path = @options['squeeze.output_path'] || @options['yasqueeze.output_path']
 		suffix = @options['squeeze.suffix'] || ''
 		all_data = @options['squeeze.all_data'] || @options['yasqueeze.all_data']
 		compat = @options['squeeze.compat_path'] || @options['yasqueeze.compat_path']
+
+		if FileTest::symlink?( __FILE__ ) then
+			org_path = File::dirname( File::readlink( __FILE__ ) )
+		else
+			org_path = File::dirname( __FILE__ )
+		end
+		$:.unshift( org_path.untaint )
 	end
 
-	tdiary_conf = tdiary_path unless tdiary_conf
-	Dir::chdir( tdiary_conf )
-
 	begin
-		ARGV << '' # dummy argument against cgi.rb offline mode.
-		$:.unshift tdiary_path
-		require "#{tdiary_path}/tdiary"
+		require "tdiary"
 	rescue LoadError
 		$stderr.print "squeeze.rb: cannot load tdiary.rb. <#{tdiary_path}/tdiary>\n"
 		exit( 1 )
@@ -199,7 +108,9 @@ module TDiary
 		def initialize(diary, dest, all_data, compat, conf, suffix)
 			@ignore_parser_cache = true
 	
-			super(CGI::new, 'day.rhtml', conf)
+			cgi = CGI::new
+			def cgi.referer; nil; end
+			super( cgi, 'day.rhtml', conf )
 			@diary = diary
 			@date = diary.date
 			@diaries = {@date.strftime('%Y%m%d') => @diary} if @diaries.size == 0
@@ -254,16 +165,20 @@ module TDiary
 		def initialize(dest, all_data, compat, conf, suffix)
 			@ignore_parser_cache = true
 	
-			super(CGI::new, 'day.rhtml', conf)
+			cgi = CGI::new
+			def cgi.referer; nil; end
+			super( cgi, 'day.rhtml', conf )
 			calendar
 			@years.keys.sort.each do |year|
 				print "(#{year.to_s}/) "
 				@years[year.to_s].sort.each do |month|
+					diaries2 = nil
 					@io.transaction(Time::local(year.to_i, month.to_i)) do |diaries|
-						diaries.sort.each do |day, diary|
-							print YATDiarySqueeze.new(diary, dest, all_data, compat, conf, suffix).execute + " "
-						end
-						false
+						diaries2 = diaries
+						DIRTY_NONE
+					end
+					diaries2.sort.each do |day, diary|
+						print YATDiarySqueeze.new(diary, dest, all_data, compat, conf, suffix).execute + " "
 					end
 				end
 			end
@@ -281,14 +196,16 @@ if mode == "CGI" || mode == "CMD"
 			</head>
 			<body><div style="text-align:center">
 			<h1>Squeeze for tDiary</h1>
-			<p>$Revision: 1.18 $</p>
+			<p>$Revision: 1.24 $</p>
 			<p>Copyright (C) 2002 MUTOH Masao&lt;mutoh@highway.ne.jp&gt;</p></div>
 			<br><br>Start!</p><hr>
 		]
 	end
 
 	begin
-		conf = TDiary::Config::new
+		require 'cgi'
+		cgi = CGI.new
+		conf = TDiary::Config::new(cgi)
 		conf.header = ''
 		conf.footer = ''
 		conf.show_comment = true
