@@ -1,4 +1,4 @@
-# tlink.rb $Revision: 1.14 $
+# tlink.rb $Revision: 1.19 $
 #
 # title ° anchor plugin
 #
@@ -74,11 +74,10 @@ def tlink_initialize
   @tlink_path = dir + "/tlink.dat"
 
   Dir.mkdir(dir, 0700) unless FileTest.exist?(dir)
-  db = PStore.new(@tlink_path)
-  db.transaction do
-    begin
+  db = PStore.new(@tlink_path).transaction do |db|
+    if (db.root?('tlinkdata')) then
       @tlink_dic = db["tlinkdata"]
-    rescue PStore::Error
+    else
       @tlink_dic = Hash.new
     end
   end
@@ -139,10 +138,10 @@ def tlink( url, str, title = nil )
   unless title
     if @tlink_dic[url] && %r[#(p|c)\d\d$] =~ url && @tlink_dic[url] != ''
       title = @tlink_dic[url]
-    elsif @tlink_dic[url] && %r[#(p|c)\d\d$] !=~ url
+    elsif @tlink_dic[url] && %r[#(p|c)\d\d$] !~ url
       title = @tlink_dic[url]
     else
-      if url =~ ENV["REDIRECT_URL"] && url =~ @date.strftime('%Y%m%d')
+      if /#{url}/ =~ ENV["REDIRECT_URL"] && /#{url}/ =~ @date.strftime('%Y%m%d')
       else
         title = tlink_getcomment( url )
         @tlink_dic[url] = title
@@ -151,6 +150,6 @@ def tlink( url, str, title = nil )
     end
   end
 
-  %Q[<a href="#{url}" title="#{title}">#{str}</a>]
+  %Q[<a href="#{h url}" title="#{h title}">#{str}</a>]
 end
 
