@@ -1,5 +1,5 @@
 #
-# Chinese resource of amazon plugin $Revision: 1.1.2.2 $
+# English resource of amazon plugin $Revision: 1.8 $
 #
 # Copyright (C) 2002 HAL99 <hal99@mtj.biglobe.ne.jp>
 # You can redistribute it and/or modify it under GPL2.
@@ -20,6 +20,9 @@
 #     asin:    ASIN or ISBN
 #     comment: comment (optional)
 #
+# isbn_detail: show the item detail with image
+#     asin:    ASIN or ISBN
+#
 # isbn: light version. it dose not access to amazon.
 #     asin:    ASIN or ISBN
 #     comment: comment
@@ -29,18 +32,23 @@
 #                           changed in preferences page.
 #   @options['amazon.hideconf']: When you want to prohibit changing amazon.aid
 #                                via preferences page, set false.
-#   @options['amazon.proxy']: HTTP proxy in "host:post" style.
 #   @options['amazon.imgsize']: specify image size (0:laege, 1:regular, 2:small)
 #   @options['amazon.hidename']: hide book name when class="amazon", set true.
+#   @options['amazon.default_image_base']: URL that include default images.
+#                             amazon.rb uses images on tDiary.org when this
+#                             option not specified. If you want to use your
+#                             original images, modify PNG file in amazon directory.
 #   @options['amazon.nodefault']: If you dosen't want to show default image 
 #                                 when the book image not found, set true.
 #
 
 @amazon_url = 'http://www.amazon.com/exec/obidos/ASIN'
+@amazon_ecs_url = 'http://webservices.amazon.com/onca/xml'
 @amazon_item_name = /^Amazon\.com: (.*)$/
 @amazon_item_image = %r|(<img src="(http://images\.amazon\.com/images/P/(.*MZZZZZZZ_?.jpg))".*?>)|i
 @amazon_label_conf = 'Amazon'
 @amazon_label_aid = 'Amazon Assosiate ID'
+@amazon_label_aid_desc = "If you don't specified it, this plugin call amazon with ID of tDiary developer."
 @amazon_label_imgsize = 'Image size of the book'
 @amazon_label_large = 'Large'
 @amazon_label_regular = 'Regular'
