@@ -1,6 +1,4 @@
-# ping.rb English resources
-@ping_encode = 'UTF-8'
-@ping_encoder = Proc::new {|s| s }
+# ping.rb Chinese resources
 
 if /conf/ =~ @mode then
 	@ping_label_conf = 'Update ping'
