@@ -1,5 +1,5 @@
 =begin
-= emptDiary style((-$Id: emptdiary_style.rb,v 1.6.2.1 2005/03/11 07:44:37 tadatadashi Exp $-))
+= emptDiary style((-$Id: emptdiary_style.rb,v 1.10 2005/10/12 06:20:33 tadatadashi Exp $-))
 
 == Summary
 This style is an extension to the tDiary style which allows plug-in
@@ -147,60 +147,45 @@ sections.
 		end
 
 		def to_html4( opt )
-			idx = 1
 			r = ''
 			each_section do |section|
 				r << %Q[<div class="section">\n]
+				r << %Q[<%=section_enter_proc( Time::at( #{date.to_i} ) )%>\n]
 				if section.subtitle then
-					r << %Q[<h3><a ]
-					if opt['anchor'] then
-						r << %Q[name="p#{'%02d' % idx}" ]
-					end
-					r << %Q[href="#{opt['index']}<%=anchor "#{date.strftime( '%Y%m%d' )}#p#{'%02d' % idx}" %>">#{opt['section_anchor']}</a> ]
-					if opt['multi_user'] and section.author then
-						r << %Q|[#{section.author}]|
-					end
-					r << %Q[#{section.categorized_subtitle}</h3>]
+					r << %Q[<h3><%= subtitle_proc( Time::at( #{date.to_i} ), #{section.subtitle.dump.gsub( /%/, '\\\\045' )} ) %></h3>\n]
 				end
 				if /\A</ =~ section.body then
 					r << %Q[#{section.body}]
 				elsif section.subtitle
 					r << %Q[<p>#{section.body.split_unless_plugin( "\n+" ).collect{|l|l.chomp.sub( /\A[ ]/e, '')}.join( "</p>\n<p>" )}</p>]
 				else
-					r << %Q[<p><a ]
-					if opt['anchor'] then
-						r << %Q[name="p#{'%02d' % idx}" ]
-					end
-					r << %Q[href="#{opt['index']}<%=anchor "#{date.strftime( '%Y%m%d' )}#p#{'%02d' % idx}" %>">#{opt['section_anchor']}</a> #{section.body.split_unless_plugin( "\n+" ).collect{|l|l.chomp.sub( /\A[ ]/e, '' )}.join( "</p>\n<p>" )}</p>]
+					r << %Q[<p><%= subtitle_proc( Time::at( #{date.to_i} ), nil ) %>]
+					r << %Q[#{section.body.split_unless_plugin( "\n+" ).collect{|l|l.chomp.sub( /\A[ ]/e, '' )}.join( "</p>\n<p>" )}</p>]
 				end
+				r << %Q[<%=section_leave_proc( Time::at( #{date.to_i} ) )%>\n]
 				r << %Q[</div>]
-				idx += 1
 			end
 			r
 		end
 
 		def to_chtml( opt )
-			idx = 0
 			r = ''
 			each_section do |section|
+				r << %Q[<%=section_enter_proc( Time::at( #{date.to_i} ) )%>\n]
 				if section.subtitle then
-					r << %Q[<H3><A NAME="p#{'%02d' % idx += 1}">*</A> #{section.subtitle}</H3>]
+					r << %Q[<H3><%= subtitle_proc( Time::at( #{date.to_i} ), #{section.subtitle.dump.gsub( /%/, '\\\\045' )} ) %></H3>\n]
 				end
 				if /\A</ =~ section.body then
-					idx += 1
 					r << section.body
 				elsif section.subtitle
 					r << %Q[<P>#{section.body.split_unless_plugin( "\n+" ).collect{|l|l.chomp.sub( /\A[ ]/e, '' )}.join( "</P>\n<P>" )}</P>]
 				else
-					r << %Q[<P><A NAME="p#{'%02d' % idx += 1}">*</A> ]
-					if opt['multi_user'] and section.author then
-						r << %Q|[#{section.author}]|
-					end
+					r << %Q[<P><%= subtitle_proc( Time::at( #{date.to_i} ), nil ) %>]
 					r << %Q[#{section.body.split_unless_plugin( "\n+" ).collect{|l|l.chomp.sub( /\A[ ]/e, '' )}.join( "</P>\n<P>" )}</P>]
 				end
+				r << %Q[<%=section_leave_proc( Time::at( #{date.to_i} ) )%>\n]
 			end
 			r
 		end
-
 	end
 end
