@@ -1,12 +1,15 @@
 #
 # en/00default.rb: English resources of 00default.rb.
 #
+# Copyright (C) 2001-2005, TADA Tadashi <sho@spc.gr.jp>
+# You can redistribute it and/or modify it under GPL2.
+#
 
 #
 # header
 #
 def title_tag
-	r = "<title>#{CGI::escapeHTML( @html_title )}"
+	r = "<title>#{h @html_title}"
 	case @mode
 	when 'day', 'comment'
 		r << "(#{@date.strftime( '%Y-%m-%d' )})" if @date
@@ -32,6 +35,20 @@ def title_tag
 end
 
 
+#
+# link to HOWTO write diary
+#
+def style_howto
+	%Q|/<a href="http://docs.tdiary.org/en/?#{h @conf.style}Style">How to write</a>|
+end
+
+#
+# convert to UTF-8
+#
+def to_utf8( str, charset = nil )
+	str.dup
+end
+
 #
 # labels
 #
@@ -39,7 +56,8 @@ def no_diary; "No diary on #{@date.strftime( @conf.date_format )}"; end
 def comment_today; "Today's TSUKKOMI"; end
 def comment_total( total ); "(Total: #{total})"; end
 def comment_new; 'Add a TSUKKOMI'; end
-def comment_description; 'Add a TSUKKOMI or Comment please. E-mail address will be shown to only me.'; end
+def comment_description_default; 'Add a TSUKKOMI or Comment please. E-mail address will be shown to only me.'; end
+def comment_limit_label; 'You cannot make more TSUKKOMI because it has over limit.'; end
 def comment_description_short; 'TSUKKOMI!!'; end
 def comment_name_label; 'Name'; end
 def comment_name_label_short; 'Name'; end
@@ -50,7 +68,6 @@ def comment_body_label_short; 'Comment'; end
 def comment_submit_label; 'Submit'; end
 def comment_submit_label_short; 'Submit'; end
 def comment_date( time ); time.strftime( "(#{@date_format} %H:%M)" ); end
-def referer_today; "Today's Link"; end
 def trackback_today; "Today's TrackBacks"; end
 def trackback_total( total ); "(Total: #{total})"; end
 
@@ -62,8 +79,12 @@ def navi_edit; "Edit"; end
 def navi_preference; "Preference"; end
 def navi_prev_diary(date); "Prev(#{date.strftime(@date_format)})"; end
 def navi_next_diary(date); "Next(#{date.strftime(@date_format)})"; end
+def navi_prev_month; "Prev month"; end
+def navi_next_month; "Next month"; end
 def navi_prev_nyear(date); "Prev(#{date.strftime('%m-%d')})"; end
 def navi_next_nyear(date); "Next(#{date.strftime('%m-%d')})"; end
+def navi_prev_ndays; "#{@conf.latest_limit} days before"; end
+def navi_next_ndays; "#{@conf.latest_limit} days after"; end
 
 def submit_label
 	if @mode == 'form' or @cgi.valid?( 'appendpreview' ) then
@@ -74,9 +95,6 @@ def submit_label
 end
 def preview_label; 'Preview'; end
 
-def label_no_referer; "Today's Link Excluding List"; end
-def label_referer_table; "Today's Link Conversion Rule"; end
-
 def nyear_diary_label(date, years); "my old days"; end
 def nyear_diary_title(date, years); "same days in past"; end
 
@@ -86,6 +104,7 @@ def nyear_diary_title(date, years); "same days in past"; end
 #
 def mobile_navi_latest; 'Latest'; end
 def mobile_navi_update; 'Update'; end
+def mobile_navi_edit; "Edit"; end
 def mobile_navi_preference; 'Prefs'; end
 def mobile_navi_prev_diary; 'Prev'; end
 def mobile_navi_next_diary; 'Next'; end
@@ -100,137 +119,140 @@ def category_anchor(c); "[#{c}]"; end
 # preferences
 #
 
+# genre labels
+@conf_genre_label['basic'] = 'Basic'
+@conf_genre_label['theme'] = 'Themes'
+@conf_genre_label['tsukkomi'] = 'TSUKKOMI'
+@conf_genre_label['referer'] = 'Referrer'
+@conf_genre_label['security'] = 'Security'
+@conf_genre_label['etc'] = 'etc'
+
 # basic (default)
-add_conf_proc( 'default', 'Basic' ) do
+add_conf_proc( 'default', 'Site information', 'basic' ) do
 	saveconf_default
+	@conf.description ||= ''
+	@conf.icon ||= ''
+	@conf.banner ||= ''
 	<<-HTML
+	<h3 class="subtitle">Title</h3>
+	#{"<p>The title of your diary. This value is used in HTML &lt;title&gt; element and in mobile mode. Do not use HTML tags.</p>" unless @conf.mobile_agent?}
+	<p><input name="html_title" value="#{h @conf.html_title}" size="50"></p>
+
 	<h3 class="subtitle">Author</h3>
 	#{"<p>Specify your name. This value is into HTML header.</p>" unless @conf.mobile_agent?}
-	<p><input name="author_name" value="#{CGI::escapeHTML @conf.author_name}" size="40"></p>
+	<p><input name="author_name" value="#{h @conf.author_name}" size="40"></p>
+
 	<h3 class="subtitle">E-mail address</h3>
 	#{"<p>Specify your E-mail address. This value is into HTML header.</p>" unless @conf.mobile_agent?}
-	<p><input name="author_mail" value="#{@conf.author_mail}" size="40"></p>
+	<p><input name="author_mail" value="#{h @conf.author_mail}" size="40"></p>
+
 	<h3 class="subtitle">URL of index page</h3>
 	#{"<p>The URL of index of your website if you have.</p>" unless @conf.mobile_agent?}
-	<p><input name="index_page" value="#{@conf.index_page}" size="50"></p>
-	<h3 class="subtitle">Time difference adjustment</h3>
-	#{"<p>When updating diary, you can adjust date which is automatically inserted into the form. The unit is hour. For example, if you want to handle the time until 2 a.m. as the previous day, you set this to -2. tDiary inserts the date which is older by 2 hours than the actual time. </p>" unless @conf.mobile_agent?}
-	<p><input name="hour_offset" value="#{@conf.hour_offset}" size="5"></p>
+	<p><input name="index_page" value="#{h @conf.index_page}" size="50"></p>
+
+	<h3 class="subtitle">URL of Your Diary</h3>
+	#{"<p>Specify your diary's URL. This URL is used by some plugins for indicate your diary</p>" unless @conf.mobile_agent?}
+	#{"<p><strong>NOTICE!! The URL specified below is different from current URL of accessed now.</strong></p>" unless @conf.base_url == @conf.base_url_auto}
+	<p><input name="base_url" value="#{h @conf.base_url}" size="70"></p>
+
+	<h3 class="subtitle">Description</h3>
+	#{"<p>A brief description of your diary. Can be left blank.</p>" unless @conf.mobile_agent?}
+	<p><input name="description" value="#{h @conf.description}" size="60"></p>
+
+	<h3 class="subtitle">Site icon (favicon)</h3>
+	#{"<p>URL for the small icon (aka 'favicon') of your site. Can be left blank.</p>" unless @conf.mobile_agent?}
+	<p><input name="icon" value="#{h @conf.icon}" size="60"></p>
+
+	<h3 class="subtitle">Site banner</h3>
+	#{"<p>URL for the banner image of your site. makerss plugin will use this value to make RSS. Can be left blank.</p>" unless @conf.mobile_agent?}
+	<p><input name="banner" value="#{h @conf.banner}" size="60"></p>
 	HTML
 end
 
 # header/footer (header)
-add_conf_proc( 'header', 'Header/Footer' ) do
+add_conf_proc( 'header', 'Header/Footer', 'basic' ) do
 	saveconf_header
 
 	<<-HTML
-	<h3 class="subtitle">Title</h3>
-	#{"<p>The title of your diary. This value is used in HTML &lt;title&gt; element and in mobile mode. Do not use HTML tags.</p>" unless @conf.mobile_agent?}
-	<p><input name="html_title" value="#{ CGI::escapeHTML @conf.html_title }" size="50"></p>
 	<h3 class="subtitle">Header</h3>
 	#{"<p>This text is inserted into top of each pages. You can use HTML tags. Do not remove \"&lt;%=navi%&gt;\", because it mean Navigation bar inclued \"Update\" button. And \"&lt;%=calendar%&gt;\" mean calendar. So you can specify other plugins also.</p>" unless @conf.mobile_agent?}
-	<p><textarea name="header" cols="70" rows="10">#{ CGI::escapeHTML @conf.header }</textarea></p>
+	<p><textarea name="header" cols="60" rows="10">#{h @conf.header}</textarea></p>
 	<h3 class="subtitle">Footer</h3>
 	#{"<p>This text is inserted into bottom of each pages. You can specify as same as Header.</p>" unless @conf.mobile_agent?}
-	<p><textarea name="footer" cols="70" rows="10">#{ CGI::escapeHTML @conf.footer }</textarea></p>
+	<p><textarea name="footer" cols="60" rows="10">#{h @conf.footer}</textarea></p>
 	HTML
 end
 
 # diaplay
-add_conf_proc( 'display', 'Display' ) do
+add_conf_proc( 'display', 'Display', 'basic' ) do
 	saveconf_display
 
 	<<-HTML
 	<h3 class="subtitle">Section anchor</h3>
 	#{"<p>\"Anchor\" guide to link from other website. Section anchors are insertd into begining of each section. So if you specify \"&lt;span class=\"sanchor\"&gt;_&lt;/span&gt;\", image anchor will be shown Image anchor by themes.</p>" unless @conf.mobile_agent?}
-	<p><input name="section_anchor" value="#{ CGI::escapeHTML @conf.section_anchor }" size="40"></p>
+	<p><input name="section_anchor" value="#{h @conf.section_anchor}" size="40"></p>
 	<h3 class="subtitle">TSUKKOMI anchor</h3>
 	#{"<p>TSUKKOMI anchor is inserted into begining of each TSUKKOMIs. So You can specify \"&lt;span class=\"canchor\"&gt;_&lt;/span&gt;\" for Image anchor.</p>" unless @conf.mobile_agent?}
-	<p><input name="comment_anchor" value="#{ CGI::escapeHTML @conf.comment_anchor }" size="40"></p>
+	<p><input name="comment_anchor" value="#{h @conf.comment_anchor}" size="40"></p>
 	<h3 class="subtitle">Date format</h3>
-	#{"<p>Format of date. If you specify a charactor after %, it mean special about date formatting: \"%Y\"(Year), \"%m\"(Month)\"%b\"(Short name of month), \"%B\"(Long name of month), \"%d\"(Day), \"%a\"(Short name of day of week), \"%A\"(Long name of day of week).</p>" unless @conf.mobile_agent?}
-	<p><input name="date_format" value="#{ CGI::escapeHTML @conf.date_format }" size="30"></p>
+	#{"<p>Format of date. If you specify a charactor after %, it mean special about date formatting: \"%Y\"(Year), \"%m\"(Month), \"%b\"(Short name of month), \"%B\"(Long name of month), \"%d\"(Day), \"%a\"(Short name of day of week), \"%A\"(Long name of day of week).</p>" unless @conf.mobile_agent?}
+	<p><input name="date_format" value="#{h @conf.date_format}" size="30"></p>
 	<h3 class="subtitle">Max dates of Latest diaplay</h3>
 	#{"<p>In the Latest mode, you can specify the number of days in the page.</p>" unless @conf.mobile_agent?}
-	<p><input name="latest_limit" value="#{@conf.latest_limit}" size="2"> days in a page.</p>
+	<p><input name="latest_limit" value="#{h @conf.latest_limit}" size="2"> days in a page.</p>
 	<h3 class="subtitle">My old days</h3>
 	#{"<p>Show the link of \"My old days\"</p>" unless @conf.mobile_agent?}
 	<p><select name="show_nyear">
-		<option value="true"#{if @conf.show_nyear then " selected" end}>Show</option>
-        <option value="false"#{if not @conf.show_nyear then " selected" end}>Hide</option>
+		<option value="true"#{" selected" if @conf.show_nyear}>Show</option>
+		<option value="false"#{" selected" unless @conf.show_nyear}>Hide</option>
 	</select></p>
 	HTML
 end
 
+# timezone
+add_conf_proc( 'timezone', 'Time difference adjustment', 'update' ) do
+	saveconf_timezone
+	<<-HTML
+	<h3 class="subtitle">Time difference adjustment</h3>
+	#{"<p>When updating diary, you can adjust date which is automatically inserted into the form. The unit is hour. For example, if you want to handle the time until 2 a.m. as the previous day, you set this to -2. tDiary inserts the date which is older by 2 hours than the actual time. </p>" unless @conf.mobile_agent?}
+	<p><input name="hour_offset" value="#{h @conf.hour_offset}" size="5"></p>
+	HTML
+end
+
 # themes
 @theme_location_comment = "<p>You can get many themes from <a href=\"http://www.tdiary.org/20021001.html\">Theme Gallery</a>(Japanese).</p>"
+@theme_thumbnail_label = "Thumbnail"
 
-add_conf_proc( 'theme', 'Themes' ) do
+add_conf_proc( 'theme', 'Themes', 'theme' ) do
 	saveconf_theme
 
-	 r = <<-HTML
+	r = <<-HTML
 	<h3 class="subtitle">Theme</h3>
 	#{"<p>Specify the design of your diary using Theme or CSS. When you select \"CSS specify\", input URL of CSS into the field right side.</p>" unless @conf.mobile_agent?}
 	<p>
-	<select name="theme">
+	<select name="theme" onChange="changeTheme( theme_thumbnail, this )">
 		<option value="">CSS Specify-&gt;</option>
 	HTML
-	@conf_theme_list.each do |theme|
-		r << %Q|<option value="#{theme[0]}"#{if theme[0] == @conf.theme then " selected" end}>#{theme[1]}</option>|
-	end
-	r << <<-HTML
-	</select>
-	<input name="css" size="50" value="#{ @conf.css }">
-	</p>
-	#{@theme_location_comment unless @conf.mobile_agent?}
-	HTML
+	r << conf_theme_list
 end
 
 # comments
-add_conf_proc( 'comment', 'TSUKKOMI' ) do
+add_conf_proc( 'comment', 'TSUKKOMI', 'tsukkomi' ) do
 	saveconf_comment
 
 	<<-HTML
 	<h3 class="subtitle">Show TSUKKOMI</h3>
 	#{"<p>Select show or hide TSUKKOMI from readers</p>" unless @conf.mobile_agent?}
 	<p><select name="show_comment">
-		<option value="true"#{if @conf.show_comment then " selected" end}>Show</option>
-		<option value="false"#{if not @conf.show_comment then " selected" end}>Hide</option>
+		<option value="true"#{" selected" if @conf.show_comment}>Show</option>
+		<option value="false"#{" selected" unless @conf.show_comment}>Hide</option>
 	</select></p>
 	<h3 class="subtitle">Number of TSUKKOMI</h3>
 	#{"<p>In Latest or Month mode, you can specify number of visible TSUKKOMIs. So in Dayly mode, all of TSUKKOMIs are shown.</p>" unless @conf.mobile_agent?}
-	<p><input name="comment_limit" value="#{ @conf.comment_limit }" size="3"> TSUKKOMIs</p>
-	HTML
-end
-
-# referer
-add_conf_proc( 'referer', "Today's Link" ) do
-	saveconf_referer
-
-	<<-HTML
-	<h3 class="subtitle">Show links</h3>
-	#{"<p>Select show or hide about Today's Link</p>" unless @conf.mobile_agent?}
-	<p><select name="show_referer">
-		<option value="true"#{if @conf.show_referer then " selected" end}>Show</option>
-		<option value="false"#{if not @conf.show_referer then " selected" end}>Hide</option>
-	</select></p>
-	<h3 class="subtitle">Number of Links</h3>
-	#{"<p>In Latest or Month mode, you can specify number of visible Link list. So in Dayly mode, all of Link are shown.</p>" unless @conf.mobile_agent?}
-	<p><input name="referer_limit" value="#{@conf.referer_limit}" size="3"> sites</p>
-	<h3 class="subtitle">Control Links saving</h3>
-	#{"<p>Specify which saving only day mode. It means reducing 'referer noise' by access from 'Link page'.</p>" unless @conf.mobile_agent?}
-	<p><select name="referer_day_only">
-		<option value="true"#{if @conf.referer_day_only then " selected" end}>Save links only in day mode</option>
-		<option value="false"#{if not @conf.referer_day_only then " selected" end}>Save links in all access</option>
-	</select></p>
-	<h3 class="subtitle">Excluding list</h3>
-	#{"<p>List of excluding URL that is not recorded to Today's Link. Specify it in regular expression, and a URL into a line.</p>" unless @conf.mobile_agent?}
-	<p>See <a href="#{@conf.update}?referer=no" target="referer">Default configuration is here</a>.</p>
-	<p><textarea name="no_referer" cols="70" rows="10">#{@conf.no_referer2.join( "\n" )}</textarea></p>
-	<h3 class="subtitle">Rule of conversion URL to words.</h3>
-	#{"<p>A table to convert URL to words in Today's Link. Specify it in regular expression, and a URL into a line.<p>" unless @conf.mobile_agent?}
-	<p>See <a href="#{@conf.update}?referer=table" target="referer">Default configurations</a>.</p>
-	<p><textarea name="referer_table" cols="70" rows="10">#{@conf.referer_table2.collect{|a|a.join( " " )}.join( "\n" )}</textarea></p>
+	<p><input name="comment_limit" value="#{h @conf.comment_limit}" size="3"> TSUKKOMIs</p>
+	<h3 class="subtitle">Limit of TSUKKOMI per a day</h3>
+	#{"<p>When numbers of TSUKKOMI over this value in a day, nobody can make new TSUKKOMI. If you use TrackBack plugin, this value means sum of TSUKKOMIs and TrackBacks.</p>" unless @conf.mobile_agent?}
+	<p><input name="comment_limit_per_day" value="#{h @conf.comment_limit_per_day}" size="3"> TSUKKOMIs</p>
 	HTML
 end
 
@@ -244,31 +266,28 @@ def comment_mail_conf_label; 'TSUKKOMI Mail'; end
 def comment_mail_basic_html
 	@conf['comment_mail.header'] = '' unless @conf['comment_mail.header']
 	@conf['comment_mail.receivers'] = '' unless @conf['comment_mail.receivers']
+	@conf['comment_mail.sendhidden'] = false unless @conf['comment_mail.sendhidden']
 
 	<<-HTML
 	<h3 class="subtitle">Notify TSUKKOMI by E-mail</h3>
 	#{"<p>Select notify or not when your diary gets a new TSUKKOMI. So TSUKKOMI mail need SMTP server settings in tdiary.conf.</p>" unless @conf.mobile_agent?}
 	<p><select name="comment_mail.enable">
-		<option value="true"#{if @conf['comment_mail.enable'] then " selected" end}>Send Mail</option>
-        <option value="false"#{if not @conf['comment_mail.enable'] then " selected" end}>Don't Send</option>
+		<option value="true"#{" selected" if @conf['comment_mail.enable']}>Send Mail</option>
+        <option value="false"#{" selected" unless @conf['comment_mail.enable']}>Don't Send</option>
 	</select></p>
 	<h3 class="subtitle">Receivers</h3>
 	#{"<p>Sepecify receivers of TSUKKOMI mail, 1 address per 1 line. If you dose not specify, TSUKKOMI mails will be sent to your address.</p>" unless @conf.mobile_agent?}
-	<p><textarea name="comment_mail.receivers" cols="40" rows="3">#{CGI::escapeHTML( @conf['comment_mail.receivers'].gsub( /[, ]+/, "\n") )}</textarea></p>
+	<p><textarea name="comment_mail.receivers" cols="40" rows="3">#{h( @conf['comment_mail.receivers'].gsub( /[, ]+/, "\n") )}</textarea></p>
 	<h3 class="subtitle">Mail header</h3>
 	#{"<p>Specify a string insert to beginning of mail subject. The subject have a style of \"your_specified_string:DATE-SERIAL NAME\". \"date\" is formatted as same as diary's date you specified. But when you specify another date style in this string, subject style is changed to \"your_specified_string-SERIAL NAME\" (ex: \"hoge:%Y-%m-%d\")</p>" unless @conf.mobile_agent?}
-	<p><input name="comment_mail.header" value="#{CGI::escapeHTML( @conf['comment_mail.header'])}"></p>
+	<p><input name="comment_mail.header" value="#{h @conf['comment_mail.header']}"></p>
+	<h3 class="subtitle">About hidden TSUKKOMI</h3>
+	#{"<p>Some TSUKKOMI are hidden by filters. You can decide which sending E-mail by hidden TSUKKOMI.</p>" unless @conf.mobile_agent?}
+	<p><label for="comment_mail.sendhidden"><input type="checkbox" id="comment_mail.sendhidden" name="comment_mail.sendhidden" value="#{" checked" if @conf['comment_mail.sendhidden']}">Send mail by hidden TSUKKOMI</label></p>
 	HTML
 end
 
-#
-# link to HOWTO write diary
-#
-def style_howto
-	%Q|/<a href="http://docs.tdiary.org/en/?#{@conf.style}Style">How to write</a>|
-end
-
-add_conf_proc( 'csrf_protection', 'CSRF Protection' ) do
+add_conf_proc( 'csrf_protection', 'CSRF Protection', 'security' ) do
 	err = saveconf_csrf_protection
 	errstr = ''
 	case err
@@ -321,13 +340,13 @@ add_conf_proc( 'csrf_protection', 'CSRF Protection' ) do
 	forged requests will not be granted. To enable this feature, you must specify the secret key below.
 	To allow Referer-disabled browsers, you must enable this setting.</p>" unless @conf.mobile_agent?}
 	<h4>CSRF protection key</h4>
-	<p><input type="text" name="key" value="#{CGI::escapeHTML csrf_protection_key}" size="20"></p>
+	<p><input type="text" name="key" value="#{h csrf_protection_key}" size="20"></p>
 	#{"<p>A secret key used for key-based CSRF protection. Specify a secret string which is not easy to guess.
 	If this key is leaked, CSRF attacks can be exploited.
 	Do not use any passwords used in other places. You need not to remember this phrase to type in.</p>" unless @conf.mobile_agent?}
 	#{"<p class=\"message\">Caution: 
 	Your browser seems not to be sending any Referers, although Referer-based protection is enabled.
-	<a href=\"#{@conf.update}?conf=csrf_protection\">Please open this page again via this link</a>.
+	<a href=\"#{h @update}?conf=csrf_protection\">Please open this page again via this link</a>.
 	If you see this message again, you must either change your browser setting (temporarily to change these settings, at least),
 	or edit \"tdiary.conf\" directly.</p>" if [1,3].include?(csrf_protection_method) && ! @cgi.referer && !@cgi.valid?('referer_exists')}
 	</div>
