@@ -9,7 +9,7 @@
 # header
 #
 def title_tag
-	r = "<title>#{CGI::escapeHTML( @html_title )}"
+	r = "<title>#{h @html_title}"
 	case @mode
 	when 'day', 'comment'
 		r << "(#{@date.strftime( '%Y-%m-%d' )})" if @date
@@ -29,7 +29,7 @@ def title_tag
 		r << '(괰λ)'
 	when 'nyear'
 		years = @diaries.keys.map {|ymd| ymd.sub(/^\d{4}/, "")}
-		r << "(#{@cgi.params['date'][0].sub( /^(\d\d)/, '\1-')}[#{nyear_diary_label @date, years}])" if @date
+		r << "(#{h @cgi.params['date'][0].sub( /^(\d\d)/, '\1-')}[#{nyear_diary_label @date, years}])" if @date
 	end
 	r << '</title>'
 end
@@ -49,20 +49,24 @@ def comment_mail_conf_label; 'ĥåߥ᡼'; end
 def comment_mail_basic_html
 	@conf['comment_mail.header'] = '' unless @conf['comment_mail.header']
 	@conf['comment_mail.receivers'] = '' unless @conf['comment_mail.receivers']
+	@conf['comment_mail.sendhidden'] = false unless @conf['comment_mail.sendhidden']
 
 	<<-HTML
 	<h3 class="subtitle">ĥåߥ᡼</h3>
 	#{"<p>ĥåߤäˡ᡼뤫ɤ򤷤ޤ</p>" unless @conf.mobile_agent?}
 	<p><select name="comment_mail.enable">
-		<option value="true"#{if @conf['comment_mail.enable'] then " selected" end}></option>
-        <option value="false"#{if not @conf['comment_mail.enable'] then " selected" end}>ʤ</option>
+		<option value="true"#{" selected" if @conf['comment_mail.enable']}></option>
+        <option value="false"#{" selected" unless @conf['comment_mail.enable']}>ʤ</option>
 	</select></p>
 	<h3 class="subtitle"></h3>
 	#{"<p>᡼ꤷޤ1Ԥ1᡼륢ɥ쥹ηǡʣǽǤΤʤˤϡʤΥ᡼륢ɥ쥹ޤ</p>" unless @conf.mobile_agent?}
-	<p><textarea name="comment_mail.receivers" cols="40" rows="3">#{CGI::escapeHTML( @conf['comment_mail.receivers'].gsub( /[, ]+/, "\n") )}</textarea></p>
+	<p><textarea name="comment_mail.receivers" cols="40" rows="3">#{h( @conf['comment_mail.receivers'].gsub( /[, ]+/, "\n") )}</textarea></p>
 	<h3 class="subtitle">᡼إå</h3>
 	#{"<p>᡼SubjectˤĤإåʸꤷޤʬʤ褦˻ꤷޤºݤSubjectˤϡֻʸ:-1פΤ褦ˡդȥֹ椬դޤʸˡ%³ѻä硢եեޥåȻ򸫤ʤޤĤޤաפʬϼưŪղäʤʤޤ(ֹղäޤ)</p>" unless @conf.mobile_agent?}
-	<p><input name="comment_mail.header" value="#{CGI::escapeHTML( @conf['comment_mail.header'])}"></p>
+	<p><input name="comment_mail.header" value="#{h @conf['comment_mail.header']}"></p>
+	<h3 class="subtitle">ɽĥåߤΰ</h3>
+	#{"<p>ե륿η̡ǽ餫ɽˤ줿ĥåߤϿ뤳ȤޤɽΥĥåߤ褿Ȥˤ᡼ȯ뤫ɤ򤷤ޤ</p>" unless @conf.mobile_agent?}
+	<p><label for="comment_mail.sendhidden"><input type="checkbox" id="comment_mail.sendhidden" name="comment_mail.sendhidden" value="true"#{" checked" if @conf['comment_mail.sendhidden']}>ɽΥĥåߤǤ᡼</label></p>
 	HTML
 end
 
@@ -70,7 +74,24 @@ end
 # link to HOWTO write diary
 #
 def style_howto
-	%Q|/<a href="http://docs.tdiary.org/ja/?#{@conf.style}%A5%B9%A5%BF%A5%A4%A5%EB"></a>|
+	%Q|/<a href="http://docs.tdiary.org/ja/?#{h @conf.style}%A5%B9%A5%BF%A5%A4%A5%EB"></a>|
+end
+
+#
+# convert to UTF-8
+#
+def to_utf8( str, charset = nil )
+	from = case charset
+		when /^utf-8$/i
+			'W'
+		when /^shift_jis/i
+			'S'
+		when /^EUC-JP/i
+			'E'
+		else
+			''
+	end
+	NKF::nkf( "-m0 -#{from}w", str )
 end
 
 #
@@ -80,7 +101,8 @@ def no_diary; "#{@date.strftime( @conf.date_format )}Ϥޤ"; end
 def comment_today; 'Υĥå'; end
 def comment_total( total ); "(#{total})"; end
 def comment_new; 'ĥåߤ'; end
-def comment_description; 'ĥåߡȤФɤ! E-mailɥ쥹ϸޤ'; end
+def comment_description_default; 'ĥåߡȤФɤ! E-mailɥ쥹ϸޤ'; end
+def comment_limit_label; 'ϥĥå߿¤ۤƤޤ'; end
 def comment_description_short; 'ĥå!!'; end
 def comment_name_label; '̾'; end
 def comment_name_label_short; '̾'; end
@@ -91,7 +113,6 @@ def comment_body_label_short; 'ʸ'; end
 def comment_submit_label; ''; end
 def comment_submit_label_short; ''; end
 def comment_date( time ); time.strftime( "(#{@date_format} %H:%M)" ); end
-def referer_today; 'Υ󥯸'; end
 def trackback_today; 'TrackBacks'; end
 def trackback_total( total ); "(#{total})"; end
 
@@ -103,8 +124,12 @@ def navi_edit; "Խ"; end
 def navi_preference; ""; end
 def navi_prev_diary(date); "(#{date.strftime(@date_format)})"; end
 def navi_next_diary(date); "(#{date.strftime(@date_format)})"; end
+def navi_prev_month; ""; end
+def navi_next_month; ""; end
 def navi_prev_nyear(date); "(#{date.strftime('%m-%d')})"; end
 def navi_next_nyear(date); "(#{date.strftime('%m-%d')})"; end
+def navi_prev_ndays; "#{@conf.latest_limit}ʬ"; end
+def navi_next_ndays; "#{@conf.latest_limit}ʬ"; end
 
 def submit_label
 	if @mode == 'form' or @cgi.valid?( 'appendpreview' ) then
@@ -115,9 +140,6 @@ def submit_label
 end
 def preview_label; 'ץӥ塼'; end
 
-def label_no_referer; '󥯸Ͽꥹ'; end
-def label_referer_table; 'ִꥹ'; end
-
 def nyear_diary_label(date, years); "Ĺǯ"; end
 def nyear_diary_title(date, years); "Ĺǯ"; end
 
@@ -126,6 +148,7 @@ def nyear_diary_title(date, years); "Ĺǯ"; end
 #
 def mobile_navi_latest; 'ǿ'; end
 def mobile_navi_update; "ɵ"; end
+def mobile_navi_edit; "Խ"; end
 def mobile_navi_preference; ""; end
 def mobile_navi_prev_diary; ""; end
 def mobile_navi_next_diary; ""; end
@@ -139,135 +162,142 @@ def category_anchor(c); "[#{c}]"; end
 #
 # preferences (resources)
 #
-add_conf_proc( 'default', '' ) do
+
+# genre labels
+@conf_genre_label['basic'] = ''
+@conf_genre_label['update'] = ''
+@conf_genre_label['theme'] = 'ơ'
+@conf_genre_label['tsukkomi'] = 'ĥå'
+@conf_genre_label['referer'] = '󥯸'
+@conf_genre_label['security'] = 'ƥ'
+@conf_genre_label['etc'] = '¾'
+
+
+add_conf_proc( 'default', 'Ȥξ', 'basic' ) do
 	saveconf_default
-	<<-HTML
-	<h3 class="subtitle">̾</h3>
-	#{"<p>ʤ̾ꤷޤHTMLإåŸޤ</p>" unless @conf.mobile_agent?}
-	<p><input name="author_name" value="#{CGI::escapeHTML @conf.author_name}" size="40"></p>
-	<h3 class="subtitle">᡼륢ɥ쥹</h3>
-	#{"<p>ʤΥ᡼륢ɥ쥹ꤷޤHTMLإåŸޤ</p>" unless @conf.mobile_agent?}
-	<p><input name="author_mail" value="#{@conf.author_mail}" size="40"></p>
-	<h3 class="subtitle">ȥåץڡURL</h3>
-	#{"<p>̤ΥƥĤлꤷޤ¸ߤʤϲϤʤƤޤޤ</p>" unless @conf.mobile_agent?}
-	<p><input name="index_page" value="#{@conf.index_page}" size="50"></p>
-	<h3 class="subtitle">Ĵ</h3>
-	#{"<p>եդñ̤ĴǤޤ㤨и2ޤǤȤưˤϡ-2פΤ褦˻ꤹ뤳Ȥǡ2ʬ줿դ褦ˤʤޤޤդWebоλˤʤäƤΤǡΥФǱĤƤλĴˤѤǤޤ</p>" unless @conf.mobile_agent?}
-	<p><input name="hour_offset" value="#{@conf.hour_offset}" size="5"></p>
-	HTML
-end
-
-add_conf_proc( 'header', 'إåեå' ) do
-	saveconf_header
-
+	@conf.description ||= ''
+	@conf.icon ||= ''
+	@conf.banner ||= ''
 	<<-HTML
 	<h3 class="subtitle">ȥ</h3>
 	#{"<p>HTML&lt;title&gt;椪ӡХüλȻ˻Ȥ륿ȥǤHTMLϻȤޤ</p>" unless @conf.mobile_agent?}
-	<p><input name="html_title" value="#{ CGI::escapeHTML @conf.html_title }" size="50"></p>
-	<h3 class="subtitle">إå</h3>
-	#{"<p>ƬʸϤꤷޤHTMLȤޤ&lt;%=navi%&gt;פǡʥӥܥǤޤ(줬ʤȹǤʤʤΤǺʤ褦ˤƤ)ޤ&lt;%=calendar%&gt;פǥǤޤ¾Ƽץ饰򵭽ҤǤޤ</p>" unless @conf.mobile_agent?}
-	<p><textarea name="header" cols="70" rows="10">#{ CGI::escapeHTML @conf.header }</textarea></p>
-	<h3 class="subtitle">եå</h3>
-	#{"<p>κǸʸϤꤷޤإåƱͤ˻Ǥޤ</p>" unless @conf.mobile_agent?}
-	<p><textarea name="footer" cols="70" rows="10">#{ CGI::escapeHTML @conf.footer }</textarea></p>
+	<p><input name="html_title" value="#{h @conf.html_title}" size="50"></p>
+
+	<h3 class="subtitle">̾</h3>
+	#{"<p>ʤ̾ꤷޤHTMLإåŸޤ</p>" unless @conf.mobile_agent?}
+	<p><input name="author_name" value="#{h @conf.author_name}" size="40"></p>
+
+	<h3 class="subtitle">᡼륢ɥ쥹</h3>
+	#{"<p>ʤΥ᡼륢ɥ쥹ꤷޤHTMLإåŸޤ</p>" unless @conf.mobile_agent?}
+	<p><input name="author_mail" value="#{h @conf.author_mail}" size="40"></p>
+
+	<h3 class="subtitle">ȥåץڡURL</h3>
+	#{"<p>̤ΥƥĤлꤷޤ¸ߤʤϲϤʤƤޤޤ</p>" unless @conf.mobile_agent?}
+	<p><input name="index_page" value="#{h @conf.index_page}" size="70"></p>
+
+	<h3 class="subtitle">URL</h3>
+	#{"<p>URLꤷޤURLϡޤޤʥץ饰λؤѤΤǡդʤΤꤷޤ礦</p>" unless @conf.mobile_agent?}
+	#{"<p><strong>ꤷƤͤȡߥURLۤʤޤդƤ</strong></p>" unless @conf.base_url == @conf.base_url_auto}
+	<p><input name="base_url" value="#{h @conf.base_url}" size="70"></p>
+
+	<h3 class="subtitle"></h3>
+	#{"<p>δñꤷޤHTMLإåŸޤϤʤƤ⤫ޤޤ</p>" unless @conf.mobile_agent?}
+	<p><input name="description" value="#{h @conf.description}" size="70"></p>
+
+	<h3 class="subtitle">ȥ(favicon)</h3>
+	#{"<p>ɽʥ(favicon)ФURLꤷޤHTMLإåŸޤϤʤƤ⤫ޤޤ</p>" unless @conf.mobile_agent?}
+	<p><input name="icon" value="#{h @conf.icon}" size="70"></p>
+
+	<h3 class="subtitle">Хʡ</h3>
+	#{"<p>ɽ(Хʡ)ФURLꤷޤmakerssץ饰ʤɤRSSϤʤɤ˻ȤޤϤʤƤ⤫ޤޤ</p>" unless @conf.mobile_agent?}
+	<p><input name="banner" value="#{h @conf.banner}" size="70"></p>
 	HTML
 end
 
-add_conf_proc( 'display', 'ɽ' ) do
+add_conf_proc( 'header', 'إåեå', 'basic' ) do
+	saveconf_header
+
+	<<-HTML
+	<h3 class="subtitle">إå</h3>
+	#{"<p>ƬʸϤꤷޤHTMLȤޤ&lt;%=navi%&gt;פǡʥӥܥǤޤ(줬ʤȹǤʤʤΤǺʤ褦ˤƤ)ޤ&lt;%=calendar%&gt;פǥǤޤ¾Ƽץ饰򵭽ҤǤޤ</p>" unless @conf.mobile_agent?}
+	<p><textarea name="header" cols="70" rows="10">#{h @conf.header}</textarea></p>
+	<h3 class="subtitle">եå</h3>
+	#{"<p>κǸʸϤꤷޤإåƱͤ˻Ǥޤ</p>" unless @conf.mobile_agent?}
+	<p><textarea name="footer" cols="70" rows="10">#{h @conf.footer}</textarea></p>
+	HTML
+end
+
+add_conf_proc( 'display', 'ɽ', 'basic' ) do
 	saveconf_display
 
 	<<-HTML
 	<h3 class="subtitle">󥢥󥫡</h3>
 	#{"<p>ΥƬ(֥ȥιƬ)롢ѤΥ󥫡ʸꤷޤʤ&lt;span class=\"sanchor\"&gt;_&lt;/span&gt;פꤹȡơޤˤäƤϼưŪ˲󥫡Ĥ褦ˤʤޤ</p>" unless @conf.mobile_agent?}
-	<p><input name="section_anchor" value="#{ CGI::escapeHTML @conf.section_anchor }" size="40"></p>
+	<p><input name="section_anchor" value="#{h @conf.section_anchor}" size="40"></p>
 	<h3 class="subtitle">ĥåߥ󥫡</h3>
 	#{"<p>ɼԤΥĥåߤƬ롢ѤΥ󥫡ʸꤷޤʤ&lt;span class=\"canchor\"&gt;_&lt;/span&gt;פꤹȡơޤˤäƤϼưŪ˲󥫡Ĥ褦ˤʤޤ</p>" unless @conf.mobile_agent?}
-	<p><input name="comment_anchor" value="#{ CGI::escapeHTML @conf.comment_anchor }" size="40"></p>
+	<p><input name="comment_anchor" value="#{h @conf.comment_anchor}" size="40"></p>
 	<h3 class="subtitle">եեޥå</h3>
 	#{"<p>դɽʬ˻ȤեޥåȤꤷޤǤդʸȤޤ%פǻϤޤѻˤϼΤ褦üʰ̣ޤ%Y(ǯ)%m()%b(û̾)%B(Ĺ̾)%d()%a(û̾)%A(Ĺ̾)</p>" unless @conf.mobile_agent?}
-	<p><input name="date_format" value="#{ CGI::escapeHTML @conf.date_format }" size="30"></p>
+	<p><input name="date_format" value="#{h @conf.date_format}" size="30"></p>
 	<h3 class="subtitle">ǿɽκ</h3>
 	#{"<p>ǿɽȤˡΥڡ˲ʬɽ뤫ꤷޤ</p>" unless @conf.mobile_agent?}
-	<p><input name="latest_limit" value="#{ @conf.latest_limit }" size="2">ʬ</p>
+	<p><input name="latest_limit" value="#{h @conf.latest_limit}" size="2">ʬ</p>
 	<h3 class="subtitle">Ĺǯɽ</h3>
 	#{"<p>Ĺǯɽ뤿Υ󥯤ɽ뤫ɤꤷޤ</p>" unless @conf.mobile_agent?}
 	<p><select name="show_nyear">
-		<option value="true"#{if @conf.show_nyear then " selected" end}>ɽ</option>
-        <option value="false"#{if not @conf.show_nyear then " selected" end}>ɽ</option>
+		<option value="true"#{" selected" if @conf.show_nyear}>ɽ</option>
+		<option value="false"#{" selected" unless @conf.show_nyear}>ɽ</option>
 	</select></p>
 	HTML
 end
 
-@theme_location_comment = "<p>ˤʤơޤ<a href=\"http://www.tdiary.org/20021001.html\">ơޡ꡼</a>Ǥޤ</p>"
+add_conf_proc( 'timezone', 'Ĵ', 'update' ) do
+	saveconf_timezone
 
-add_conf_proc( 'theme', 'ơ' ) do
-	saveconf_theme
-
-	 r = <<-HTML
-	<h3 class="subtitle">ơޤλ</h3>
-	#{"<p>Υǥơޡ⤷CSSľϤǻꤷޤɥåץ˥塼CSSꢪפ򤷤ˤϡCSSURLϤƤ</p>" unless @conf.mobile_agent?}
-	<p>
-	<select name="theme">
-		<option value="">CSSꢪ</option>
-	HTML
-	@conf_theme_list.each do |theme|
-		r << %Q|<option value="#{theme[0]}"#{if theme[0] == @conf.theme then " selected" end}>#{theme[1]}</option>|
-	end
-	r << <<-HTML
-	</select>
-	<input name="css" size="50" value="#{ @conf.css }">
-	</p>
-	#{@theme_location_comment unless @conf.mobile_agent?}
+	<<-HTML
+	<h3 class="subtitle">Ĵ</h3>
+	#{"<p>եդñ̤ĴǤޤ㤨и2ޤǤȤưˤϡ-2פΤ褦˻ꤹ뤳Ȥǡ2ʬ줿դ褦ˤʤޤޤդWebоλˤʤäƤΤǡΥФǱĤƤλĴˤѤǤޤ</p>" unless @conf.mobile_agent?}
+	<p><input name="hour_offset" value="#{h @conf.hour_offset}" size="5"></p>
 	HTML
 end
 
-add_conf_proc( 'comment', 'ĥå' ) do
+@theme_location_comment = "<p>ˤʤơޤ<a href=\"http://www.tdiary.org/20021001.html\">ơޡ꡼</a>Ǥޤ</p>"
+@theme_thumbnail_label = "ͥ"
+
+add_conf_proc( 'theme', 'ơ', 'theme' ) do
+	saveconf_theme
+
+	r = <<-HTML
+	<h3 class="subtitle">ơޤλ</h3>
+	#{"<p>Υǥơޡ⤷CSSľϤǻꤷޤɥåץ˥塼CSSꢪפ򤷤ˤϡCSSURLϤƤ</p>" unless @conf.mobile_agent?}
+	<p>
+	<select name="theme" onChange="changeTheme( theme_thumbnail, this )">
+		<option value="">CSSꢪ</option>
+	HTML
+	r << conf_theme_list
+end
+
+add_conf_proc( 'comment', 'ĥå', 'tsukkomi' ) do
 	saveconf_comment
 
 	<<-HTML
 	<h3 class="subtitle">ĥåߤɽ</h3>
 	#{"<p>ɼԤΥĥåߤɽ뤫ɤꤷޤ</p>" unless @conf.mobile_agent?}
 	<p><select name="show_comment">
-		<option value="true"#{if @conf.show_comment then " selected" end}>ɽ</option>
-		<option value="false"#{if not @conf.show_comment then " selected" end}>ɽ</option>
+		<option value="true"#{" selected" if @conf.show_comment}>ɽ</option>
+		<option value="false"#{" selected" unless @conf.show_comment}>ɽ</option>
 	</select></p>
 	<h3 class="subtitle">ĥåߥꥹɽ</h3>
 	#{"<p>ǿ⤷Ϸɽɽ롢ĥåߤκꤷޤʤɽˤϤλˤ餺٤ƤΥĥåߤɽޤ</p>" unless @conf.mobile_agent?}
-	<p><input name="comment_limit" value="#{ @conf.comment_limit }" size="3"></p>
+	<p><input name="comment_limit" value="#{h @conf.comment_limit}" size="3"></p>
+	<h3 class="subtitle">1Υĥåߺ</h3>
+	#{"<p>1˽񤭹ĥåߤκꤷޤοĶȡĥåѤΥեबɽˤʤޤʤTrackBackץ饰ƤˤϡĥåߤTrackBackιפ¤ޤ</p>" unless @conf.mobile_agent?}
+	<p><input name="comment_limit_per_day" value="#{h @conf.comment_limit_per_day}" size="3"></p>
 	HTML
 end
 
-add_conf_proc( 'referer', '󥯸' ) do
-	saveconf_referer
-
-	<<-HTML
-	<h3 class="subtitle">󥯸ɽ</h3>
-	#{"<p>󥯸ꥹȤɽ뤫ɤꤷޤ</p>" unless @conf.mobile_agent?}
-	<p><select name="show_referer">
-		<option value="true"#{if @conf.show_referer then " selected" end}>ɽ</option>
-		<option value="false"#{if not @conf.show_referer then " selected" end}>ɽ</option>
-	</select></p>
-	<h3 class="subtitle">󥯸ꥹɽ</h3>
-	#{"<p>ǿ⤷Ϸɽɽ롢󥯸ꥹȤκꤷޤʤɽˤϤλˤ餺٤ƤΥ󥯸ɽޤ</p>" unless @conf.mobile_agent?}
-	<p><input name="referer_limit" value="#{@conf.referer_limit}" size="3"></p>
-	<h3 class="subtitle">󥯸εϿ</h3>
-	#{"<p>ջΥΥ󥯸Ͽ뤫ɤꤷޤλ򤹤ȥƥʤ󥯽ξ󤬵ϿʤʤΤǡ󥯸ΥΥޤ</p>" unless @conf.mobile_agent?}
-	<p><select name="referer_day_only">
-		<option value="true"#{if @conf.referer_day_only then " selected" end}>ջΥΤߵϿ</option>
-		<option value="false"#{if not @conf.referer_day_only then " selected" end}>٤ƤΥǵϿ</option>
-	</select></p>
-	<h3 class="subtitle">󥯸Ͽꥹ</h3>
-	#{"<p>󥯸ꥹȤɲäʤURLꤷޤɽǻǤޤ11ԤϤƤ</p>" unless @conf.mobile_agent?}
-	<p><a href="#{@conf.update}?referer=no" target="referer">¸Ϥ</a></p>
-	<p><textarea name="no_referer" cols="70" rows="10">#{@conf.no_referer2.join( "\n" )}</textarea></p>
-	<h3 class="subtitle">󥯸ִꥹ</h3>
-	#{"<p>󥯸ꥹȤURLʸѴбɽǤޤ1ˤĤURLɽʸǶڤäƻꤷޤɽȤΤǡURL˸줿()פϡִʸǡ\\1פΤ褦ʡ\פѤǤޤ</p>" unless @conf.mobile_agent?}
-	<p><a href="#{@conf.update}?referer=table" target="referer">¸Ϥ</a></p>
-	<p><textarea name="referer_table" cols="70" rows="10">#{@conf.referer_table2.collect{|a|a.join( " " )}.join( "\n" )}</textarea></p>
-	HTML
-end
-
-add_conf_proc( 'csrf_protection', 'CSRF(ü)к' ) do
+add_conf_proc( 'csrf_protection', 'CSRF(ü)к', 'security' ) do
 	err = saveconf_csrf_protection
 	errstr = ''
 	case err
@@ -335,13 +365,13 @@ add_conf_proc( 'csrf_protection', 'CSRF(ü)к' ) do
 	ץ饰ưʤʤ뤳Ȥޤ</p>
 	" unless @conf.mobile_agent?}
 	<h4>CSRF ɻߥ</h4>
-	<p><input type="text" name="key" value="#{CGI::escapeHTML csrf_protection_key}" size="30"></p>
+	<p><input type="text" name="key" value="#{h csrf_protection_key}" size="30"></p>
 	#{"<p>ɻߥꤷޤ¬ˤŬʸꤷƲ
 	θ˱̤ȡCSRFǽޤ
 	¾ΥѥɤȶѤϤƤϤޤ󡣤ʤꤷʸ򤢤ʤФƤɬפϤޤ</p>" unless @conf.mobile_agent?}
 	#{"<p class=\"message\">: 
 	ʤΥ֥饦ϸRefererФƤʤ褦Ǥ
-	<a href=\"#{@conf.update}?conf=csrf_protection\">Υ󥯤⤦
+	<a href=\"#{h @update}?conf=csrf_protection\">Υ󥯤⤦
 	Υڡ򳫤ƤߤƲ</a>
 	Ǥ⤳ΥåФǤϡѤ硢
 	ŪRefererФˤ뤫
