@@ -1,26 +1,22 @@
 =begin
 == NAME
 tDiary: the "tsukkomi-able" web diary system.
-tdiary.rb $Revision: 1.195.2.13 $
+tdiary.rb $Revision: 1.339 $
 
-Copyright (C) 2001-2005, TADA Tadashi <sho@spc.gr.jp>
+Copyright (C) 2001-2007, TADA Tadashi <sho@spc.gr.jp>
 You can redistribute it and/or modify it under GPL2.
 =end
 
-TDIARY_VERSION = '2.0.4'
+TDIARY_VERSION = '2.2.1'
+
+$:.insert( 1, File::dirname( __FILE__ ) + '/misc/lib' )
 
 require 'cgi'
 require 'uri'
 begin
 	require 'erb_fast'
-	ERbLight = ERB
 rescue LoadError
-	begin
-		require 'erb'
-		ERbLight = ERB
-	rescue LoadError
-		require 'erb/erbl'
-	end
+	require 'erb'
 end
 
 =begin
@@ -62,6 +58,40 @@ class CGI
 	def mobile_agent?
 		self.user_agent =~ %r[(DoCoMo|J-PHONE|Vodafone|MOT-|UP\.Browser|DDIPOCKET|ASTEL|PDXGW|Palmscape|Xiino|sharp pda browser|Windows CE|L-mode|WILLCOM|SoftBank)]i
 	end
+
+	def https?
+		return false if env_table['HTTPS'].nil? or /off/i =~ env_table['HTTPS']
+		true
+	end
+
+	def request_uri
+		_request_uri = env_table['REQUEST_URI']
+		_script_name = env_table['SCRIPT_NAME']
+		if !_request_uri || _request_uri == '' || _request_uri == _script_name then
+			_path_info    = env_table['PATH_INFO'] || ''
+			_query_string = env_table['QUERY_STRING'] || ''
+			# Workaround for IIS-style PATH_INFO ('/dir/script.cgi/path', not '/path')
+			# See http://support.microsoft.com/kb/184320/
+			_request_uri = _path_info.include?(_script_name) ? '' : _script_name.dup
+			_request_uri << _path_info
+			_request_uri << '?' + _query_string if _query_string != ''
+		end
+		_request_uri
+	end
+
+	def redirect_url
+		env_table['REDIRECT_URL']
+	end
+
+	if RUBY_VERSION >= '1.8.0' && RUBY_VERSION < '1.8.2'
+		module QueryExtension
+			%w[ CONTENT_LENGTH SERVER_PORT ].each do |env|
+				define_method(env.sub(/^HTTP_/n, '').downcase) do
+					(val = env_table[env]) && Integer(val)
+				end
+			end
+		end
+	end
 end
 
 =begin
@@ -96,12 +126,12 @@ module TDiary
 	#
 	class Comment
 		attr_reader :name, :mail, :body, :date
-	
+
 		def initialize( name, mail, body, date = Time::now )
 			@name, @mail, @body, @date = name, mail, body, date
 			@show = true
 		end
-	
+
 		def shorten( length = 120 )
 			matched = body.gsub( /\n/, ' ' ).scan( /^.{0,#{length - 2}}/ )[0]
 			unless $'.empty? then
@@ -113,7 +143,7 @@ module TDiary
 
 		def visible?; @show; end
 		def show=( s ); @show = s; end
-	
+
 		def ==( c )
 			(@name == c.name) and (@mail == c.mail) and (@body == c.body)
 		end
@@ -131,7 +161,7 @@ module TDiary
 		def init_comments
 			@comments = []
 		end
-	
+
 	public
 		def add_comment( com )
 			@comments << com
@@ -140,7 +170,7 @@ module TDiary
 			end
 			com
 		end
-	
+
 		def count_comments( all = false )
 			i = 0
 			@comments.each do |comment|
@@ -148,14 +178,14 @@ module TDiary
 			end
 			i
 		end
-	
-		def each_comment( limit = 3 )
+
+		def each_comment( limit = -1 )
 			@comments.each_with_index do |com,idx|
-				break if idx >= limit
+				break if idx >= limit and limit >= 0
 				yield com
 			end
 		end
-	
+
 		def each_comment_tail( limit = 3 )
 			idx = 0
 			comments = @comments.collect {|c|
@@ -172,29 +202,30 @@ module TDiary
 				yield comments[idx][0], comments[idx][1] # idx is start with 1.
 			end
 		end
-	
-		def each_visible_comment( limit = 3 )
+
+		def each_visible_comment( limit = -1 )
 			@comments.each_with_index do |com,idx|
-				break if idx >= limit
+				break if idx >= limit and limit >= 0
 				next unless com.visible?
 				yield com,idx+1 # idx is start with 1.
 			end
 		end
-	
-		def each_visible_trackback( limit = 3 )
+
+		def each_visible_trackback( limit = -1 )
 			i = 0
-			@comments.find_all {|com|
-				com.visible_true? and /^(Track|Ping)Back$/ =~ com.name
-			}[0,limit].each do |com|
-				i += 1 # i starts with 1.
-				yield com,i
+			@comments.each do |com|
+				break if i >= limit and limit >= 0
+				next unless /^TrackBack$/ =~ com.name
+				next unless com.visible_true?
+				i += 1
+				yield com, i
 			end
 		end
-	
+
 		def each_visible_trackback_tail( limit = 3 )
 			i = 0
 			@comments.find_all {|com|
-				com.visible_true? and /^(Track|Ping)Back$/ =~ com.name
+				com.visible_true? and /^TrackBack$/ =~ com.name
 			}.reverse[0,limit].reverse.each do |com|
 				i += 1 # i starts with 1.
 				yield com,i
@@ -215,7 +246,7 @@ module TDiary
 			@referers = {}
 			@new_referer = true # for compatibility
 		end
-	
+
 	public
 		def add_referer( ref, count = 1 )
 			newer_referer
@@ -231,11 +262,15 @@ module TDiary
 				@referers[uref] = [count, ref]
 			end
 		end
-	
+
+		def clear_referers
+			@referers = {}
+		end
+
 		def count_referers
 			@referers.size
 		end
-	
+
 		def each_referer( limit = 10 )
 			newer_referer
 			@referers.values.sort.reverse.each_with_index do |ary,idx|
@@ -243,7 +278,7 @@ module TDiary
 				yield ary[0], ary[1]
 			end
 		end
-	
+
 	private
 		def newer_referer
 			unless @new_referer then # for compatibility
@@ -264,8 +299,24 @@ module TDiary
 	#
 	module Filter
 		class Filter
+			DEBUG_NONE = 0
+			DEBUG_SPAM = 1
+			DEBUG_FULL = 2
+
 			def initialize( cgi, conf )
 				@cgi, @conf = cgi, conf
+
+				if @conf.options.include?('filter.debug_mode')
+					@debug_mode = @conf.options['filter.debug_mode']
+				else
+					@debug_mode = DEBUG_NONE
+				end
+
+				if @conf.options.include?('filter.debug_file')
+					@debug_file = @conf.options['filter.debug_file']
+				else
+					@debug_file = nil
+				end
 			end
 
 			def comment_filter( diary, comment )
@@ -275,27 +326,39 @@ module TDiary
 			def referer_filter( referer )
 				true
 			end
+
+			def debug( msg, level = DEBUG_SPAM )
+				return if @debug_mode == DEBUG_NONE
+				return if @debug_mode == DEBUG_SPAM and level == DEBUG_FULL
+
+				require 'time'
+				File.open( @debug_file, 'a' ) do |io|
+					io.flock(File::LOCK_EX)
+					io.puts "#{Time.now.iso8601}: #{@cgi.remote_addr}->#{(@cgi.params['date'][0] || 'no date').dump}: #{msg}"
+				end
+			end
 		end
 	end
-	
+
 	#
 	# module DiaryBase
 	#  Base module of Diary.
 	#
 	module DiaryBase
+		include ERB::Util
 		include CommentManager
 		include RefererManager
-	
+
 		def init_diary
 			init_comments
 			init_referers
 			@show = true
 		end
-	
+
 		def date
 			@date
 		end
-	
+
 		def set_date( date )
 			if date.class == String then
 				y, m, d = date.scan( /^(\d{4})(\d\d)(\d\d)$/ )[0]
@@ -305,34 +368,34 @@ module TDiary
 				@date = date
 			end
 		end
-	
+
 		def title
 			@title || ''
 		end
-	
+
 		def set_title( title )
 			@title = title
 			@last_modified = Time::now
 		end
-	
+
 		def show( s )
 			@show = s
 		end
-	
+
 		def visible?
 			@show != false;
 		end
-	
+
 		def last_modified
 			@last_modified ? @last_modified : Time::at( 0 )
 		end
-	
+
 		def last_modified=( lm )
 			@last_modified  = lm
 		end
-	
+
 		def eval_rhtml( opt, path = '.' )
-			ERbLight::new( File::open( "#{path}/skel/#{opt['prefix']}diary.rhtml" ){|f| f.read }.untaint ).result( binding )
+			ERB::new( File::open( "#{path}/skel/#{opt['prefix']}diary.rhtml" ){|f| f.read }.untaint ).result( binding )
 		end
 	end
 
@@ -352,7 +415,7 @@ module TDiary
 		def calendar
 			raise StandardError, 'not implemented'
 		end
-		
+
 		def transaction( date )
 			raise StandardError, 'not implemented'
 		end
@@ -361,11 +424,11 @@ module TDiary
 			raise StandardError, 'not implemented'
 		end
 
-		def styled_diary_factory( date, title, body, style = 'tDiary' )
-			if style_class = style( style.downcase )
+		def styled_diary_factory( date, title, body, style_name = 'tDiary' )
+			if style_class = style( style_name.downcase )
 				return style_class::new( date, title, body )
 			else
-				raise BadStyleError, "bad style: #{style}"
+				raise BadStyleError, "bad style: #{style_name}"
 			end
 		end
 
@@ -398,7 +461,8 @@ module TDiary
 	#  configuration class
 	#
 	class Config
-		def initialize
+		def initialize(cgi)
+			@cgi = cgi
 			load
 
 			instance_variables.each do |v|
@@ -414,14 +478,14 @@ module TDiary
 				)
 			end
 
-			bot = ["googlebot", "Hatena Antenna", "moget@goo.ne.jp"]
+			bot = ["bot", "spider", "antenna", "crawler", "moget", "slurp"]
 			bot += @options['bot'] || []
 			@bot = Regexp::new( "(#{bot.uniq.join( '|' )})", true )
 		end
 
 		# saving to tdiary.conf in @data_path
 		def save
-			result = ERbLight::new( File::open( "#{PATH}/skel/tdiary.rconf" ){|f| f.read }.untaint ).result( binding )
+			result = ERB::new( File::open( "#{PATH}/skel/tdiary.rconf" ){|f| f.read }.untaint ).result( binding )
 			result.untaint unless @secure
 			Safe::safe( @secure ? 4 : 1 ) do
 				eval( result, binding, "(TDiary::Config#save)", 1 )
@@ -432,11 +496,11 @@ module TDiary
 		end
 
 		def mobile_agent?
-			%r[(DoCoMo|J-PHONE|Vodafone|MOT-|UP\.Browser|DDIPOCKET|ASTEL|PDXGW|Palmscape|Xiino|sharp pda browser|Windows CE|L-mode)]i =~ ENV['HTTP_USER_AGENT']
+			@cgi.mobile_agent?
 		end
 
 		def bot?
-			@bot =~ ENV['HTTP_USER_AGENT']
+			@bot =~ @cgi.user_agent
 		end
 
 		#
@@ -454,15 +518,25 @@ module TDiary
 			@options.delete( key )
 			@options2.delete( key )
 		end
-	
+
 		def base_url
-			return '' unless ENV['SCRIPT_NAME']
-			if ENV['HTTPS']
-				port = (ENV['SERVER_PORT'] == '443') ? '' : ':' + ENV['SERVER_PORT'].to_s
-				"https://#{ ENV['SERVER_NAME'] }#{ port }#{File::dirname(ENV['SCRIPT_NAME'])}/"
+			begin
+				if @options['base_url'].length > 0 then
+					return @options['base_url']
+				end
+			rescue
+			end
+			base_url_auto
+		end
+
+		def base_url_auto
+			return '' unless @cgi.script_name
+			if @cgi.https?
+				port = (@cgi.server_port == 443) ? '' : ':' + @cgi.server_port.to_s
+				"https://#{ @cgi.server_name }#{ port }#{File::dirname(@cgi.script_name)}/"
 			else
-				port = (ENV['SERVER_PORT'] == '80') ? '' : ':' + ENV['SERVER_PORT'].to_s
-				"http://#{ ENV['SERVER_NAME'] }#{ port }#{File::dirname(ENV['SCRIPT_NAME'])}/"
+				port = (@cgi.server_port == 80) ? '' : ':' + @cgi.server_port.to_s
+				"http://#{ @cgi.server_name }#{ port }#{File::dirname(@cgi.script_name)}/"
 			end.sub(%r|/+$|, '/')
 		end
 
@@ -481,7 +555,7 @@ module TDiary
 				@lang = 'ja'
 				retry
 			end
-	
+
 			@data_path += '/' if /\/$/ !~ @data_path
 			@style = 'tDiary' unless @style
 			@index = './' unless @index
@@ -495,7 +569,7 @@ module TDiary
 			@html_title = '' unless @html_title
 			@header = '' unless @header
 			@footer = '' unless @footer
-	
+
 			@section_anchor = '<span class="sanchor">_</span>' unless @section_anchor
 			@comment_anchor = '<span class="canchor">_</span>' unless @comment_anchor
 			@date_format = '%Y-%m-%d' unless @date_format
@@ -507,13 +581,17 @@ module TDiary
 
 			@show_comment = true unless defined?( @show_comment )
 			@comment_limit = 3 unless @comment_limit
+			@comment_limit_per_day = 100 unless @comment_limit_per_day
 
 			@show_referer = true unless defined?( @show_referer )
 			@referer_limit = 10 unless @referer_limit
-			@referer_day_only = false unless defined?( @referer_day_only )
+			@referer_day_only = true unless defined?( @referer_day_only )
 			@no_referer = [] unless @no_referer
 			@no_referer2 = [] unless @no_referer2
 			@no_referer = @no_referer2 + @no_referer
+			@only_volatile = [] unless @only_volatile
+			@only_volatile2 = [] unless @only_volatile2
+			@only_volatile = @only_volatile2 + @only_volatile
 			@referer_table = [] unless @referer_table
 			@referer_table2 = [] unless @referer_table2
 			@referer_table = @referer_table2 + @referer_table
@@ -533,17 +611,19 @@ module TDiary
 		# loading tdiary.conf in @data_path.
 		def load_cgi_conf
 			raise TDiaryError, 'No @data_path variable.' unless @data_path
-	
+
 			@data_path += '/' if /\/$/ !~ @data_path
 			raise TDiaryError, 'Do not set @data_path as same as tDiary system directory.' if @data_path == "#{PATH}/"
-	
+
 			variables = [
-				:author_name, :author_mail, :index_page, :hour_offset,
-				:html_title, :header, :footer,
+				:html_title, :author_name, :author_mail, :index_page, :hour_offset,
+				:description, :icon, :banner,
+				:header, :footer,
 				:section_anchor, :comment_anchor, :date_format, :latest_limit, :show_nyear,
 				:theme, :css,
-				:show_comment, :comment_limit, :mail_on_comment, :mail_header,
-				:show_referer, :referer_limit, :referer_day_only, :no_referer2, :referer_table2,
+				:show_comment, :comment_limit, :comment_limit_per_day,
+				:mail_on_comment, :mail_header,
+				:show_referer, :no_referer2, :only_volatile2, :referer_table2,
 				:options2,
 			]
 			begin
@@ -581,18 +661,25 @@ module TDiary
 	#  plugin management class
 	#
 	class Plugin
+		include ERB::Util
 		attr_reader :cookies
 
 		def initialize( params )
 			@header_procs = []
 			@footer_procs = []
 			@update_procs = []
+			@title_procs = []
 			@body_enter_procs = []
 			@body_leave_procs = []
+			@section_index = {}
+			@section_enter_procs = []
+			@subtitle_procs = []
+			@section_leave_procs = []
 			@edit_procs = []
 			@form_procs = []
 			@conf_keys = []
 			@conf_procs = {}
+			@conf_genre_label = {}
 			@cookies = []
 
 			params.each_key do |key|
@@ -652,8 +739,13 @@ module TDiary
 		def eval_src( src, secure )
 			self.taint
 			@conf.taint
+			@title_procs.taint
 			@body_enter_procs.taint
 			@body_leave_procs.taint
+			@section_index.taint
+			@section_enter_procs.taint
+			@subtitle_procs.taint
+			@section_leave_procs.taint
 			return Safe::safe( secure ? 4 : 1 ) do
 				eval( src, binding, "(TDiary::Plugin#eval_src)", 1 )
 			end
@@ -695,6 +787,17 @@ module TDiary
 			''
 		end
 
+		def add_title_proc( block = Proc::new )
+			@title_procs << block
+		end
+
+		def title_proc( date, title )
+			@title_procs.each do |proc|
+				title = proc.call( date, title )
+			end
+			apply_plugin( title )
+		end
+
 		def add_body_enter_proc( block = Proc::new )
 			@body_enter_procs << block
 		end
@@ -719,6 +822,42 @@ module TDiary
 			r.join
 		end
 
+		def add_section_enter_proc( block = Proc::new )
+			@section_enter_procs << block
+		end
+
+		def section_enter_proc( date )
+			@section_index[date] = (@section_index[date] || 0) + 1
+			r = []
+			@section_enter_procs.each do |proc|
+				r << proc.call( date, @section_index[date] )
+			end
+			r.join
+		end
+
+		def add_subtitle_proc( block = Proc::new )
+			@subtitle_procs << block
+		end
+
+		def subtitle_proc( date, subtitle )
+			@subtitle_procs.each do |proc|
+				subtitle = proc.call( date, @section_index[date], subtitle )
+			end
+			apply_plugin( subtitle )
+		end
+
+		def add_section_leave_proc( block = Proc::new )
+			@section_leave_procs << block
+		end
+
+		def section_leave_proc( date )
+			r = []
+			@section_leave_procs.each do |proc|
+				r << proc.call( date, @section_index[date] )
+			end
+			r.join
+		end
+
 		def add_edit_proc( block = Proc::new )
 			@edit_procs << block
 		end
@@ -743,15 +882,30 @@ module TDiary
 			r.join
 		end
 
-		def add_conf_proc( key, label, block = Proc::new )
+		def add_conf_proc( key, label, genre = 'etc', block = Proc::new )
 			return unless @mode =~ /^(conf|saveconf)$/
-			@conf_keys << key unless @conf_keys.index( key )
+			genre_and_key = "#{genre}:#{key}"
+			@conf_keys << genre_and_key unless @conf_keys.index( genre_and_key )
 			@conf_procs[key] = [label, block]
 		end
 
-		def each_conf_key
-			@conf_keys.each do |key|
-				yield key
+		def each_conf_genre
+			genres = {}
+			@conf_keys.each do |genre_and_key|
+				genre, key = genre_and_key.split( /:/, 2 )
+				next if genres[genre]
+				yield genre
+				genres[genre] = key
+			end
+		end
+
+		def each_conf_key( genre )
+			re = /^#{genre}:/
+			@conf_keys.each do |genre_and_key|
+				if re =~ genre_and_key then
+					genre, key = genre_and_key.split( /:/, 2 )
+					yield key
+				end
 			end
 		end
 
@@ -762,11 +916,24 @@ module TDiary
 			r
 		end
 
+		def conf_genre_label( genre )
+			label = @conf_genre_label[genre]
+			label ? label : genre
+		end
+
 		def conf_label( key )
-			label, block = @conf_procs[key]
+			label, = @conf_procs[key]
 			label
 		end
 
+		def conf_current_style( key )
+			if key == @cgi.params['conf'][0] then
+				'selected'
+			else
+				'other'
+			end
+		end
+
 		def add_cookie( cookie )
 			begin
 				@cookies << cookie
@@ -775,16 +942,24 @@ module TDiary
 			end
 		end
 
+		def remove_tag( str )
+			str.gsub( /<[^"'<>]*(?:"[^"]*"[^"'<>]*|'[^']*'[^"'<>]*)*(?:>|(?=<)|$)/, '' )
+		end
+
 		def apply_plugin( str, remove_tag = false )
 			return '' unless str
 			r = str.dup
 			if @options['apply_plugin'] and str.index( '<%' ) then
 				r = str.untaint if $SAFE < 3
 				Safe::safe( @conf.secure ? 4 : 1 ) do
-					r = ERbLight.new( r ).result( binding )
+					begin
+						r = ERB::new( r ).result( binding )
+					rescue Exception
+						r = %Q|<p class="message">Invalid Text</p>#{r}|
+					end
 				end
 			end
-			r.gsub!( /<[^"'<>]*(?:"[^"]*"[^"'<>]*|'[^']*'[^"'<>]*)*(?:>|(?=<)|$)/, '' ) if remove_tag
+			r = remove_tag( r ) if remove_tag
 			r
 		end
 
@@ -804,6 +979,10 @@ module TDiary
 			@conf.bot?
 		end
 
+		def help( name )
+			%Q[<div class="help-icon"><a href="http://docs.tdiary.org/#{h @conf.lang}/?#{h name}" target="_blank"><img src="#{theme_url}/help.png" width="19" height="19" alt="Help"></a></div>]
+		end
+
 		def method_missing( *m )
 			super if @debug
 			# ignore when no plugin
@@ -829,45 +1008,49 @@ module TDiary
 	#  tDiary CGI
 	#
 	class TDiaryBase
+		include ERB::Util
+
 		DIRTY_NONE = 0
 		DIRTY_DIARY = 1
 		DIRTY_COMMENT = 2
 		DIRTY_REFERER = 4
-	
+
 		attr_reader :cookies
 		attr_reader :conf
-	
+		attr_reader :date
+		attr_reader :diaries
+
 		def initialize( cgi, rhtml, conf )
 			@cgi, @rhtml, @conf = cgi, rhtml, conf
 			@diaries = {}
 			@cookies = []
-	
+
 			unless @conf.io_class then
 				require 'tdiary/defaultio'
 				@conf.io_class = DefaultIO
 			end
 			@io = @conf.io_class.new( self )
 		end
-	
+
 		def eval_rhtml( prefix = '' )
 			begin
 				r = do_eval_rhtml( prefix )
 			rescue PluginError, SyntaxError, ArgumentError
-				r = ERbLight::new( File::open( "#{PATH}/skel/plugin_error.rhtml" ) {|f| f.read }.untaint ).result( binding )
+				r = ERB::new( File::open( "#{PATH}/skel/plugin_error.rhtml" ) {|f| f.read }.untaint ).result( binding )
 			rescue Exception
 				raise
 			end
 			return r
 		end
-	
+
 		def restore_parser_cache( date, key )
 			parser_cache( date, key )
 		end
-	
+
 		def store_parser_cache( date, key, obj )
 			parser_cache( date, key, obj )
 		end
-	
+
 		def clear_parser_cache( date )
 			parser_cache( date )
 		end
@@ -875,7 +1058,15 @@ module TDiary
 		def last_modified
 			nil
 		end
-	
+
+		def []( date )
+			@diaries[date.strftime( '%Y%m%d' )]
+		end
+
+		def calendar
+			@years = @io.calendar unless @years
+		end
+
 	protected
 		def do_eval_rhtml( prefix )
 			# load plugin files
@@ -895,8 +1086,8 @@ module TDiary
 						File::open( path ) {|f| f.read }
 					end
 				}.join
-				r = ERbLight::new( rhtml.untaint ).result( binding )
-				r = ERbLight::new( r ).src
+				r = ERB::new( rhtml.untaint ).result( binding )
+				r = ERB::new( r ).src
 				store_cache( r, prefix ) unless @diaries.empty?
 			end
 
@@ -909,7 +1100,7 @@ module TDiary
 		def mode
 			self.class.to_s.sub( /^TDiary::TDiary/, '' ).downcase
 		end
-	
+
 		def load_plugins
 			calendar
 			@plugin = Plugin::new(
@@ -924,31 +1115,27 @@ module TDiary
 				'last_modified' => last_modified
 			)
 		end
-	
-		def []( date )
-			@diaries[date.strftime( '%Y%m%d' )]
-		end
-	
+
 		def <<( diary )
 			@diaries[diary.date.strftime( '%Y%m%d' )] = diary
 		end
-	
+
 		def delete( date )
 			@diaries.delete( date.strftime( '%Y%m%d' ) )
 		end
-	
+
 		def cache_path
 			@conf.cache_path || "#{@conf.data_path}cache"
 		end
-	
+
 		def cache_file( prefix )
 			nil
 		end
-	
+
 		def cache_enable?( prefix )
 			cache_file( prefix ) and FileTest::file?( "#{cache_path}/#{cache_file( prefix )}" )
 		end
-	
+
 		def store_cache( cache, prefix )
 			unless FileTest::directory?( cache_path ) then
 				begin
@@ -963,16 +1150,16 @@ module TDiary
 				end
 			end
 		end
-	
+
 		def clear_cache( target = /.*/ )
 			Dir::glob( "#{cache_path}/*.r[bh]*" ).each do |c|
 				File::delete( c.untaint ) if target =~ c
 			end
 		end
-	
+
 		def parser_cache( date, key = nil, obj = nil )
 			return nil if @ignore_parser_cache
-	
+
 			require 'pstore'
 			unless FileTest::directory?( cache_path ) then
 				begin
@@ -981,7 +1168,7 @@ module TDiary
 				end
 			end
 			file = date.strftime( "#{cache_path}/%Y%m.parser" )
-	
+
 			unless key then
 				begin
 					File::delete( file )
@@ -990,7 +1177,7 @@ module TDiary
 				end
 				return nil
 			end
-	
+
 			begin
 				PStore::new( file ).transaction do |cache|
 					begin
@@ -1019,10 +1206,6 @@ module TDiary
 			end
 			obj
 		end
-	
-		def calendar
-			@years = @io.calendar unless @years
-		end
 
 		def load_filters
 			return if @filters
@@ -1039,6 +1222,7 @@ module TDiary
 			load_filters unless @filters
 			@filters.each do |filter|
 				return false unless filter.comment_filter( diary, comment )
+				break unless comment.visible?
 			end
 			true
 		end
@@ -1085,7 +1269,7 @@ module TDiary
 			updaterb_regexp = '' unless updaterb_regexp
 
 			if (masterkey != '' && check_key)
-				@csrf_protection="<input type=\"hidden\" name=\"csrf_protection_key\" value=\"#{CGI::escapeHTML(masterkey)}\">"
+				@csrf_protection = %Q[<input type="hidden" name="csrf_protection_key" value="#{h masterkey}">]
 			else
 				@csrf_protection="<!-- no CSRF protection key used -->"
 			end
@@ -1110,7 +1294,7 @@ module TDiary
 					given_key = given_key.read
 				end
 			end
-				
+
 			is_key_ok = masterkey != '' && given_key == masterkey
 
 			keycheck_ok = !check_key || is_key_ok
@@ -1119,7 +1303,7 @@ module TDiary
 			if csrf_protection_get_is_okay then
 				return if is_post || given_key == nil
 			else
-			        return if keycheck_ok && referercheck_ok
+				return if keycheck_ok && referercheck_ok
 			end
 
 			raise Exception.new(<<"EOS")
@@ -1131,9 +1315,9 @@ Security Error: Possible Cross-site Request Forgery (CSRF)
                     - GET is #{ csrf_protection_get_is_okay ? '' : 'not '}allowed
                 - Request Method is #{ is_post ? 'POST' : 'not POST' }
                 - Referer is #{ referer_is_empty ? 'empty' : referer_is_config ? 'config' : 'another page' }
-                    - Given referer:       #{ CGI::escapeHTML( referer_uri.to_s )}
-                    - Expected base URI:   #{ CGI::escapeHTML( base_uri.to_s )}
-                    - Expected update URI: #{ CGI::escapeHTML( config_uri.to_s )}
+                    - Given referer:       #{h referer_uri.to_s}
+                    - Expected base URI:   #{h base_uri.to_s}
+                    - Expected update URI: #{h config_uri.to_s}
                 - CSRF key is #{ is_key_ok ? 'OK' : given_key ? 'NG (' + (given_key || '') + ')' : 'nothing' }
 EOS
 		end
@@ -1172,7 +1356,16 @@ EOS
 			rescue TDiaryError
 			end
 			@date = Time::now + (@conf.hour_offset * 3600).to_i
-			@diary = @io.diary_factory( @date, '', '', @conf.style )
+			title = ''
+			@io.transaction( @date ) do |diaries|
+				@diaries = diaries
+				diary = self[@date]
+				if diary then
+					title = diary.title
+				end
+				DIRTY_NONE
+			end
+			@diary = @io.diary_factory( @date, title, '', @conf.style )
 		end
 	end
 
@@ -1185,7 +1378,7 @@ EOS
 
 		def initialize( cgi, rhtm, conf )
 			super
-	
+
 			@io.transaction( @date ) do |diaries|
 				@diaries = diaries
 				@diary = self[@date]
@@ -1206,7 +1399,7 @@ EOS
 	class TDiaryPreview < TDiaryAdmin
 		def initialize( cgi, rhtm, conf )
 			super
-	
+
 			@title = @conf.to_native( @cgi.params['title'][0] )
 			@body = @conf.to_native( @cgi.params['body'][0] )
 			@old_date = @cgi.params['old'][0]
@@ -1246,14 +1439,14 @@ EOS
 			@hide = cgi.params['hide'][0] == 'true' ? true : false
 			super
 		end
-	
+
 	protected
 		def do_eval_rhtml( prefix )
 			super
 			@plugin.instance_eval { update_proc }
-			anchor = @plugin.instance_eval( %Q[anchor "#{@diary.date.strftime('%Y%m%d')}"].untaint )
+			anchor_str = @plugin.instance_eval( %Q[anchor "#{@diary.date.strftime('%Y%m%d')}"].untaint )
 			clear_cache( /(latest|#{@date.strftime( '%Y%m' )})/ )
-			raise ForceRedirect::new( "#{@conf.index}#{anchor}" )
+			raise ForceRedirect::new( "#{@conf.index}#{anchor_str}" )
 		end
 	end
 
@@ -1294,7 +1487,7 @@ EOS
 		def initialize( cgi, rhtm, conf )
 			super
 			old_date = @cgi.params['old'][0]
-	
+
 			@io.transaction( @date ) do |diaries|
 				@diaries = diaries
 				@diary = self[@date]
@@ -1322,14 +1515,14 @@ EOS
 	class TDiaryShowComment < TDiaryAdmin
 		def initialize( cgi, rhtml, conf )
 			super
-	
+
 			@io.transaction( @date ) do |diaries|
 				@diaries = diaries
 				dirty = DIRTY_NONE
 				@diary = self[@date]
 				if @diary then
 					idx = 0
-					@diary.each_comment( 100 ) do |com|
+					@diary.each_comment do |com|
 						com.show = @cgi.params[(idx += 1).to_s][0] == 'true' ? true : false;
 					end
 					self << @diary
@@ -1339,6 +1532,12 @@ EOS
 				dirty
 			end
 		end
+
+		def eval_rhtml( prefix = '' )
+			load_plugins
+			@plugin.instance_eval { update_proc }
+			super
+		end
 	end
 
 	#
@@ -1360,7 +1559,7 @@ EOS
 				@date = Time::now + (@conf.hour_offset * 3600).to_i
 				@diary = @io.diary_factory( @date, '', '', @conf.style )
 			end
-	
+
 			@io.transaction( @date ) do |diaries|
 				@diaries = diaries
 				@diary = self[@date]
@@ -1383,7 +1582,7 @@ EOS
 
 		def initialize( cgi, rhtml, conf )
 			super
-			@key = CGI::escapeHTML( @cgi.params['conf'][0] || '' )
+			@key = @cgi.params['conf'][0] || ''
 		end
 	end
 
@@ -1400,7 +1599,7 @@ EOS
 
 		def eval_rhtml( prefix = '' )
 			r = super
-	
+
 			begin
 				@conf.save
 				clear_cache
@@ -1419,9 +1618,12 @@ EOS
 	class TDiaryView < TDiaryBase
 		def initialize( cgi, rhtml, conf )
 			super
-	
+			unless referer_filter( @cgi.referer )
+				def @cgi.referer; nil; end
+			end
+
 			# save referer to latest
-			if (!@conf.referer_day_only or (@cgi.params['date'][0] and @cgi.params['date'][0].length == 8)) and referer_filter( @cgi.referer ) then
+			if (!@conf.referer_day_only or (@cgi.params['date'][0] and @cgi.params['date'][0].length == 8)) and @cgi.referer then
 				ym = latest_month
 				@date = ym ? Time::local( ym[0], ym[1] ) : Time::now
 				@io.transaction( @date ) do |diaries|
@@ -1439,7 +1641,7 @@ EOS
 				end
 			end
 		end
-	
+
 		def last_modified
 			lm = Time::at( 0 )
 			@diaries.each_value do |diary|
@@ -1448,7 +1650,7 @@ EOS
 			end
 			lm
 		end
-	
+
 	protected
 		def each_day
 			@diaries.keys.sort.each do |date|
@@ -1457,7 +1659,7 @@ EOS
 				yield diary
 			end
 		end
-	
+
 		def latest_month
 			result = nil
 			calendar
@@ -1470,7 +1672,7 @@ EOS
 			end
 			result
 		end
-	
+
 		def oldest_month
 			result = nil
 			calendar
@@ -1483,7 +1685,7 @@ EOS
 			end
 			result
 		end
-	
+
 		def cache_enable?( prefix )
 			super and (File::mtime( "#{cache_path}/#{cache_file( prefix )}" ) > last_modified )
 		end
@@ -1517,7 +1719,7 @@ EOS
 					@diaries = diaries
 					dirty = DIRTY_NONE
 					@diary = self[@date]
-					if @diary and referer_filter( @cgi.referer ) then
+					if @diary and @cgi.referer then
 						@diary.add_referer( @cgi.referer )
 						dirty = DIRTY_REFERER
 					end
@@ -1580,8 +1782,8 @@ EOS
 		def do_eval_rhtml( prefix )
 			load_plugins
 			@plugin.instance_eval { update_proc } if @comment
-			anchor = @plugin.instance_eval( %Q[anchor "#{@diary.date.strftime('%Y%m%d')}"].untaint )
-			raise ForceRedirect::new( "#{@conf.index}#{anchor}#c#{'%02d' % @diary.count_comments( true )}" )
+			anchor_str = @plugin.instance_eval( %Q[anchor "#{@diary.date.strftime('%Y%m%d')}"].untaint )
+			raise ForceRedirect::new( "#{@conf.index}#{anchor_str}#c#{'%02d' % @diary.count_comments( true )}" )
 		end
 	end
 
@@ -1609,7 +1811,7 @@ EOS
 				raise TDiaryError, 'bad date'
 			end
 		end
-	
+
 	protected
 		def cache_file( prefix )
 			"#{prefix}#{@rhtml.sub( /month/, @date.strftime( '%Y%m' ) ).sub( /\.rhtml$/, '.rb' )}"
@@ -1646,7 +1848,7 @@ EOS
 			r
 		end
 	end
-			
+
 
 	#
 	# class TDiaryLatest
@@ -1655,22 +1857,65 @@ EOS
 	class TDiaryLatest < TDiaryView
 		def initialize( cgi, rhtml, conf )
 			super
-			ym = latest_month
+			if @cgi.params['date'][0] then
+				ym = [@cgi.params['date'][0][0,4].to_i, @cgi.params['date'][0][4,2].to_i]
+				@date = nil
+			else
+				ym = latest_month
+			end
 			unless @date then
 				@date = ym ? Time::local( ym[0], ym[1] ) : Time::now
 				@io.transaction( @date ) do |diaries|
 					@diaries = diaries
-					@diary = @diaries[@diaries.keys.sort.reverse[0]]
+					if @cgi.params['date'][0] then
+						@diary = @diaries[@cgi.params['date'][0][0,8]]
+						@date = @diary.date if @diary
+					end
+					unless @diary then
+						@diaries.keys.sort.reverse_each do |d|
+							diary = @diaries[d]
+							if diary.visible?
+								@diary = diary
+								break
+							end
+						end
+						@diary = @diaries[@diaries.keys.sort.reverse[0]] unless @diary
+						@date = @diary.date if @diary
+					end
 					DIRTY_NONE
 				end
 			end
-	
+
 			if ym then
+				# read +2 days for calc ndays.prev in count_diaries method
+				limit = limit_size( @conf.latest_limit ) + 2
+
+				# read next month data until limit
+				y = ym[0].to_i
+				m = ym[1].to_i
+				latest = latest_month
+				diaries_tmp = {}.update( @diaries )
+				diaries_size = count_diaries_after( diaries_tmp )
+				while ( latest and diaries_size < limit )
+					date = if m == 12 then
+						Time::local( y += 1, m = 1 )
+					else
+						Time::local( y, m += 1 )
+					end
+					break if date > Time::local( *latest )
+					@io.transaction( date ) do |diaries|
+						diaries_tmp.update( diaries )
+						diaries_size = count_diaries_after( diaries_tmp )
+						DIRTY_NONE
+					end
+				end
+
+				# read prev month data until limit
 				y = ym[0].to_i
 				m = ym[1].to_i
 				oldest = oldest_month
-				calc_diaries_size
-				while ( oldest and @diaries_size < @conf.latest_limit )
+				diaries_size = count_diaries_before( @diaries )
+				while ( oldest and diaries_size < limit )
 					date = if m == 1 then
 						Time::local( y -= 1, m = 12 )
 					else
@@ -1679,34 +1924,85 @@ EOS
 					break if date < Time::local( *oldest )
 					@io.transaction( date ) do |diaries|
 						@diaries.update( diaries )
-						calc_diaries_size
+						diaries_size = count_diaries_before( @diaries )
 						DIRTY_NONE
 					end
 				end
 			end
 		end
-	
-	protected
-		def calc_diaries_size
-			@diaries_size = 0
-			@diaries.each_value do |diary|
-				@diaries_size += 1 if diary.visible?
-			end
-		end
-	
+
 		def latest( limit = 5 )
+			start = start_date
+			limit = limit_size( limit )
 			idx = 0
 			@diaries.keys.sort.reverse_each do |date|
-				break if idx >= limit
+				next if date > start
 				diary = @diaries[date]
 				next unless diary.visible?
 				yield diary
 				idx += 1
+				break if idx >= limit
 			end
 		end
-	
+
+	protected
+		def count_diaries_after( diaries )
+			start = start_date
+			limit = limit_size( @conf.latest_limit )
+			diaries_size = 0
+			continue_exist = true
+			diaries.keys.sort.each do |date|
+				if diaries[date].visible? and date > start then
+					continue_exist = true if diaries_size < limit
+					@conf['ndays.next'] = date if diaries_size < limit
+					diaries_size += 1
+				end
+			end
+			@conf['ndays.next'] = nil unless continue_exist
+			diaries_size
+		end
+
+		def count_diaries_before( diaries )
+			start = start_date
+			limit = limit_size( @conf.latest_limit )
+			diaries_size = 0
+			continue_exist = false
+			diaries.keys.sort.reverse_each do |date|
+				if diaries[date].visible? and date <= start then
+					continue_exist = true if diaries_size >= limit
+					@conf['ndays.prev'] = date if diaries_size <= limit
+					diaries_size += 1
+				end
+			end
+			@conf['ndays.prev'] = nil unless continue_exist
+			diaries_size
+		end
+
 		def cache_file( prefix )
-			"#{prefix}#{@rhtml.sub( /\.rhtml$/, '.rb' )}"
+			if @cgi.params['date'][0] then
+				nil
+			else
+				"#{prefix}#{@rhtml.sub( /\.rhtml$/, '.rb' )}"
+			end
+		end
+
+		def start_date
+			if @cgi.params['date'][0] then
+				@cgi.params['date'][0][0,8]
+			else
+				'99999999' # max of date string
+			end
+		end
+
+		def limit_size( default_limit )
+			if @cgi.params['date'][0] then
+				date = @cgi.params['date'][0]
+				limit = date[9,date.length-9].to_i
+				limit = 30 if limit > 30
+				limit
+			else
+				default_limit
+			end
 		end
 	end
 
@@ -1735,12 +2031,13 @@ EOS
 		public :mode
 		def initialize( cgi, rhtml, conf )
 			super
-			date = ENV['REQUEST_URI'].scan(%r!/(\d{4})(\d\d)(\d\d)!)[0]
+			date = @cgi.request_uri.scan(%r!/(\d{4})(\d\d)(\d\d)!)[0]
 			if date
 				@date = Time::local(*date)
 			else
 				@date = Time::now
 			end
+			@cgi.params['date'] = [@date.strftime( '%Y%m%d' )]
 		end
 
 		def diary_url
@@ -1761,64 +2058,12 @@ HERE
 <?xml version="1.0" encoding="iso-8859-1"?>
 <response>
 <error>1</error>
-<message>#{reason}</message>
+<message>#{CGI::escapeHTML reason}</message>
 </response>
 HERE
 		end
 	end
 
-	#
-	# class TDiaryTrackBackRSS
-	#  generate RSS
-	#
-	class TDiaryTrackBackRSS < TDiaryTrackBackBase
-		def initialize( cgi, rhtml, conf )
-			super
-			@io.transaction( @date ) do |diaries|
-				@diaries = diaries
-				@diary = @diaries[@date.strftime('%Y%m%d')]
-				DIRTY_NONE
-			end
-		end
-
-		def eval_rhtml( prefix = '' )
-			raise TDiaryTrackBackError.new("invalid date: #{@date.strftime('%Y%m%d')}") unless @diary
-			load_plugins
-			r = <<RSSHEAD
-<?xml version="1.0" encoding="#{@conf.encoding}"?>
-<response>
-<error>0</error>
-<rss version="0.91">
-<channel>
-<title>#{@diary.title}</title>
-<link>#{diary_url}</link>
-<description></description>
-<language>#{@conf.html_lang}</language>
-RSSHEAD
-			@diary.each_comment(100) do |com, idx|
-				begin
-					next unless com.visible_true?
-				rescue NameError, NoMethodError
-					next unless com.visible?
-				end
-				next unless /^(Track|Ping)Back$/ =~ com.name
-				url, blog_name, title, excerpt = com.body.split(/\n/, 4)
-				r << <<RSSITEM
-<item>
-<title>#{CGI::escapeHTML( title )}</title>
-<link>#{CGI::escapeHTML( url )}</link>
-<description>#{CGI::escapeHTML( excerpt )}</description>
-</item>
-RSSITEM
-			end
-			r << <<RSSFOOT
-</channel>
-</rss>
-</response>
-RSSFOOT
-		end
-	end
-
 	#
 	# class TDiaryTrackBackReceive
 	#  receive TrackBack ping and store as comment
@@ -1828,10 +2073,15 @@ RSSFOOT
 			super
 			@error = nil
 
+			charset = nil
+			if @cgi.content_type =~ /charset=([^\s;]*)/i then
+				charset = $1
+			end
+			
 			url = @cgi.params['url'][0]
-			blog_name = @conf.to_native( @cgi.params['blog_name'][0] || '' )
-			title = @conf.to_native( @cgi.params['title'][0] || '' )
-			excerpt = @conf.to_native( @cgi.params['excerpt'][0] || '' )
+			blog_name = @conf.to_native( @cgi.params['blog_name'][0] || '', charset )
+			title = @conf.to_native( @cgi.params['title'][0] || '', charset )
+			excerpt = @conf.to_native( @cgi.params['excerpt'][0] || '', charset )
 			if excerpt.length > 255
 				excerpt = @conf.shorten( excerpt, 252 )
 			end
@@ -1847,8 +2097,12 @@ RSSFOOT
 					@diary = @diaries[@date.strftime('%Y%m%d')]
 					if @diary and comment_filter( @diary, @comment ) then
 						@diary.add_comment(@comment)
+						unless @comment.visible?
+							@error = 'Your TrackBack has been filtered (maybe).'
+						end
 						DIRTY_COMMENT
 					else
+						@error = 'Your TrackBack has been filtered.'
 						@comment = nil
 						DIRTY_NONE
 					end
@@ -1873,8 +2127,8 @@ RSSFOOT
 	class TDiaryTrackBackShow < TDiaryTrackBackBase
 		def eval_rhtml( prefix = '' )
 			load_plugins
-			anchor = @plugin.instance_eval(%Q|anchor "#{@date.strftime('%Y%m%d')}"|)
-			url = "#{@conf.index}#{anchor}#t"
+			anchor_str = @plugin.instance_eval(%Q|anchor "#{@date.strftime('%Y%m%d')}"|)
+			url = "#{@conf.index}#{anchor_str}#t"
 			url[0, 0] = '../' if %r|^https?://|i !~ @conf.index
 			raise ForceRedirect::new( url )
 		end
