@@ -1,5 +1,5 @@
 #
-# defaultio.rb: tDiary IO class for tDiary 2.x format. $Revision: 1.28.2.3 $
+# defaultio.rb: tDiary IO class for tDiary 2.x format. $Revision: 1.43 $
 #
 # Copyright (C) 2001-2005, TADA Tadashi <sho@spc.gr.jp>
 # You can redistribute it and/or modify it under GPL2.
@@ -11,15 +11,19 @@ module TDiary
 
 	def TDiary::parse_tdiary( data )
 		header, body = data.split( /\r?\n\r?\n/, 2 )
-		if header and body
-			body.gsub!( /^\./, '' )
-			headers = {}
+		headers = {}
+		if header then
 			header.each do |l|
 				l.chomp!
 				key, val = l.scan( /([^:]*):\s*(.*)/ )[0]
 				headers[key] = val ? val.chomp : nil
 			end
 		end
+		if body then
+			body.gsub!( /^\./, '' )
+		else
+			body = ''
+		end
 		[headers, body]
 	end
 
@@ -31,7 +35,8 @@ module TDiary
 		def restore_comment( file, diaries )
 			begin
 				File::open( file, 'r' ) do |fh|
-					(fh.read || '').split( /\r?\n\.\r?\n/ ).each do |l|
+					fh.flock( File::LOCK_SH )
+					fh.read.split( /\r?\n\.\r?\n/ ).each do |l|
 						headers, body = TDiary::parse_tdiary( l )
 						next unless body
 						comment = Comment::new(
@@ -40,7 +45,7 @@ module TDiary
 								body,
 								Time::at( headers['Last-Modified'].to_i ) )
 						comment.show = false if headers['Visible'] == 'false'
-						diaries[headers['Date']].add_comment( comment )
+						diaries[headers['Date']].add_comment( comment ) if headers['Date']
 					end
 				end
 			rescue Errno::ENOENT
@@ -48,21 +53,24 @@ module TDiary
 		end
 
 		def store_comment( file, diaries )
-			fhc = File::open( file, 'w' )
-			fhc.puts( TDIARY_MAGIC )
-			diaries.each do |date,diary|
-				diary.each_comment( diary.count_comments( true ) ) do |com|
-					fhc.puts( "Date: #{date}" )
-					fhc.puts( "Name: #{com.name}" )
-					fhc.puts( "Mail: #{com.mail}" )
-					fhc.puts( "Last-Modified: #{com.date.to_i}" )
-					fhc.puts( "Visible: #{com.visible? ? 'true' : 'false'}" )
-					fhc.puts
-					fhc.puts( com.body.gsub( /\r/, '' ).sub( /\n+\Z/, '' ).gsub( /\n\./, "\n.." ) )
-					fhc.puts( '.' )
+			File::open( file, File::WRONLY | File::CREAT ) do |fhc|
+				fhc.flock( File::LOCK_EX )
+				fhc.rewind
+				fhc.truncate( 0 )
+				fhc.puts( TDIARY_MAGIC )
+				diaries.each do |date,diary|
+					diary.each_comment( diary.count_comments( true ) ) do |com|
+						fhc.puts( "Date: #{date}" )
+						fhc.puts( "Name: #{com.name}" )
+						fhc.puts( "Mail: #{com.mail}" )
+						fhc.puts( "Last-Modified: #{com.date.to_i}" )
+						fhc.puts( "Visible: #{com.visible? ? 'true' : 'false'}" )
+						fhc.puts
+						fhc.puts( com.body.gsub( /\r/, '' ).sub( /\n+\Z/, '' ).gsub( /\n\./, "\n.." ) )
+						fhc.puts( '.' )
+					end
 				end
 			end
-			fhc.close
 		end
 	end
 
@@ -74,7 +82,8 @@ module TDiary
 		def restore_referer( file, diaries )
 			begin
 				File::open( file, 'r' ) do |fh|
-					(fh.read || '').split( /\r?\n\.\r?\n/ ).each do |l|
+					fh.flock( File::LOCK_SH )
+					fh.read.split( /\r?\n\.\r?\n/ ).each do |l|
 						headers, body = TDiary::parse_tdiary( l )
 						next unless body
 						body.each do |r|
@@ -83,23 +92,31 @@ module TDiary
 							diaries[headers['Date']].add_referer( ref.chomp, count.to_i )
 						end
 					end
+
+					# convert to referer plugin format
+					diaries.each do |date,diary|
+						fname = file.sub( /\.tdr$/, "#{date[6,2]}.tdr".untaint )
+						File::open( fname, File::WRONLY | File::CREAT ) do |fhr|
+							fhr.flock( File::LOCK_EX )
+							fhr.rewind
+							fhr.truncate( 0 )
+							fhr.puts( TDiary::TDIARY_MAGIC )
+							fhr.puts( "Date: #{date}" )
+							fhr.puts 
+							diary.each_referer( diary.count_referers ) do |count,ref|
+								fhr.puts( "#{count} #{ref}" )
+							end
+							fhr.puts( '.' )
+						end
+					end
 				end
+				File::rename( file, file.sub( /\.tdr$/, '.tdr~' ) )
 			rescue Errno::ENOENT
 			end
 		end
 
 		def store_referer( file, diaries )
-			fhr = File::open( file, 'w' )
-			fhr.puts( TDiary::TDIARY_MAGIC )
-			diaries.each do |date,diary|
-				fhr.puts( "Date: #{date}" )
-				fhr.puts 
-				diary.each_referer( diary.count_referers ) do |count,ref|
-					fhr.puts( "#{count} #{ref}" )
-				end
-				fhr.puts( '.' )
-			end
-			fhr.close
+			return
 		end
 	end
 
@@ -147,14 +164,27 @@ module TDiary
 					@tdiary.store_parser_cache( date, 'defaultio', diaries )
 				end
 
-				fh.close
 				if diaries.empty?
-					File::delete( @dfile )
-					# also delete parser cache
-					@tdiary.store_parser_cache( date, nil, nil)
+					begin
+						if fh then
+							fh.close
+							fh = nil
+						end
+						File::delete( @dfile )
+					rescue Errno::ENOENT
+					end
+					begin
+						@tdiary.store_parser_cache( date, nil, nil)
+					rescue Errno::ENOENT
+					end
 				end
 				# delete dispensable data directory
-				Dir.delete( dir ) if Dir.new( dir ).entries.reject {|f| "." == f or ".." == f}.empty?
+				begin
+					Dir.delete( dir ) if Dir.new( dir ).entries.reject {|f| "." == f or ".." == f}.empty?
+				rescue Errno::ENOENT
+				end
+			ensure
+				fh.close if fh
 			end
 		end
 	
@@ -178,46 +208,46 @@ module TDiary
 
 	private
 		def restore( fh, diaries )
-			fh.seek( 0 )
 			begin
-				major, minor = fh.gets.split( /\./, 2 )
-				unless TDIARY_MAGIC_MAJOR == major then
-					raise StandardError, 'bad file format.'
-				end
-			rescue NameError
-				# no magic number when it is new file.
-			end
-
-			# read and parse diary
-			(fh.read || '').split( /\r?\n\.\r?\n/ ).each do |l|
+				fh.seek( 0 )
 				begin
-					headers, body = TDiary::parse_tdiary( l )
-					style = headers['Format'] || 'tDiary'
-					diary = eval( "#{style( style )}::new( headers['Date'], headers['Title'], body, Time::at( headers['Last-Modified'].to_i ) )" )
-					diary.show( headers['Visible'] == 'true' ? true : false )
-					diaries[headers['Date']] = diary
+					major, minor = fh.gets.split( /\./, 2 )
+					unless TDIARY_MAGIC_MAJOR == major then
+						raise StandardError, 'bad file format.'
+					end
+
+					# read and parse diary
+					fh.read.split( /\r?\n\.\r?\n/ ).each do |l|
+						headers, body = TDiary::parse_tdiary( l )
+						style_name = headers['Format'] || 'tDiary'
+						diary = eval( "#{style( style_name )}::new( headers['Date'], headers['Title'], body, Time::at( headers['Last-Modified'].to_i ) )" )
+						diary.show( headers['Visible'] == 'true' ? true : false )
+						diaries[headers['Date']] = diary
+					end
+
 				rescue NameError
-				rescue
-					raise
+					# no magic number when it is new file.
 				end
 			end
 		end
 
 		def store( fh, diaries )
-			fh.seek( 0 )
-			fh.puts( TDIARY_MAGIC )
-			diaries.each do |date,diary|
-				# save diaries
-				fh.puts( "Date: #{date}" )
-				fh.puts( "Title: #{diary.title}" )
-				fh.puts( "Last-Modified: #{diary.last_modified.to_i}" )
-				fh.puts( "Visible: #{diary.visible? ? 'true' : 'false'}" )
-				fh.puts( "Format: #{diary.style}" )
-				fh.puts
-				fh.puts( diary.to_src.gsub( /\r/, '' ).gsub( /\n\./, "\n.." ) )
-				fh.puts( '.' )
+			begin
+				fh.seek( 0 )
+				fh.puts( TDIARY_MAGIC )
+				diaries.each do |date,diary|
+					# save diaries
+					fh.puts( "Date: #{date}" )
+					fh.puts( "Title: #{diary.title}" )
+					fh.puts( "Last-Modified: #{diary.last_modified.to_i}" )
+					fh.puts( "Visible: #{diary.visible? ? 'true' : 'false'}" )
+					fh.puts( "Format: #{diary.style}" )
+					fh.puts
+					fh.puts( diary.to_src.gsub( /\r/, '' ).gsub( /\n\./, "\n.." ) )
+					fh.puts( '.' )
+				end
+				fh.truncate( fh.tell )
 			end
-			fh.truncate( fh.tell )
 		end
 	end
 end
