@@ -1,6 +1,6 @@
 #!/usr/bin/env ruby
 #
-# update.rb $Revision: 1.17 $
+# update.rb $Revision: 1.21 $
 #
 # Copyright (C) 2001-2003, TADA Tadashi <sho@spc.gr.jp>
 # You can redistribute it and/or modify it under GPL2.
@@ -18,7 +18,7 @@ begin
 	require 'tdiary'
 
 	@cgi = CGI::new
-	conf = TDiary::Config::new
+	conf = TDiary::Config::new(@cgi)
 	tdiary = nil
 
 	begin
@@ -89,12 +89,17 @@ begin
 	
 rescue Exception
 	if @cgi then
-		print @cgi.header( 'type' => 'text/plain' )
+		print @cgi.header( 'status' => '500 Internal Server Error', 'type' => 'text/html' )
 	else
-		print "Content-Type: text/plain\n\n"
+		print "Status: 500 Internal Server Error\n"
+		print "Content-Type: text/html\n\n"
 	end
-	puts "#$! (#{$!.class})"
+	puts "<h1>500 Internal Server Error</h1>"
+	puts "<pre>"
+	puts CGI::escapeHTML( "#{$!} (#{$!.class})" )
 	puts ""
-	puts $@.join( "\n" )
+	puts CGI::escapeHTML( $@.join( "\n" ) )
+	puts "</pre>"
+	puts "<div>#{' ' * 500}</div>"
 end
 
